/*
 * $Id: spm-migprep71.sql 101389 2011-11-25 01:51:25Z rlowery $
 *
 * Prepare to migrate a SPM 7.0 database into SPM 7.1 format.
 *
 * Use this first, then schema.sql, then migpost.sql, and finally
 * install SPM 7.1 which will create the stored procedures.
 *
 * The aim here is to make minimal changes that will allow schema.sql
 * to succeed in creating any new objects, before migpost.sql finishes
 * reshaping some tables and dropping any unused objects.
 *
 * Copyright 2011 Flexera Software LLC
 */

USE ManageSoft
GO

/*
 * Check that we are upgrading from a 7.0 database...
 */
DECLARE @spm_schema_version char(10)
SET @spm_schema_version = (SELECT Value FROM DatabaseConfiguration
		WHERE Property = 'SPMSchemaVersion')

IF @spm_schema_version IS NULL
	SET @spm_schema_version = (SELECT Value FROM DatabaseConfiguration
			WHERE Property = 'SchemaVersion')
		
IF (@spm_schema_version = '7.0')
BEGIN
	PRINT 'Preparing to migrate database from ManageSoft SPM 7.0 schema...'
END
ELSE IF (@spm_schema_version = '7.1')
BEGIN
        RAISERROR ('Your ManageSoft SPM database has already been migrated to the 7.1 schema.', 16, 1)
        RAISERROR ('For more information on migrating your database, refer to the ManageSoft Upgrade Guide.', 16, 1)
END
ELSE
BEGIN
	RAISERROR ('This script can only migrate from the ManageSoft SPM database schema version 7.0.', 16, 1)
	RAISERROR ('Please migrate your database schema to version 7.0 before executing this script again.', 16, 1)
        RAISERROR ('For more information on migrating your database, refer to the ManageSoft Upgrade Guide.', 16, 1)
END
GO


--===========================================================================
--		Alter the SecPatch_Patch table
--===========================================================================

PRINT 'Alter PatchName column in SecPatch_Patch table'

IF EXISTS (
	SELECT *
	FROM INFORMATION_SCHEMA.TABLES
	WHERE TABLE_NAME = 'SecPatch_Patch'
)
BEGIN

	DROP INDEX SecPatch_Patch.IN_PATCH
	
	ALTER TABLE SecPatch_Patch
		DROP UQ_Patch

	ALTER TABLE SecPatch_Patch 
		ALTER COLUMN PatchName nvarchar(128) 
		COLLATE Latin1_General_CS_AS

	CREATE NONCLUSTERED INDEX IN_Patch
		ON SecPatch_Patch(PatchName)

	ALTER TABLE SecPatch_Patch
		ADD CONSTRAINT UQ_Patch UNIQUE NONCLUSTERED (BulletinID, PatchName)
END
GO


--===========================================================================
--		Alter the SecurityPatch table
--===========================================================================

PRINT 'Alter PatchName column in SecurityPatch table'

IF EXISTS (
	SELECT *
	FROM INFORMATION_SCHEMA.TABLES
	WHERE TABLE_NAME = 'SecurityPatch'
)
BEGIN
	ALTER TABLE SecurityPatch
		DROP UQ_SecurityPatch

	ALTER TABLE SecurityPatch 
		ALTER COLUMN PatchName nvarchar(128) 
		COLLATE Latin1_General_CS_AS
END
GO

PRINT 'Remove duplicate BulletinID and PatchName in SecurityPatch table'

IF EXISTS (
	SELECT *
	FROM INFORMATION_SCHEMA.TABLES
	WHERE TABLE_NAME = 'SecurityPatch'
)
BEGIN
	-- SecurityPatch table cannot contain duplicate BulletinID and 
	-- PatchName as BulletinID and PatchName form a unique index
	-- Check for duplicate row and only removes BulletinID and PatchName
	-- that are not in SecPatch_Patch table. Current mssecure.xml will
	-- not have duplicate BulletinID and PatchName.

	-- Update SecurityPatchID that will be removed with the 
	-- valid SecurityPatchID
	
	UPDATE SecurityPatchAnalysis
	SET SecurityPatchID = Tmp.RealPatchID
	FROM 
		(
			SELECT 
				sp1.PatchID, 
				sp1.BulletinID, 
				sp1.PatchName,
				RealPatchID = 
					( SELECT DISTINCT SecurityPatchID 
					  FROM SecPatch_Patch AS spp 
						WHERE sp1.BulletinID = spp.BulletinID 
						AND sp1.PatchName = spp.PatchName
				)
			FROM 
				SecurityPatch as sp1
			WHERE sp1.PatchID NOT IN (SELECT SecurityPatchID FROM SecPatch_Patch)
			AND 
			(
					SELECT 
					COUNT(PatchID) AS BulletinCount
					FROM SecurityPatch sp2
					WHERE 	sp1.BulletinID = sp2.BulletinID
					  AND	sp1.PatchName = sp2.PatchName
					GROUP BY BulletinID, PatchName
					HAVING COUNT(PatchID) > 1
				) 	> 1
		) AS Tmp
	WHERE SecurityPatchAnalysis.SecurityPatchID = Tmp.PatchID

	
	-- Remove entry that reference invalid SecurityPatchID
	DELETE 
	FROM SecurityPatchToPackageVersion
	WHERE patchID IN
		(
			SELECT 
				sp1.PatchID 
			FROM 
				SecurityPatch as sp1
			WHERE sp1.PatchID NOT IN (SELECT SecurityPatchID FROM SecPatch_Patch)
			AND 
				(
					SELECT 
					COUNT(PatchID) AS BulletinCount
					FROM SecurityPatch sp2
					WHERE 	sp1.BulletinID = sp2.BulletinID
					  AND	sp1.PatchName = sp2.PatchName
					GROUP BY BulletinID, PatchName
					HAVING COUNT(PatchID) > 1
				) > 1
		)
		
	-- Remove entry that reference invalid SecurityPatchID
	DELETE 
	FROM SecurityPatchUninstallValues
	WHERE SecurityPatchID IN
		(
			SELECT 
				sp1.PatchID 
			FROM 
				SecurityPatch as sp1
			WHERE sp1.PatchID NOT IN (SELECT SecurityPatchID FROM SecPatch_Patch)
			AND 
				(
					SELECT 
					COUNT(PatchID) AS BulletinCount
					FROM SecurityPatch sp2
					WHERE 	sp1.BulletinID = sp2.BulletinID
					  AND	sp1.PatchName = sp2.PatchName
					GROUP BY BulletinID, PatchName
					HAVING COUNT(PatchID) > 1
				) > 1
		)
		
	-- Remove entry that reference invalid SecurityPatchID
	DELETE 
	FROM SecurityPatchRequires
	WHERE PatchID IN
		(
			SELECT 
				sp1.PatchID 
			FROM 
				SecurityPatch as sp1
			WHERE sp1.PatchID NOT IN (SELECT SecurityPatchID FROM SecPatch_Patch)
			AND 
				(
					SELECT 
					COUNT(PatchID) AS BulletinCount
					FROM SecurityPatch sp2
					WHERE 	sp1.BulletinID = sp2.BulletinID
					  AND	sp1.PatchName = sp2.PatchName
					GROUP BY BulletinID, PatchName
					HAVING COUNT(PatchID) > 1
				) > 1
		)

	-- Deleting invalid BulletinID and PatchName

	DELETE 
	FROM SecurityPatch
	WHERE SecurityPatch.PatchID IN 
		(
			SELECT 
				sp1.PatchID 
			FROM 
				SecurityPatch as sp1
			WHERE sp1.PatchID NOT IN (SELECT SecurityPatchID FROM SecPatch_Patch)
			AND 
				(
					SELECT 
					COUNT(PatchID) AS BulletinCount
					FROM SecurityPatch sp2
					WHERE 	sp1.BulletinID = sp2.BulletinID
					  AND	sp1.PatchName = sp2.PatchName
					GROUP BY BulletinID, PatchName
					HAVING COUNT(PatchID) > 1
				) > 1
		)	

	ALTER TABLE SecurityPatch
		ADD CONSTRAINT UQ_SecurityPatch UNIQUE NONCLUSTERED (BulletinID, PatchName)
END
GO

--===========================================================================
--		Alter the SecPatch_SupercededPatch table
--===========================================================================

PRINT 'Alter PatchName column in SecPatch_SupercededPatch table'

IF EXISTS (
	SELECT *
	FROM INFORMATION_SCHEMA.TABLES
	WHERE TABLE_NAME = 'SecPatch_SupercededPatch'
)
BEGIN
	
	ALTER TABLE SecPatch_SupercededPatch
		DROP UQ_SupercededPatch

	ALTER TABLE SecPatch_SupercededPatch 
		ALTER COLUMN PatchName nvarchar(50) 
		COLLATE Latin1_General_CS_AS

	ALTER TABLE SecPatch_SupercededPatch
		ADD CONSTRAINT UQ_SupercededPatch UNIQUE NONCLUSTERED (PatchName, BulletinID, SupercededByID)

END
GO

--===========================================================================
--		Insert 'unknown' in SecurityBulletin table
--===========================================================================

PRINT 'Insert unknown row in SecurityBulletin table'

IF EXISTS (
	SELECT *
	FROM INFORMATION_SCHEMA.TABLES
	WHERE TABLE_NAME = 'SecurityBulletin'
)
BEGIN

	IF NOT EXISTS (
		SELECT * 
		FROM SecurityBulletin
		WHERE SecurityBulletinID = 0
	)
	BEGIN
	
		SET IDENTITY_INSERT SecurityBulletin ON
		INSERT INTO SecurityBulletin (SecurityBulletinID, BulletinID, Severity, DatePosted, DateRevised)
			VALUES (0, 'Unknown', 0, '20030328', '20030328');
		SET IDENTITY_INSERT SecurityBulletin OFF

	END
	
END
GO

--===========================================================================
--		Insert 'unknown' in SecurityPatch table
--===========================================================================

PRINT 'Insert unknown row in SecurityPatch table'

IF EXISTS (
	SELECT *
	FROM INFORMATION_SCHEMA.TABLES
	WHERE TABLE_NAME = 'SecurityPatch'
)
BEGIN
	IF NOT EXISTS (
		SELECT * 
		FROM SecurityPatch
		WHERE PatchID = 0
	)
	BEGIN
	
		SET IDENTITY_INSERT SecurityPatch ON
		INSERT INTO SecurityPatch (PatchID, BulletinID, Patchname, DownloadLocation, QNumber, ActualDownloadLocation)
			VALUES (0, 'Unknown', 'Unknown', '', '', '');
		SET IDENTITY_INSERT SecurityPatch OFF
		
	END
END
GO

--===========================================================================
--		Alter the SecurityPatchAnalysis table
--===========================================================================

PRINT 'Change all SecurityPatchID NULLs to Unknown Patch on SecurityPatchAnalysis table'

IF EXISTS (
	SELECT *
	FROM INFORMATION_SCHEMA.TABLES
	WHERE TABLE_NAME = 'SecurityPatchAnalysis'
)
BEGIN
	-- Add a temp synthetic ID
	ALTER TABLE SecurityPatchAnalysis ADD SecurityPatchAnalysisID INTEGER IDENTITY NOT NULL
END 


GO
IF EXISTS (
	SELECT *
	FROM INFORMATION_SCHEMA.TABLES
	WHERE TABLE_NAME = 'SecurityPatchAnalysis'
)
BEGIN
	-- Change all SecurityPatchID NULLs to Unknown Patch (PatchID=0)
	UPDATE	SecurityPatchAnalysis SET SecurityPatchID = 0
	WHERE	SecurityPatchID IS NULL	
	
	-- Delete all duplicate rows
	DELETE	SPA1
	FROM	SecurityPatchAnalysis AS SPA1, SecurityPatchAnalysis AS SPA2
	WHERE	SPA1.SecurityPatchAnalysisID <> SPA2.SecurityPatchAnalysisID
	AND	SPA1.ComputerID = SPA2.ComputerID
	AND	SPA1.BulletinID = SPA2.BulletinID
	AND	(SPA1.SecurityPatchID = SPA2.SecurityPatchID OR
		(SPA1.SecurityPatchID IS NULL AND SPA2.SecurityPatchID IS NULL)
		)
	AND	SPA1.SecurityPatchAnalysisID <> 
		(SELECT	TOP 1 SPA3.SecurityPatchAnalysisID
		FROM	SecurityPatchAnalysis AS SPA3
		WHERE	SPA3.ComputerID = SPA1.ComputerID
		AND	SPA3.BulletinID = SPA1.BulletinID
		AND	(SPA3.SecurityPatchID = SPA1.SecurityPatchID OR
			(SPA3.SecurityPatchID IS NULL AND SPA1.SecurityPatchID IS NULL)
			)
		ORDER BY SPA3.Status
	)
	ALTER TABLE SecurityPatchAnalysis DROP COLUMN SecurityPatchAnalysisID
END

PRINT 'Create indices on BulletinID and ComputerID on SecurityPatchAnalysis table'

GO
IF EXISTS (
	SELECT *
	FROM INFORMATION_SCHEMA.TABLES
	WHERE TABLE_NAME = 'SecurityPatchAnalysis'
)
BEGIN
	
	-- Add primary key
	DROP INDEX SecurityPatchAnalysis.SecurityPatchAnalysis_ByBulletin
	DROP INDEX SecurityPatchAnalysis.PQ_SecurityPatchAnalysis_ByComputer
	
	CREATE INDEX SecurityPatchAnalysis_ByBulletin 
		ON SecurityPatchAnalysis (BulletinID, ComputerID)
	
	ALTER TABLE SecurityPatchAnalysis ALTER COLUMN SecurityPatchID INTEGER NOT NULL

END

PRINT 'Add constraint on ComputerID, BulletinID and SecurityPatchID on SecurityPatchAnalysis table'

GO
IF EXISTS (
	SELECT *
	FROM INFORMATION_SCHEMA.TABLES
	WHERE TABLE_NAME = 'SecurityPatchAnalysis'
)
BEGIN

	ALTER TABLE SecurityPatchAnalysis 
		ADD CONSTRAINT PK_SecurityPatchAnalysis_ByComputer PRIMARY KEY CLUSTERED 
		(
			ComputerID,
			BulletinID,
			SecurityPatchID
		)
END
GO

