/*
 * $Id: spm-migprep72.sql 101389 2011-11-25 01:51:25Z rlowery $
 *
 * Prepare to migrate a SPM 7.0 database into SPM 7.1 format.
 *
 * Use this first, then schema.sql, then migpost.sql, and finally
 * install SPM 7.2 which will create the stored procedures.
 *
 * The aim here is to make minimal changes that will allow schema.sql
 * to succeed in creating any new objects, before migpost.sql finishes
 * reshaping some tables and dropping any unused objects.
 *
 * Copyright 2011 Flexera Software LLC
 */

USE ManageSoft
GO

/*
 * Check that we are upgrading from a 7.0 database...
 */
DECLARE @schema_version char(10)
SET @schema_version = (SELECT Value FROM DatabaseConfiguration
		WHERE Property = 'SchemaVersion')

DECLARE @spm_schema_version char(10)
SET @spm_schema_version = (SELECT Value FROM DatabaseConfiguration
		WHERE Property = 'SPMSchemaVersion')

IF @spm_schema_version IS NULL
	SET @spm_schema_version = @schema_version
		
IF (@schema_version = '7.1.5')
BEGIN
	PRINT 'Preparing to migrate ManageSoft SPM 7.2 database information...'
END
ELSE IF (@schema_version = '7.2')
BEGIN
	PRINT 'Your ManageSoft SPM database has already been migrated to 7.2'
	PRINT 'For more information on migrating your database, refer to the ManageSoft Upgrade Guide.'
	RETURN
END
ELSE
BEGIN
	PRINT 'This script can only migrate database information from ManageSoft SPM 7.1.5, not from any previous versions.'
	PRINT 'Please migrate any previous versions of your database information first.'
	PRINT 'For more information on migrating your database, refer to the ManageSoft Upgrade Guide.'
	RETURN
END
GO


--===========================================================================
--		Alter the SecurityPatch table
--===========================================================================

PRINT 'Modify LanguageID column on SecurityPatch'
IF EXISTS (
	SELECT *
	FROM INFORMATION_SCHEMA.TABLES
	WHERE TABLE_NAME = 'SecurityPatch'
)
BEGIN
	-- drop constraints
	IF EXISTS (SELECT * FROM INFORMATION_SCHEMA.CONSTRAINT_COLUMN_USAGE WHERE CONSTRAINT_NAME = 'FK_Patch_SecurityPatch')
		BEGIN ALTER TABLE SecPatch_Patch DROP CONSTRAINT FK_Patch_SecurityPatch END
	IF EXISTS (SELECT * FROM INFORMATION_SCHEMA.CONSTRAINT_COLUMN_USAGE WHERE CONSTRAINT_NAME = 'FK_SecurityPatchRequires_SecurityPatch')
		BEGIN ALTER TABLE SecurityPatchRequires DROP CONSTRAINT FK_SecurityPatchRequires_SecurityPatch END
	IF EXISTS (SELECT * FROM INFORMATION_SCHEMA.CONSTRAINT_COLUMN_USAGE WHERE CONSTRAINT_NAME = 'FK_SecurityPatchRequires2_SecurityPatch')
		BEGIN ALTER TABLE SecurityPatchRequires DROP CONSTRAINT FK_SecurityPatchRequires2_SecurityPatch END
	IF EXISTS (SELECT * FROM INFORMATION_SCHEMA.CONSTRAINT_COLUMN_USAGE WHERE CONSTRAINT_NAME = 'FK_SecurityPatchToPackageVersion_SecurityPatch')
		BEGIN ALTER TABLE SecurityPatchToPackageVersion DROP CONSTRAINT FK_SecurityPatchToPackageVersion_SecurityPatch END
	IF EXISTS (SELECT * FROM INFORMATION_SCHEMA.CONSTRAINT_COLUMN_USAGE WHERE CONSTRAINT_NAME = 'FK_SecurityPatchAnalysis_SecutityPatch')
		BEGIN ALTER TABLE SecurityPatchAnalysis DROP CONSTRAINT FK_SecurityPatchAnalysis_SecutityPatch END
	IF EXISTS (SELECT * FROM INFORMATION_SCHEMA.CONSTRAINT_COLUMN_USAGE WHERE CONSTRAINT_NAME = 'FK_SecurityPatchUninstallValues_SecurityPatch')
		BEGIN ALTER TABLE SecurityPatchUninstallValues DROP CONSTRAINT FK_SecurityPatchUninstallValues_SecurityPatch END
	IF EXISTS (SELECT * FROM INFORMATION_SCHEMA.CONSTRAINT_COLUMN_USAGE WHERE CONSTRAINT_NAME = 'FK_SecurityPatchResource_SecurityPatchID')
		BEGIN ALTER TABLE SecurityPatchResource DROP CONSTRAINT FK_SecurityPatchResource_SecurityPatchID END
	IF EXISTS (SELECT * FROM INFORMATION_SCHEMA.CONSTRAINT_COLUMN_USAGE WHERE CONSTRAINT_NAME = 'UQ_SecurityPatch')
		BEGIN ALTER TABLE SecurityPatch DROP CONSTRAINT UQ_SecurityPatch END
	IF EXISTS (SELECT * FROM INFORMATION_SCHEMA.CONSTRAINT_COLUMN_USAGE WHERE CONSTRAINT_NAME = 'PK_SecurityPatch')
		BEGIN ALTER TABLE SecurityPatch DROP CONSTRAINT PK_SecurityPatch END
	
	-- Modify LanguageID column
	DECLARE @defaultname nvarchar(128)
	SELECT @defaultname=name FROM dbo.sysobjects
	WHERE id IN
	(
		SELECT cdefault from dbo.syscolumns 
		WHERE 	id = object_id(N'[dbo].[SecurityPatch]') 
		AND	name = 'LanguageID'
	)
	DECLARE @command nvarchar(128)
	SELECT @command = 'ALTER TABLE SecurityPatch DROP CONSTRAINT ' + @defaultname
	FROM SecurityPatch
	exec (@command)
	ALTER TABLE SecurityPatch DROP COLUMN LanguageID 
	ALTER TABLE SecurityPatch ADD LanguageID nvarchar(6) NOT NULL DEFAULT 'eng'
	
	-- add the constraints back in 
	ALTER TABLE SecurityPatch ADD CONSTRAINT PK_SecurityPatch 
			PRIMARY KEY NONCLUSTERED(PatchID)
	ALTER TABLE SecurityPatch ADD CONSTRAINT UQ_SecurityPatch
			UNIQUE NONCLUSTERED(BulletinID, PatchName)
	ALTER TABLE SecurityPatchRequires ADD CONSTRAINT FK_SecurityPatchRequires_SecurityPatch
			FOREIGN KEY(PatchID) REFERENCES SecurityPatch(PatchID)
	ALTER TABLE SecurityPatchRequires ADD CONSTRAINT FK_SecurityPatchRequires2_SecurityPatch
			FOREIGN KEY(RequiredPatchID) REFERENCES SecurityPatch(PatchID)
	ALTER TABLE SecurityPatchToPackageVersion ADD CONSTRAINT FK_SecurityPatchToPackageVersion_SecurityPatch
			FOREIGN KEY(PatchID) REFERENCES SecurityPatch(PatchID)
	ALTER TABLE SecurityPatchAnalysis ADD CONSTRAINT FK_SecurityPatchAnalysis_SecutityPatch
			FOREIGN KEY(SecurityPatchID) REFERENCES SecurityPatch(PatchID)
	ALTER TABLE SecurityPatchUninstallValues ADD CONSTRAINT FK_SecurityPatchUninstallValues_SecurityPatch
			FOREIGN KEY(SecurityPatchID) REFERENCES SecurityPatch(PatchID)
	ALTER TABLE SecurityPatchResource ADD CONSTRAINT FK_SecurityPatchResource_SecurityPatchID
			FOREIGN KEY(SecurityPatchID) REFERENCES SecurityPatch(PatchID)
	ALTER TABLE SecPatch_Patch ADD CONSTRAINT FK_Patch_SecurityPatch
			FOREIGN KEY(SecurityPatchID) REFERENCES SecurityPatch(PatchID)

END
GO

PRINT 'Populate LanguageID column to SecurityPatch'
IF EXISTS (
	SELECT *
	FROM INFORMATION_SCHEMA.TABLES
	WHERE TABLE_NAME = 'SecurityPatch'
)
BEGIN
	-- Update language column
	UPDATE SecurityPatch
	SET LanguageID = 'eng'
END
GO

PRINT 'Add Locale table constraint to SecurityPatch'
IF EXISTS (
	SELECT *
	FROM INFORMATION_SCHEMA.TABLES
	WHERE TABLE_NAME = 'SecurityPatch'
)
BEGIN
	-- Add Locale constraint
	ALTER TABLE SecurityPatch WITH CHECK ADD
		CONSTRAINT FK_SecurityPatch_Language
		FOREIGN KEY(LanguageID)
		REFERENCES Locale(LocaleCode)
END
GO

PRINT 'Add Ignore column to SecurityPatch'
IF EXISTS (
	SELECT *
	FROM INFORMATION_SCHEMA.TABLES
	WHERE TABLE_NAME = 'SecurityPatch'
)
BEGIN
	-- Add Hidden column
	ALTER TABLE SecurityPatch ADD Ignore int NOT NULL DEFAULT 0
END

GO

--===========================================================================
--		Alter the SecurityBulletin table
--===========================================================================
PRINT 'Add Ignore column to SecurityBulletin'
IF EXISTS (
	SELECT *
	FROM INFORMATION_SCHEMA.TABLES
	WHERE TABLE_NAME = 'SecurityBulletin'
)
BEGIN
	-- Add Hidden column
	ALTER TABLE SecurityBulletin ADD Ignore int NOT NULL DEFAULT 0
END

GO

--===========================================================================
--		Alter the SecurityPatchResource table
--===========================================================================

PRINT 'Modify LanguageID column on SecurityPatchResource'
IF EXISTS (
	SELECT *
	FROM INFORMATION_SCHEMA.TABLES
	WHERE TABLE_NAME = 'SecurityPatchResource'
)
BEGIN
	-- drop constraints
	IF EXISTS (SELECT * FROM INFORMATION_SCHEMA.CONSTRAINT_COLUMN_USAGE WHERE CONSTRAINT_NAME = 'FK_SecurityPatchResource_Architecture')
		BEGIN ALTER TABLE SecurityPatchResource DROP CONSTRAINT FK_SecurityPatchResource_Architecture END
	IF EXISTS (SELECT * FROM INFORMATION_SCHEMA.CONSTRAINT_COLUMN_USAGE WHERE CONSTRAINT_NAME = 'FK_SecurityPatchResourceProduct_SecurityPatchResource')
		BEGIN ALTER TABLE SecurityPatchResourceProduct DROP CONSTRAINT FK_SecurityPatchResourceProduct_SecurityPatchResource END
	IF EXISTS (SELECT * FROM INFORMATION_SCHEMA.CONSTRAINT_COLUMN_USAGE WHERE CONSTRAINT_NAME = 'FK_SecurityPatchResource_SecurityPatchID')
		BEGIN ALTER TABLE SecurityPatchResource DROP CONSTRAINT FK_SecurityPatchResource_SecurityPatchID END
	IF EXISTS (SELECT * FROM INFORMATION_SCHEMA.CONSTRAINT_COLUMN_USAGE WHERE CONSTRAINT_NAME = 'PQ_SecurityPatchResource')
		BEGIN ALTER TABLE SecurityPatchResource DROP CONSTRAINT PQ_SecurityPatchResource END
	IF EXISTS (SELECT * FROM INFORMATION_SCHEMA.CONSTRAINT_COLUMN_USAGE WHERE CONSTRAINT_NAME = 'UQ_SecurityPatchResource')
		BEGIN ALTER TABLE SecurityPatchResource DROP CONSTRAINT UQ_SecurityPatchResource END

	-- Modify LanguageID column
	DECLARE @defname nvarchar(128)
	SELECT @defname=name FROM dbo.sysobjects
	WHERE id IN
	(
		SELECT cdefault from dbo.syscolumns 
		WHERE 	id = object_id(N'[dbo].[SecurityPatchResource]') 
		AND	name = 'LanguageID'
	)
	DECLARE @command nvarchar(128)
	SELECT @command = 'ALTER TABLE SecurityPatchResource DROP CONSTRAINT ' + @defname
	FROM SecurityPatchResource
	exec (@command)
	ALTER TABLE SecurityPatchResource ALTER COLUMN LanguageID nvarchar(6) NOT NULL 
	ALTER TABLE SecurityPatchResource ADD CONSTRAINT DF_LANG_DEFAULT DEFAULT 'eng' FOR LanguageID 
	
	-- add all the constraints back in again
	ALTER TABLE SecurityPatchResource ADD CONSTRAINT FK_SecurityPatchResource_SecurityPatchID
			FOREIGN KEY(SecurityPatchID) REFERENCES SecurityPatch(PatchID)
	ALTER TABLE SecurityPatchResource ADD CONSTRAINT PQ_SecurityPatchResource
			PRIMARY KEY NONCLUSTERED (SecurityPatchID, ResourceURL, ArchitectureID, LanguageID)
	ALTER TABLE SecurityPatchResource ADD CONSTRAINT UQ_SecurityPatchResource
			UNIQUE NONCLUSTERED(SecurityPatchResourceID)
	ALTER TABLE SecurityPatchResource ADD CONSTRAINT FK_SecurityPatchResource_Architecture
			FOREIGN KEY(ArchitectureID) REFERENCES Architecture(ArchitectureID)
	ALTER TABLE SecurityPatchResourceProduct ADD CONSTRAINT FK_SecurityPatchResourceProduct_SecurityPatchResource
			FOREIGN KEY(SecurityPatchResourceID)REFERENCES SecurityPatchResource(SecurityPatchResourceID)
END
GO

PRINT 'Add Incorporate column on SecurityPatchResource'
IF EXISTS (
	SELECT *
	FROM INFORMATION_SCHEMA.TABLES
	WHERE TABLE_NAME = 'SecurityPatchResource'
)
BEGIN
	-- Modify LanguageID column
	ALTER TABLE SecurityPatchResource ADD Incorporate bit NOT NULL DEFAULT 1
	ALTER TABLE SecurityPatchResource ADD BulletinID nvarchar(32) NOT NULL DEFAULT ''	
	ALTER TABLE SecurityPatchResource ADD ResourcePatchName nvarchar(128) COLLATE Latin1_General_CS_AS NULL	

END
GO

PRINT 'Populate LanguageID column to SecurityPatchResource'
IF EXISTS (
	SELECT *
	FROM INFORMATION_SCHEMA.TABLES
	WHERE TABLE_NAME = 'SecurityPatchResource'
)
BEGIN
	-- Update language column
	UPDATE SecurityPatchResource
	SET LanguageID = 'eng'
END
GO

PRINT 'Add Locale table constraint to SecurityPatchResource'
IF EXISTS (
	SELECT *
	FROM INFORMATION_SCHEMA.TABLES
	WHERE TABLE_NAME = 'SecurityPatchResource'
)
BEGIN
	-- Add Locale constraint
	ALTER TABLE SecurityPatchResource WITH CHECK ADD
		CONSTRAINT FK_SecurityPatchResource_Locale
		FOREIGN KEY(LanguageID)
		REFERENCES Locale(LocaleCode)
END
GO

