/*
 * $Id: spm-migprep77.sql 101389 2011-11-25 01:51:25Z rlowery $
 *
 * Prepare to migrate a SPM 7.6 database into SM 7.7 format.
 *
 * Use this first, then schema.sql, then migpost.sql, AND finally
 * install SM 7.7 which will create the stored procedures.
 *
 * The aim here is to make minimal changes that will allow schema.sql
 * to succeed in creating any new objects, before migpost.sql finishes
 * reshaping some tables AND dropping any unused objects.
 *
 * Copyright 2011 Flexera Software LLC
 */
 
USE ManageSoft
GO

-----------------------------------------------------------------------------
-- Update the definition of the SecPatch_Product table
-----------------------------------------------------------------------------

IF EXISTS(
	SELECT * FROM INFORMATION_SCHEMA.TABLES
	WHERE TABLE_NAME = 'SecPatch_Product'
)
BEGIN
	-- Clean up duplicate data
	DELETE	spap
	FROM	SecPatch_AffectedProduct spap
			INNER JOIN SecPatch_Product sp ON sp.ProductID = spap.ProductID
	WHERE	EXISTS(	SELECT	1
					FROM	SecPatch_AffectedProduct spap2
							INNER JOIN SecPatch_Product sp2 ON sp2.ProductID = spap2.ProductID
					WHERE	sp2.[Name] = sp.[Name]
							AND spap2.PatchID = spap.PatchID
							AND spap2.ProductID < spap.ProductID
			)

	UPDATE	SecPatch_AffectedProduct 
	SET		ProductID = (
						SELECT	MIN(spp2.ProductID)
						FROM	SecPatch_Product spp1
							INNER JOIN SecPatch_Product spp2 ON spp2.[Name] = spp1.[Name]
						WHERE	spp1.ProductID = SecPatch_AffectedProduct.ProductID
			)

	DELETE	spppf
	FROM	SecPatch_ProductProductFamily spppf
			INNER JOIN SecPatch_Product spp ON spp.ProductID = spppf.ProductID
	WHERE	EXISTS(	SELECT	1
					FROM	SecPatch_Product spp2
					WHERE	spp2.[Name] = spp.[Name]
							AND spp2.ProductID < spp.ProductID
			)

	DELETE	spp
	FROM	SecPatch_Product spp
	WHERE	EXISTS(	SELECT	1
					FROM	SecPatch_Product spp2
					WHERE	spp2.[Name] = spp.[Name]
							AND spp2.ProductID < spp.ProductID
			)

	-- Copy data to a temporary table
	IF OBJECT_ID('tempdb..#SecPatch_Product') IS NULL
	BEGIN
		CREATE TABLE #SecPatch_Product (
			ProductID		int NOT NULL,
			[Name]			nvarchar(80) NOT NULL,
			MinimumSupportedServicePackID int NULL,
			CurrentServicePackID	int NULL,
			CurrentVersion		nvarchar(50) NULL
		)
	END
	ELSE
	BEGIN
		DELETE FROM #SecPatch_Product
	END

	INSERT #SecPatch_Product (
		ProductID,
		[Name],
		MinimumSupportedServicePackID,
		CurrentServicePackID,
		CurrentVersion
	)
		SELECT	ProductID,
			[Name],
			MinimumSupportedServicePackID,
			CurrentServicePackID,
			CurrentVersion
		FROM SecPatch_Product

	-- Drop the constraints
	IF EXISTS (
		SELECT *
		FROM INFORMATION_SCHEMA.CONSTRAINT_COLUMN_USAGE
		WHERE CONSTRAINT_NAME = 'FK_AffectedProduct_Product'
	)
	BEGIN
		ALTER TABLE SecPatch_AffectedProduct
			DROP CONSTRAINT FK_AffectedProduct_Product
	END

	IF EXISTS (
		SELECT *
		FROM INFORMATION_SCHEMA.CONSTRAINT_COLUMN_USAGE
		WHERE CONSTRAINT_NAME = 'FK_ProductProductFamily_Product'
	)
	BEGIN
		ALTER TABLE SecPatch_ProductProductFamily
			DROP CONSTRAINT FK_ProductProductFamily_Product
	END

	IF EXISTS (
		SELECT *
		FROM INFORMATION_SCHEMA.CONSTRAINT_COLUMN_USAGE
		WHERE CONSTRAINT_NAME = 'PK_Product'
	)
	BEGIN
		ALTER TABLE SecPatch_Product
			DROP CONSTRAINT PK_Product
	END

	-- Drop the table
	DROP TABLE SecPatch_Product

	-- Re-create the table
	CREATE TABLE SecPatch_Product (
		-- Primary key.
		ProductID		int IDENTITY NOT NULL,
		-- Name of this product.
		[Name]			nvarchar(80) NOT NULL,
		-- The least recent service pack that is supported for this product.
		MinimumSupportedServicePackID int NULL,
		-- The most recently released service pack for this product.
		CurrentServicePackID	int NULL,
		-- The most recently released version of this product.
		CurrentVersion		nvarchar(50) NULL,
		CONSTRAINT PK_Product
			PRIMARY KEY NONCLUSTERED([Name]),
		CONSTRAINT UQ_Product
			UNIQUE NONCLUSTERED(ProductID)
	);

	-- Copy the data back across
	SET IDENTITY_INSERT SecPatch_Product ON
	INSERT SecPatch_Product (
		ProductID,
		[Name],
		MinimumSupportedServicePackID,
		CurrentServicePackID,
		CurrentVersion
	)
		SELECT	ProductID,
			[Name],
			MinimumSupportedServicePackID,
			CurrentServicePackID,
			CurrentVersion
		FROM #SecPatch_Product
	SET IDENTITY_INSERT SecPatch_Product OFF

	DROP TABLE #SecPatch_Product	-- Drop temporary table

	-- Add the constraints
	ALTER TABLE SecPatch_AffectedProduct
		ADD CONSTRAINT FK_AffectedProduct_Product
		FOREIGN KEY(ProductID)
		REFERENCES SecPatch_Product(ProductID) ON DELETE CASCADE
	ALTER TABLE SecPatch_ProductProductFamily
		ADD CONSTRAINT FK_ProductProductFamily_Product
		FOREIGN KEY(ProductID)
		REFERENCES SecPatch_Product(ProductID) ON DELETE CASCADE

END
GO

-----------------------------------------------------------------------------
-- Update the definition of the SecurityPatchSupersede table
-----------------------------------------------------------------------------
IF EXISTS(
	SELECT * FROM INFORMATION_SCHEMA.TABLES
	WHERE TABLE_NAME = 'SecPatch_SupercededPatch'
)
BEGIN
	IF NOT EXISTS (
		SELECT * FROM INFORMATION_SCHEMA.TABLES
		WHERE TABLE_NAME = 'SecurityPatchSupersede'
	)
	BEGIN
		CREATE TABLE SecurityPatchSupersede (
			-- Foreign key for security patch that superseds another patch.
			NewSecurityPatchID	int NOT NULL,
			-- Foreign key for security patch that has been superseded.
			OldSecurityPatchID	int NOT NULL,
			CONSTRAINT PK_SecurityPatchSupersede
				PRIMARY KEY NONCLUSTERED(NewSecurityPatchID, OldSecurityPatchID)
		);
	END

	IF NOT EXISTS (
		SELECT *
		FROM sysindexes
		WHERE [Name] = 'SecurityPatchSupersedeByOldSecurityPatch'
	)
	BEGIN
		CREATE NONCLUSTERED INDEX SecurityPatchSupersedeByOldSecurityPatch
			ON SecurityPatchSupersede(OldSecurityPatchID)
	END

	INSERT INTO SecurityPatchSupersede
		SELECT	spp.SecurityPatchID AS OldPatchID, spp2.NewPatchID
		FROM	SecPatch_Patch AS spp,
			SecPatch_SupercededPatch AS spsp,
			(
				SELECT	spp.SBID, spp.SecurityPatchID AS NewPatchID
				FROM	SecPatch_Patch AS spp
				WHERE	spp.SBID IS NOT NULL
			) AS spp2
		WHERE	spp2.SBID = spsp.SupercededByID
		  AND	spsp.BulletinID = spp.BulletinID
		  AND	spsp.PatchName = spp.PatchName

	IF EXISTS (
		SELECT *
		FROM INFORMATION_SCHEMA.CONSTRAINT_COLUMN_USAGE
		WHERE CONSTRAINT_NAME = 'FK_Patch_SupercededBy'
	)
	BEGIN
		ALTER TABLE SecPatch_Patch
			DROP CONSTRAINT FK_Patch_SupercededBy
	END

	IF EXISTS (
		SELECT *
		FROM INFORMATION_SCHEMA.CONSTRAINT_COLUMN_USAGE
		WHERE CONSTRAINT_NAME = 'FK_SupercededPatch_Bulletin'
	)
	BEGIN
		ALTER TABLE SecPatch_SupercededPatch
			DROP CONSTRAINT FK_SupercededPatch_Bulletin
	END

	IF EXISTS (
		SELECT *
		FROM INFORMATION_SCHEMA.CONSTRAINT_COLUMN_USAGE
		WHERE CONSTRAINT_NAME = 'FK_SupercededPatch_SupercededBy'
	)
	BEGIN
		ALTER TABLE SecPatch_SupercededPatch
			DROP CONSTRAINT FK_SupercededPatch_SupercededBy
	END

	DROP TABLE SecPatch_SupercededBy

	DROP TABLE SecPatch_SupercededPatch
END
GO


-----------------------------------------------------------------------------
-- Update the definition of the SecPatch_Patch table
-----------------------------------------------------------------------------
IF EXISTS(
	SELECT * FROM INFORMATION_SCHEMA.TABLES
	WHERE TABLE_NAME = 'SecPatch_Patch'
)
BEGIN
	ALTER TABLE SecPatch_Patch
		DROP COLUMN SBID
END
GO

-----------------------------------------------------------------------------
-- Update the definition of the SecPatch_Bulletin table
-----------------------------------------------------------------------------
IF EXISTS(
	SELECT * FROM INFORMATION_SCHEMA.TABLES
	WHERE TABLE_NAME = 'SecPatch_Bulletin'
)
BEGIN
	ALTER TABLE SecPatch_Bulletin
		ALTER COLUMN Summary ntext NULL

	IF EXISTS (
		SELECT *
		FROM INFORMATION_SCHEMA.CONSTRAINT_COLUMN_USAGE
		WHERE CONSTRAINT_NAME = 'FK_Bulletin_Severity'
	)
	BEGIN
		ALTER TABLE SecPatch_Bulletin
			DROP CONSTRAINT FK_Bulletin_Severity
	END

	IF EXISTS (
		SELECT *
		FROM INFORMATION_SCHEMA.CONSTRAINT_COLUMN_USAGE
		WHERE CONSTRAINT_NAME = 'FK_Bulletin_Severity1'
	)
	BEGIN
		ALTER TABLE SecPatch_Bulletin
			DROP CONSTRAINT FK_Bulletin_Severity1
	END

	IF EXISTS (
		SELECT *
		FROM INFORMATION_SCHEMA.CONSTRAINT_COLUMN_USAGE
		WHERE CONSTRAINT_NAME = 'FK_Bulletin_Severity2'
	)
	BEGIN
		ALTER TABLE SecPatch_Bulletin
			DROP CONSTRAINT FK_Bulletin_Severity2
	END

	IF EXISTS (
		SELECT *
		FROM INFORMATION_SCHEMA.CONSTRAINT_COLUMN_USAGE
		WHERE CONSTRAINT_NAME = 'FK_Bulletin_Severity3'
	)
	BEGIN
		ALTER TABLE SecPatch_Bulletin
			DROP CONSTRAINT FK_Bulletin_Severity3
	END
END
GO

-----------------------------------------------------------------------------
-- Update the definition of the SecurityBulletin table
-----------------------------------------------------------------------------
IF EXISTS(
	SELECT * FROM INFORMATION_SCHEMA.TABLES
	WHERE TABLE_NAME = 'SecurityBulletin'
)
BEGIN
	IF NOT EXISTS (
		SELECT *
		FROM sysindexes
		WHERE [Name] = 'SecurityBulletinByErrata'
	)
	BEGIN
		CREATE NONCLUSTERED INDEX SecurityBulletinByErrata
			ON SecurityBulletin(Errata)
	END
END
GO

-----------------------------------------------------------------------------
-- Update the definition of the SecurityPatch table
-----------------------------------------------------------------------------
IF EXISTS(
	SELECT * FROM INFORMATION_SCHEMA.TABLES
	WHERE TABLE_NAME = 'SecurityPatch'
)
BEGIN
	DECLARE @Default nvarchar(300)
	DECLARE @alterSQL nvarchar(3000)

	SELECT @Default = so1.[name] FROM sysobjects AS so1 WHERE so1.[id] IN (
		SELECT constid FROM sysconstraints AS sc WHERE colid IN (
			SELECT colid FROM syscolumns WHERE [id] IN (
				SELECT [id] FROM sysobjects AS so2 WHERE so2.[name] = 'SecurityPatch'
			)
			  AND	[name] = 'Downloading'
		)
		  AND	sc.[id] IN (
			SELECT [id] FROM sysobjects AS so3 WHERE so3.[name] = 'SecurityPatch'
		)
	)
	  AND so1.xtype = 'D'

	SET @alterSQL = 'ALTER TABLE SecurityPatch DROP CONSTRAINT ' + @Default
	EXEC sp_executesql @alterSQL

	SELECT @Default = so1.[name] FROM sysobjects AS so1 WHERE so1.[id] IN (
		SELECT constid FROM sysconstraints AS sc WHERE colid IN (
			SELECT colid FROM syscolumns WHERE [id] IN (
				SELECT [id] FROM sysobjects AS so2 WHERE so2.[name] = 'SecurityPatch'
			)
			  AND	[name] = 'LanguageID'
		)
		  AND	sc.[id] IN (
			SELECT [id] FROM sysobjects AS so3 WHERE so3.[name] = 'SecurityPatch'
		)
	)
	  AND so1.xtype = 'D'

	SET @alterSQL = 'ALTER TABLE SecurityPatch DROP CONSTRAINT ' + @Default
	EXEC sp_executesql @alterSQL

	IF EXISTS (
		SELECT *
		FROM INFORMATION_SCHEMA.CONSTRAINT_COLUMN_USAGE
		WHERE CONSTRAINT_NAME = 'FK_SecurityPatch_Locale'
	)
	BEGIN
		ALTER TABLE SecurityPatch
			DROP CONSTRAINT FK_SecurityPatch_Locale
	END
	IF EXISTS (
		SELECT *
		FROM INFORMATION_SCHEMA.CONSTRAINT_COLUMN_USAGE
		WHERE CONSTRAINT_NAME = 'FK_SecurityPatch_Language'
	)
	BEGIN
		ALTER TABLE SecurityPatch
			DROP CONSTRAINT FK_SecurityPatch_Language
	END
	ALTER TABLE SecurityPatch
		DROP COLUMN DownloadLocation
	ALTER TABLE SecurityPatch
		DROP COLUMN Downloading
	ALTER TABLE SecurityPatch
		DROP COLUMN ActualDownloadLocation
	ALTER TABLE SecurityPatch
		DROP COLUMN LanguageID

	ALTER TABLE SecurityPatch
		ADD Title nvarchar(256) NULL
END
GO

-----------------------------------------------------------------------------
-- Populate the Title column AND update it's definition to not allow NULL
-----------------------------------------------------------------------------
IF EXISTS(
	SELECT * FROM INFORMATION_SCHEMA.TABLES
	WHERE TABLE_NAME = 'SecurityPatch'
)
BEGIN
	UPDATE SecurityPatch SET Title = PatchName

	ALTER TABLE SecurityPatch
		ALTER COLUMN Title nvarchar(256) NOT NULL
END
GO

-----------------------------------------------------------------------------
-- Update the definition of the SecurityPatchToPackageVersion table
-----------------------------------------------------------------------------
IF EXISTS(
	SELECT * FROM INFORMATION_SCHEMA.TABLES
	WHERE TABLE_NAME = 'SecurityPatchToPackageVersion'
)
BEGIN
	IF EXISTS (
		SELECT *
		FROM INFORMATION_SCHEMA.CONSTRAINT_COLUMN_USAGE
		WHERE CONSTRAINT_NAME = 'PK_SecurityPatchToPackageVersion'
	)
	BEGIN
		ALTER TABLE SecurityPatchToPackageVersion
			DROP CONSTRAINT PK_SecurityPatchToPackageVersion
	END
	ALTER TABLE SecurityPatchToPackageVersion
		ADD CONSTRAINT PK_SecurityPatchToPackageVersion
		PRIMARY KEY CLUSTERED(PatchID)

	IF EXISTS (
		SELECT *
		FROM sysindexes
		WHERE [Name] = 'SecurityPatchToPackageVersionByPatchID'
	)
	BEGIN
		DROP INDEX SecurityPatchToPackageVersion.SecurityPatchToPackageVersionByPatchID
	END
END
GO

-----------------------------------------------------------------------------
-- Update the definition of the SecurityUserStateChange table
-----------------------------------------------------------------------------
IF EXISTS(
	SELECT * FROM INFORMATION_SCHEMA.TABLES
	WHERE TABLE_NAME = 'SecurityUserStateChange'
)
BEGIN
	IF EXISTS (
		SELECT *
		FROM INFORMATION_SCHEMA.CONSTRAINT_COLUMN_USAGE
		WHERE CONSTRAINT_NAME = 'FK_SecurityUserStateChange_SecurityState'
	)
	BEGIN
		ALTER TABLE SecurityUserStateChange
			DROP CONSTRAINT FK_SecurityUserStateChange_SecurityState
	END
	ALTER TABLE SecurityUserStateChange
		ADD CONSTRAINT FK_SecurityUserStateChange_SecurityState
		FOREIGN KEY(UserStateID)
		REFERENCES SecurityUserState(UserStateID) ON DELETE NO ACTION
END
GO

-----------------------------------------------------------------------------
-- Update the definition of the SecurityPatchResource table
-----------------------------------------------------------------------------
IF EXISTS(
	SELECT * FROM INFORMATION_SCHEMA.TABLES
	WHERE TABLE_NAME = 'SecurityPatchResource'
)
BEGIN
	IF EXISTS (
		SELECT *
		FROM sysindexes
		WHERE [Name] = 'SecurityPatchResourceByBulletinID'
	)
	BEGIN
		DROP INDEX SecurityPatchResource.SecurityPatchResourceByBulletinID
	END

	ALTER TABLE SecurityPatchResource
		DROP COLUMN ResourcePatchName

	IF NOT EXISTS (
		SELECT *
		FROM sysindexes
		WHERE [Name] = 'SecurityPatchResourceByBulletinID'
	)
	BEGIN
		CREATE NONCLUSTERED INDEX SecurityPatchResourceByBulletinID
			ON SecurityPatchResource(BulletinID)
	END
END
GO

-----------------------------------------------------------------------------
-- Update the definition of the SecurityPatchLanguage table
-----------------------------------------------------------------------------
IF EXISTS(
	SELECT * FROM INFORMATION_SCHEMA.TABLES
	WHERE TABLE_NAME = 'SecurityPatchLanguage'
)
BEGIN
	IF NOT EXISTS (
		SELECT *
		FROM sysindexes
		WHERE [Name] = 'SecurityPatchLanguageBySelected'
	)
	BEGIN
		CREATE NONCLUSTERED INDEX SecurityPatchLanguageBySelected
			ON SecurityPatchLanguage(Selected)
	END
END
GO

-----------------------------------------------------------------------------
-- Update the definition of the SecurityPatchArchitecture table
-----------------------------------------------------------------------------
IF EXISTS(
	SELECT * FROM INFORMATION_SCHEMA.TABLES
	WHERE TABLE_NAME = 'SecurityPatchArchitecture'
)
BEGIN
	IF NOT EXISTS (
		SELECT *
		FROM sysindexes
		WHERE [Name] = 'SecurityPatchArchitectureBySelected'
	)
	BEGIN
		CREATE NONCLUSTERED INDEX SecurityPatchArchitectureBySelected
			ON SecurityPatchArchitecture(Selected)
	END
END
GO

-----------------------------------------------------------------------------
-- Update the definition of the SecurityBulletinToUserState table
-----------------------------------------------------------------------------
IF EXISTS(
	SELECT * FROM INFORMATION_SCHEMA.TABLES
	WHERE TABLE_NAME = 'SecurityBulletinToUserState'
)
BEGIN
	IF EXISTS (
		SELECT *
		FROM INFORMATION_SCHEMA.CONSTRAINT_COLUMN_USAGE
		WHERE CONSTRAINT_NAME = 'FK_SecurityBulletinToUserState_SecurityUserState'
	)
	BEGIN
		ALTER TABLE SecurityBulletinToUserState
			DROP CONSTRAINT FK_SecurityBulletinToUserState_SecurityUserState
	END
	ALTER TABLE SecurityBulletinToUserState
		ADD CONSTRAINT FK_SecurityBulletinToUserState_SecurityUserState
		FOREIGN KEY(UserStateID)
		REFERENCES SecurityUserState(UserStateID) ON DELETE NO ACTION
END
GO

-----------------------------------------------------------------------------
-- Update the definition of the SecurityPatchAnalysis table
-----------------------------------------------------------------------------
IF EXISTS(
	SELECT * FROM INFORMATION_SCHEMA.TABLES
	WHERE TABLE_NAME = 'SecurityPatchAnalysis'
)
BEGIN
	IF EXISTS (
		SELECT *
		FROM INFORMATION_SCHEMA.CONSTRAINT_COLUMN_USAGE
		WHERE CONSTRAINT_NAME = 'FK_SecurityPatchAnalysis_SecutityPatchStatus'
	)
	BEGIN
		ALTER TABLE SecurityPatchAnalysis
			DROP CONSTRAINT FK_SecurityPatchAnalysis_SecutityPatchStatus
	END
	ALTER TABLE SecurityPatchAnalysis
		ADD CONSTRAINT FK_SecurityPatchAnalysis_SecutityPatchStatus
		FOREIGN KEY(Status)
		REFERENCES SecurityPatchStatus(SecurityPatchStatusID) ON DELETE NO ACTION
END
GO

-----------------------------------------------------------------------------
-- Update the definition of the SecurityState table
-----------------------------------------------------------------------------
IF EXISTS(
	SELECT * FROM INFORMATION_SCHEMA.TABLES
	WHERE TABLE_NAME = 'SecurityState'
)
BEGIN
	IF NOT EXISTS (
		SELECT *
		FROM INFORMATION_SCHEMA.CONSTRAINT_COLUMN_USAGE
		WHERE CONSTRAINT_NAME = 'UQ_SecurityStateByDescription'
	)
	BEGIN
		ALTER TABLE SecurityState
			ADD CONSTRAINT UQ_SecurityStateByDescription
				UNIQUE NONCLUSTERED(Description)
	END
END
GO

-----------------------------------------------------------------------------
-- Update the definition of the SecurityUIState table
-----------------------------------------------------------------------------
IF EXISTS(
	SELECT * FROM INFORMATION_SCHEMA.TABLES
	WHERE TABLE_NAME = 'SecurityUIState'
)
BEGIN
	IF NOT EXISTS (
		SELECT *
		FROM INFORMATION_SCHEMA.CONSTRAINT_COLUMN_USAGE
		WHERE CONSTRAINT_NAME = 'UQ_SecurityUIStateByDescription'
	)
	BEGIN
		ALTER TABLE SecurityUIState
			ADD CONSTRAINT UQ_SecurityUIStateByDescription
				UNIQUE NONCLUSTERED(Description)
	END
END
GO

-----------------------------------------------------------------------------
-- Update the definition of the SecurityBulletinChangeType table
-----------------------------------------------------------------------------
IF EXISTS(
	SELECT * FROM INFORMATION_SCHEMA.TABLES
	WHERE TABLE_NAME = 'SecurityBulletinChangeType'
)
BEGIN
	IF NOT EXISTS (
		SELECT *
		FROM INFORMATION_SCHEMA.CONSTRAINT_COLUMN_USAGE
		WHERE CONSTRAINT_NAME = 'UQ_SecurityBulletinChangeTypeByDescription'
	)
	BEGIN
		ALTER TABLE SecurityBulletinChangeType
			ADD CONSTRAINT UQ_SecurityBulletinChangeTypeByDescription
				UNIQUE NONCLUSTERED(Description)
	END
END
GO

-----------------------------------------------------------------------------
-- Drop obsolete stored procedures
-----------------------------------------------------------------------------
IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = object_id(N'[dbo].[SecPatch_ProductGetByProductID]') AND OBJECTPROPERTY(id, N'IsProcedure') = 1)
DROP PROCEDURE [dbo].[SecPatch_ProductGetByProductID]
GO

IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = object_id(N'[dbo].[SecPatch_ProductPutBatchByProductID]') AND OBJECTPROPERTY(id, N'IsProcedure') = 1)
DROP PROCEDURE [dbo].[SecPatch_ProductPutBatchByProductID]
GO

IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = object_id(N'[dbo].[SecPatch_ProductPutByProductID]') AND OBJECTPROPERTY(id, N'IsProcedure') = 1)
DROP PROCEDURE [dbo].[SecPatch_ProductPutByProductID]
GO

IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = object_id(N'[dbo].[SecPatch_ProductUpdateBatchByProductID]') AND OBJECTPROPERTY(id, N'IsProcedure') = 1)
DROP PROCEDURE [dbo].[SecPatch_ProductUpdateBatchByProductID]
GO

IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = object_id(N'[dbo].[SecPatch_ProductUpdateByProductID]') AND OBJECTPROPERTY(id, N'IsProcedure') = 1)
DROP PROCEDURE [dbo].[SecPatch_ProductUpdateByProductID]
GO

IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = object_id(N'[dbo].[SecPatch_SupercededByAdd]') AND OBJECTPROPERTY(id, N'IsProcedure') = 1)
DROP PROCEDURE [dbo].[SecPatch_SupercededByAdd]
GO

IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = object_id(N'[dbo].[SecPatch_SupercededByAddBatch]') AND OBJECTPROPERTY(id, N'IsProcedure') = 1)
DROP PROCEDURE [dbo].[SecPatch_SupercededByAddBatch]
GO

IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = object_id(N'[dbo].[SecPatch_SupercededByGetAll]') AND OBJECTPROPERTY(id, N'IsProcedure') = 1)
DROP PROCEDURE [dbo].[SecPatch_SupercededByGetAll]
GO

IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = object_id(N'[dbo].[SecPatch_SupercededByGetBySBID]') AND OBJECTPROPERTY(id, N'IsProcedure') = 1)
DROP PROCEDURE [dbo].[SecPatch_SupercededByGetBySBID]
GO

IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = object_id(N'[dbo].[SecPatch_SupercededByPutBatchBySBID]') AND OBJECTPROPERTY(id, N'IsProcedure') = 1)
DROP PROCEDURE [dbo].[SecPatch_SupercededByPutBatchBySBID]
GO

IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = object_id(N'[dbo].[SecPatch_SupercededByPutBySBID]') AND OBJECTPROPERTY(id, N'IsProcedure') = 1)
DROP PROCEDURE [dbo].[SecPatch_SupercededByPutBySBID]
GO

IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = object_id(N'[dbo].[SecPatch_SupercededByRemoveAll]') AND OBJECTPROPERTY(id, N'IsProcedure') = 1)
DROP PROCEDURE [dbo].[SecPatch_SupercededByRemoveAll]
GO

IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = object_id(N'[dbo].[SecPatch_SupercededBySchema]') AND OBJECTPROPERTY(id, N'IsProcedure') = 1)
DROP PROCEDURE [dbo].[SecPatch_SupercededBySchema]
GO

IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = object_id(N'[dbo].[SecPatch_SupercededByTempAdd]') AND OBJECTPROPERTY(id, N'IsProcedure') = 1)
DROP PROCEDURE [dbo].[SecPatch_SupercededByTempAdd]
GO

IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = object_id(N'[dbo].[SecPatch_SupercededByUpdateBatchBySBID]') AND OBJECTPROPERTY(id, N'IsProcedure') = 1)
DROP PROCEDURE [dbo].[SecPatch_SupercededByUpdateBatchBySBID]
GO

IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = object_id(N'[dbo].[SecPatch_SupercededByUpdateBySBID]') AND OBJECTPROPERTY(id, N'IsProcedure') = 1)
DROP PROCEDURE [dbo].[SecPatch_SupercededByUpdateBySBID]
GO

IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = object_id(N'[dbo].[SecPatch_SupercededPatchAdd]') AND OBJECTPROPERTY(id, N'IsProcedure') = 1)
DROP PROCEDURE [dbo].[SecPatch_SupercededPatchAdd]
GO

IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = object_id(N'[dbo].[SecPatch_SupercededPatchAddBatch]') AND OBJECTPROPERTY(id, N'IsProcedure') = 1)
DROP PROCEDURE [dbo].[SecPatch_SupercededPatchAddBatch]
GO

IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = object_id(N'[dbo].[SecPatch_SupercededPatchBind]') AND OBJECTPROPERTY(id, N'IsProcedure') = 1)
DROP PROCEDURE [dbo].[SecPatch_SupercededPatchBind]
GO

IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = object_id(N'[dbo].[SecPatch_SupercededPatchGetAll]') AND OBJECTPROPERTY(id, N'IsProcedure') = 1)
DROP PROCEDURE [dbo].[SecPatch_SupercededPatchGetAll]
GO

IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = object_id(N'[dbo].[SecPatch_SupercededPatchPutBatchByPatchNameBulletinIDSupercededByID]') AND OBJECTPROPERTY(id, N'IsProcedure') = 1)
DROP PROCEDURE [dbo].[SecPatch_SupercededPatchPutBatchByPatchNameBulletinIDSupercededByID]
GO

IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = object_id(N'[dbo].[SecPatch_SupercededPatchPutByPatchNameBulletinIDSupercededByID]') AND OBJECTPROPERTY(id, N'IsProcedure') = 1)
DROP PROCEDURE [dbo].[SecPatch_SupercededPatchPutByPatchNameBulletinIDSupercededByID]
GO

IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = object_id(N'[dbo].[SecPatch_SupercededPatchRemoveAll]') AND OBJECTPROPERTY(id, N'IsProcedure') = 1)
DROP PROCEDURE [dbo].[SecPatch_SupercededPatchRemoveAll]
GO

IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = object_id(N'[dbo].[SecPatch_SupercededPatchSchema]') AND OBJECTPROPERTY(id, N'IsProcedure') = 1)
DROP PROCEDURE [dbo].[SecPatch_SupercededPatchSchema]
GO

IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = object_id(N'[dbo].[SecPatch_SupercededPatchTempAdd]') AND OBJECTPROPERTY(id, N'IsProcedure') = 1)
DROP PROCEDURE [dbo].[SecPatch_SupercededPatchTempAdd]
GO

IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = object_id(N'[dbo].[SecPatch_SupercededPatchUpdateBatchByID]') AND OBJECTPROPERTY(id, N'IsProcedure') = 1)
DROP PROCEDURE [dbo].[SecPatch_SupercededPatchUpdateBatchByID]
GO

IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = object_id(N'[dbo].[SecPatch_SupercededPatchUpdateByID]') AND OBJECTPROPERTY(id, N'IsProcedure') = 1)
DROP PROCEDURE [dbo].[SecPatch_SupercededPatchUpdateByID]
GO

IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = object_id(N'[dbo].[SecurityPatchResourceGetAllByBulletinIDResourcePatchName]') AND OBJECTPROPERTY(id, N'IsProcedure') = 1)
DROP PROCEDURE [dbo].[SecurityPatchResourceGetAllByBulletinIDResourcePatchName]
GO

IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = object_id(N'[dbo].[SecurityPatchStatusAdd]') AND OBJECTPROPERTY(id, N'IsProcedure') = 1)
DROP PROCEDURE [dbo].[SecurityPatchStatusAdd]
GO

IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = object_id(N'[dbo].[SecurityPatchStatusAddBatch]') AND OBJECTPROPERTY(id, N'IsProcedure') = 1)
DROP PROCEDURE [dbo].[SecurityPatchStatusAddBatch]
GO

IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = object_id(N'[dbo].[SecurityPatchStatusPutBatchByInternalText]') AND OBJECTPROPERTY(id, N'IsProcedure') = 1)
DROP PROCEDURE [dbo].[SecurityPatchStatusPutBatchByInternalText]
GO

IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = object_id(N'[dbo].[SecurityPatchStatusPutByInternalText]') AND OBJECTPROPERTY(id, N'IsProcedure') = 1)
DROP PROCEDURE [dbo].[SecurityPatchStatusPutByInternalText]
GO

IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = object_id(N'[dbo].[SecurityPatchStatusRemoveAll]') AND OBJECTPROPERTY(id, N'IsProcedure') = 1)
DROP PROCEDURE [dbo].[SecurityPatchStatusRemoveAll]
GO

IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = object_id(N'[dbo].[SecurityPatchStatusSchema]') AND OBJECTPROPERTY(id, N'IsProcedure') = 1)
DROP PROCEDURE [dbo].[SecurityPatchStatusSchema]
GO

IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = object_id(N'[dbo].[SecurityPatchStatusTempAdd]') AND OBJECTPROPERTY(id, N'IsProcedure') = 1)
DROP PROCEDURE [dbo].[SecurityPatchStatusTempAdd]
GO

IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = object_id(N'[dbo].[SecurityPatchStatusUpdateBatchByID]') AND OBJECTPROPERTY(id, N'IsProcedure') = 1)
DROP PROCEDURE [dbo].[SecurityPatchStatusUpdateBatchByID]
GO

IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = object_id(N'[dbo].[SecurityPatchStatusUpdateBatchByInternalText]') AND OBJECTPROPERTY(id, N'IsProcedure') = 1)
DROP PROCEDURE [dbo].[SecurityPatchStatusUpdateBatchByInternalText]
GO

IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = object_id(N'[dbo].[SecurityPatchStatusUpdateByID]') AND OBJECTPROPERTY(id, N'IsProcedure') = 1)
DROP PROCEDURE [dbo].[SecurityPatchStatusUpdateByID]
GO

IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = object_id(N'[dbo].[SecurityPatchStatusUpdateByInternalText]') AND OBJECTPROPERTY(id, N'IsProcedure') = 1)
DROP PROCEDURE [dbo].[SecurityPatchStatusUpdateByInternalText]
GO

IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = object_id(N'[dbo].[SecurityPatchSupercededByAddByDescription]') AND OBJECTPROPERTY(id, N'IsProcedure') = 1)
DROP PROCEDURE [dbo].[SecurityPatchSupercededByAddByDescription]
GO

IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = object_id(N'[dbo].[SecurityPatchToPackageVersionGetAllByPatchID]') AND OBJECTPROPERTY(id, N'IsProcedure') = 1)
DROP PROCEDURE [dbo].[SecurityPatchToPackageVersionGetAllByPatchID]
GO

IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = object_id(N'[dbo].[SecurityPatchToPackageVersionGetByPatchIDPackageFullName]') AND OBJECTPROPERTY(id, N'IsProcedure') = 1)
DROP PROCEDURE [dbo].[SecurityPatchToPackageVersionGetByPatchIDPackageFullName]
GO

IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = object_id(N'[dbo].[SecurityPatchToPackageVersionPutBatchByPatchIDPackageFullName]') AND OBJECTPROPERTY(id, N'IsProcedure') = 1)
DROP PROCEDURE [dbo].[SecurityPatchToPackageVersionPutBatchByPatchIDPackageFullName]
GO

IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = object_id(N'[dbo].[SecurityPatchToPackageVersionPutByPatchIDPackageFullName]') AND OBJECTPROPERTY(id, N'IsProcedure') = 1)
DROP PROCEDURE [dbo].[SecurityPatchToPackageVersionPutByPatchIDPackageFullName]
GO

IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = object_id(N'[dbo].[SecurityPatchToPackageVersionRemoveByPatchIDPackageFullName]') AND OBJECTPROPERTY(id, N'IsProcedure') = 1)
DROP PROCEDURE [dbo].[SecurityPatchToPackageVersionRemoveByPatchIDPackageFullName]
GO

IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = object_id(N'[dbo].[SecurityPatchToPackageVersionUpdateBatchByPatchIDPackageFullName]') AND OBJECTPROPERTY(id, N'IsProcedure') = 1)
DROP PROCEDURE [dbo].[SecurityPatchToPackageVersionUpdateBatchByPatchIDPackageFullName]
GO

IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = object_id(N'[dbo].[SecurityPatchToPackageVersionUpdateByPatchIDPackageFullName]') AND OBJECTPROPERTY(id, N'IsProcedure') = 1)
DROP PROCEDURE [dbo].[SecurityPatchToPackageVersionUpdateByPatchIDPackageFullName]
GO

IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = object_id(N'[dbo].[SecurityUIStateAdd]') AND OBJECTPROPERTY(id, N'IsProcedure') = 1)
DROP PROCEDURE [dbo].[SecurityUIStateAdd]
GO

IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = object_id(N'[dbo].[SecurityUIStateAddBatch]') AND OBJECTPROPERTY(id, N'IsProcedure') = 1)
DROP PROCEDURE [dbo].[SecurityUIStateAddBatch]
GO

IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = object_id(N'[dbo].[SecurityUIStateRemoveAll]') AND OBJECTPROPERTY(id, N'IsProcedure') = 1)
DROP PROCEDURE [dbo].[SecurityUIStateRemoveAll]
GO

IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = object_id(N'[dbo].[SecurityUIStateSchema]') AND OBJECTPROPERTY(id, N'IsProcedure') = 1)
DROP PROCEDURE [dbo].[SecurityUIStateSchema]
GO

IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = object_id(N'[dbo].[SecurityUIStateTempAdd]') AND OBJECTPROPERTY(id, N'IsProcedure') = 1)
DROP PROCEDURE [dbo].[SecurityUIStateTempAdd]
GO

IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = object_id(N'[dbo].[SecurityUIStateUpdateBatchByID]') AND OBJECTPROPERTY(id, N'IsProcedure') = 1)
DROP PROCEDURE [dbo].[SecurityUIStateUpdateBatchByID]
GO

IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = object_id(N'[dbo].[SecurityUIStateUpdateByID]') AND OBJECTPROPERTY(id, N'IsProcedure') = 1)
DROP PROCEDURE [dbo].[SecurityUIStateUpdateByID]
GO

IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = object_id(N'[dbo].[SecurityUserStateAdd]') AND OBJECTPROPERTY(id, N'IsProcedure') = 1)
DROP PROCEDURE [dbo].[SecurityUserStateAdd]
GO

IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = object_id(N'[dbo].[SecurityUserStateAddBatch]') AND OBJECTPROPERTY(id, N'IsProcedure') = 1)
DROP PROCEDURE [dbo].[SecurityUserStateAddBatch]
GO

IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = object_id(N'[dbo].[SecurityUserStateRemoveAll]') AND OBJECTPROPERTY(id, N'IsProcedure') = 1)
DROP PROCEDURE [dbo].[SecurityUserStateRemoveAll]
GO

IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = object_id(N'[dbo].[SecurityUserStateSchema]') AND OBJECTPROPERTY(id, N'IsProcedure') = 1)
DROP PROCEDURE [dbo].[SecurityUserStateSchema]
GO

IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = object_id(N'[dbo].[SecurityUserStateTempAdd]') AND OBJECTPROPERTY(id, N'IsProcedure') = 1)
DROP PROCEDURE [dbo].[SecurityUserStateTempAdd]
GO

IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = object_id(N'[dbo].[SecurityUserStateUpdateBatchByID]') AND OBJECTPROPERTY(id, N'IsProcedure') = 1)
DROP PROCEDURE [dbo].[SecurityUserStateUpdateBatchByID]
GO

IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = object_id(N'[dbo].[SecurityUserStateUpdateByID]') AND OBJECTPROPERTY(id, N'IsProcedure') = 1)
DROP PROCEDURE [dbo].[SecurityUserStateUpdateByID]
GO


-----------------------------------------------------------------------------
-- Populate new records in to the SecurityPatchUIProductGroup table. This
-- must be done before running spm-schema.sql as the schema SQL
-- may attempt to populate SecurityPatchApplication records that reference
-- some of the records to be inserted here.
-----------------------------------------------------------------------------
IF EXISTS (
	SELECT *
	FROM INFORMATION_SCHEMA.TABLES
	WHERE TABLE_NAME = 'SecurityPatchUIProductGroup'
)
BEGIN
	PRINT 'Populate the SecurityPatchUIProductGroup table'

	SET IDENTITY_INSERT SecurityPatchUIProductGroup ON
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Outlook Express', 'Outlook Express 4.01', 104)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Outlook Express', 'Outlook Express 5.01', 105)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Outlook Express', 'Outlook Express 5.5', 106)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Outlook Express', 'Outlook Express 5.5 Service Pack 2', 107)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Outlook Express', 'Outlook Express 5.5 SP2', 108)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Outlook Express', 'Outlook Express 6', 109)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Outlook Express', 'Outlook Express 6 on Windows Server 2003', 110)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Outlook Express', 'Outlook Express 6 Service Pack 1', 111)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Outlook Express', 'Outlook Express 6 SP1', 112)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Outlook Express', 'Outlook Express 6.0', 113)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Outlook Express', 'Outlook Express for Windows Server 2003', 114)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Outlook Express', 'Outlook Express for Windows Server 2003 64-bit Itanium Edition', 115)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('BackOffice Server', 'BizTalk Server 2000', 116)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('BackOffice Server', 'BizTalk Server 2002', 117)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('BackOffice Server', 'BackOffice Server 4.0', 118)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('BackOffice Server', 'BackOffice Server 2000', 119)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('BackOffice Server', 'BackOffice Resource Kit SE', 120)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('BackOffice Server', 'Site Server 3.0', 121)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('BackOffice Server', 'Site Server 3.0, Commerce Edition', 122)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('BackOffice Server', 'Microsoft Commercial Internet System 2.0', 123)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('BackOffice Server', 'Microsoft Commercial Internet System 2.5', 124)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('BackOffice Server', 'Commerce Server 2000', 125)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('BackOffice Server', 'Commerce Server 2002', 126)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('BackOffice Server', 'ISA Server 2000', 127)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('BackOffice Server', 'Proxy Server 2.0', 128)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('BackOffice Server', 'Content Management Server 2001', 129)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('BackOffice Server', 'Small Business Server 2000', 130)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('BackOffice Server', 'Windows Small Business Server 2003', 131)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('BackOffice Server', 'Microsoft Business Solutions CRM', 132)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Microsoft Works', 'Works 2000', 133)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Microsoft Works', 'Works 2001', 134)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Microsoft Works', 'Works 2002', 135)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Microsoft Works', 'Works 2003', 136)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Microsoft Works', 'Works 2004', 137)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Microsoft Works', 'Money 2000', 138)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Microsoft Works', 'Money 2001', 139)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Microsoft Works', 'Greetings 2000', 140)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Microsoft Works', 'Home Publishing 2000', 141)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Microsoft Office 97', 'Office 97', 142)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Microsoft Office 97', 'Access 97', 143)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Microsoft Office 97', 'Excel 97', 144)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Microsoft Office 97', 'PowerPoint 97', 145)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Microsoft Office 97', 'Word 97', 146)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Microsoft Office 2000', 'Access 2000', 147)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Microsoft Office 2000', 'Excel 2000', 148)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Microsoft Office 2000', 'FrontPage 2000', 149)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Microsoft Office 2000', 'Office 2000', 150)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Microsoft Office 2000', 'Office Web Components 2000', 151)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Microsoft Office 2000', 'Outlook 2000', 152)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Microsoft Office 2000', 'Powerpoint 2000', 153)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Microsoft Office 2000', 'Publisher 2000', 154)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Microsoft Office 2000', 'Word 2000', 155)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Microsoft Office XP', 'Access 2002', 156)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Microsoft Office XP', 'Excel 2002', 157)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Microsoft Office XP', 'FrontPage 2002', 158)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Microsoft Office XP', 'Office XP', 159)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Microsoft Office XP', 'Office Web Components XP', 160)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Microsoft Office XP', 'Office Web Components 2002', 161)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Microsoft Office XP', 'Outlook 2002', 162)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Microsoft Office XP', 'Powerpoint 2002', 163)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Microsoft Office XP', 'Publisher 2002', 164)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Microsoft Office XP', 'Word 2002', 165)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Microsoft Office 2003', 'Access 2003', 166)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Microsoft Office 2003', 'Excel 2003', 167)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Microsoft Office 2003', 'FrontPage 2003', 168)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Microsoft Office 2003', 'Office 2003', 169)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Microsoft Office 2003', 'Office Web Components 2003', 170)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Microsoft Office 2003', 'Outlook 2003', 171)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Microsoft Office 2003', 'Powerpoint 2003', 172)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Microsoft Office 2003', 'Publisher 2003', 173)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Microsoft Office 2003', 'Word 2003', 174)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('MDAC', 'Microsoft Data Access Components', 175)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('.NET Framework', '.NET Framework', 176)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Windows 2000', 'Windows 2000', 177)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Windows NT 4.0', 'Windows NT 4.0', 178)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Windows XP', 'Windows XP', 179)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Windows Server 2003', 'Windows Server 2003', 180)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Windows Server 2003', 'Windows Server 2003 64-bit Itanium Edition', 181)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Windows Server 2003', 'Windows Server 2003 x64 Edition', 182)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Windows XP', 'Windows XP x64 Edition', 183)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Windows Media Player', 'Windows Media Services', 184)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Windows Media Player', 'Windows Media Services 4.0', 185)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Windows Media Player', 'Windows Media Services 4.1', 186)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Windows Media Player', 'Windows Media Encoder 4.0', 187)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Windows Media Player', 'Windows Media Encoder 4.1', 188)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Windows Media Player', 'Windows Media Rights Manager 1', 189)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Windows Media Player', 'Windows Media Player', 190)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('IIS', 'FrontPage 98 Personal Web Server 1.0', 191)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('IIS', 'FrontPage 97 Personal Web Server 1.0', 192)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('IIS', 'Personal Web Server 4.0', 193)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('IIS', 'FrontPage 97 Server Extensions', 194)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('IIS', 'FrontPage 98 Server Extensions', 195)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('IIS', 'FrontPage 2000 Server Extensions', 196)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('IIS', 'Internet Information Services', 197)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('IIS', 'Internet Information Services and Windows XP', 198)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('IIS', 'FrontPage Server Extensions 2002', 199)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Virtual Machine', 'Microsoft Virtual Machine  Microsoft VM', 200)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Internet Explorer', 'Internet Explorer for Windows 2000', 201)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Internet Explorer', 'Internet Explorer for Windows Server 2003', 202)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Internet Explorer', 'Internet Explorer for Windows Server 2003 64-bit Itanium Edition', 203)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Internet Explorer', 'Internet Explorer for Windows Server 2003 x64 Edition', 204)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Internet Explorer', 'Internet Explorer for Windows XP', 205)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Internet Explorer', 'Internet Explorer for Windows XP Service Pack 2', 206)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Internet Explorer', 'Internet Explorer for Windows XP x64 Edition', 207)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Picture It!/Digital Image', 'PictureIt 2000', 208)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('MSN Messenger', 'Windows Messenger', 209)
	SET IDENTITY_INSERT SecurityPatchUIProductGroup OFF
END
GO


-----------------------------------------------------------------------------
-- Populate new records in to the SecurityPatchApplication table
-----------------------------------------------------------------------------
IF EXISTS (
	SELECT *
	FROM INFORMATION_SCHEMA.TABLES
	WHERE TABLE_NAME = 'SecurityPatchApplication'
)
BEGIN
	PRINT 'Populate the SecurityPatchApplication table'

	INSERT INTO SecurityPatchApplication (ApplicationID, Description, Selected, Visible)
		VALUES (104, 'Outlook Express', 1, 1)
	INSERT INTO SecurityPatchApplication (ApplicationID, Description, Selected, Visible)
		VALUES (116, 'BackOffice Server', 1, 1)
	INSERT INTO SecurityPatchApplication (ApplicationID, Description, Selected, Visible)
		VALUES (133, 'Microsoft Works', 1, 1)
	INSERT INTO SecurityPatchApplication (ApplicationID, Description, Selected, Visible)
		VALUES (142, 'Microsoft Office 97', 1, 1)
END
GO

