USE ManageSoft
GO

-- The SecPatch_AffectedProduct table contains the products and service packs affected by a security patch.
IF NOT EXISTS (
	SELECT * FROM INFORMATION_SCHEMA.TABLES
	WHERE TABLE_NAME = 'SecPatch_AffectedProduct'
)
BEGIN
	CREATE TABLE SecPatch_AffectedProduct (
		-- Primary key.
		AffectedProductID	int IDENTITY NOT NULL,
		-- Foreign key to the SecPatch_Product table.
		ProductID		int NOT NULL,
		-- Foreign key to the SecPatch_ServicePack table. Maps to service pack ID.
		FixedInSP		int NOT NULL,
		-- Foreign key to the SecPatch_Patch table.
		PatchID			int NOT NULL,
		CONSTRAINT PK_AffectedProduct
			PRIMARY KEY CLUSTERED(AffectedProductID),
		CONSTRAINT UQ_AffectedProduct
			UNIQUE NONCLUSTERED(ProductID, PatchID)
	);

	CREATE NONCLUSTERED INDEX AffectedProductByPatchID
		ON SecPatch_AffectedProduct(PatchID)

END
ELSE
	PRINT 'Using existing SecPatch_AffectedProduct table'
GO

-- The SecPatch_AffectedServicePack table contains the service packs that a product applies to for a security patch.
IF NOT EXISTS (
	SELECT * FROM INFORMATION_SCHEMA.TABLES
	WHERE TABLE_NAME = 'SecPatch_AffectedServicePack'
)
BEGIN
	CREATE TABLE SecPatch_AffectedServicePack (
		-- Primary key.
		AffectedServicePackID	int IDENTITY NOT NULL,
		-- Foreign key to the SecPatch_AffectedProduct table.
		AffectedProductID	int NOT NULL,
		-- Foreign key to the SecPatch_ServicePack table.
		ServicePackID		int NOT NULL,
		CONSTRAINT FK_AffectedServicePack_AffectedProduct
			FOREIGN KEY(AffectedProductID)
			REFERENCES SecPatch_AffectedProduct(AffectedProductID),
		CONSTRAINT PK_AffectedServicePack
			PRIMARY KEY NONCLUSTERED(AffectedServicePackID),
		CONSTRAINT UQ_AffectedServicePack
			UNIQUE CLUSTERED(AffectedProductID, ServicePackID)
	);

	CREATE NONCLUSTERED INDEX AffectedServicePackByAffectedProductID
		ON SecPatch_AffectedServicePack(AffectedProductID)

END
ELSE
	PRINT 'Using existing SecPatch_AffectedServicePack table'
GO

-- The SecPatch_AvailableSP table describes the service pack that a product is available for.
IF NOT EXISTS (
	SELECT * FROM INFORMATION_SCHEMA.TABLES
	WHERE TABLE_NAME = 'SecPatch_AvailableSP'
)
BEGIN
	CREATE TABLE SecPatch_AvailableSP (
		-- Foreign key to the SecPatch_ServicePack table.
		ServicePackID		int NOT NULL,
		-- Foreign key to the SecPatch_Product table.
		ProductID		int NOT NULL,
		CONSTRAINT PK_AvailableSP
			PRIMARY KEY CLUSTERED(ServicePackID)
	);

END
ELSE
	PRINT 'Using existing SecPatch_AvailableSP table'
GO

-- The SecPatch_Command table describes the action to be performed for a file or registry change required for a patch.
IF NOT EXISTS (
	SELECT * FROM INFORMATION_SCHEMA.TABLES
	WHERE TABLE_NAME = 'SecPatch_Command'
)
BEGIN
	CREATE TABLE SecPatch_Command (
		-- Primary key.
		CommandID		char(10) NOT NULL,
		-- Text describing the action to be performed for a file or registry change.
		[Name]			nvarchar(128) NOT NULL,
		CONSTRAINT PK_Command
			PRIMARY KEY CLUSTERED(CommandID)
	);

END
ELSE
	PRINT 'Using existing SecPatch_Command table'
GO

-- The SecPatch_Comment table contains descriptive text about security patches and bulletins.
IF NOT EXISTS (
	SELECT * FROM INFORMATION_SCHEMA.TABLES
	WHERE TABLE_NAME = 'SecPatch_Comment'
)
BEGIN
	CREATE TABLE SecPatch_Comment (
		-- Primary key.
		CommentID		int NOT NULL,
		-- Text describing a security patch or bulletin
		Text			ntext NOT NULL,
		CONSTRAINT PK_Comment
			PRIMARY KEY CLUSTERED(CommentID)
	);

END
ELSE
	PRINT 'Using existing SecPatch_Comment table'
GO

-- The SecPatch_File table contains file records used by security patches.
IF NOT EXISTS (
	SELECT * FROM INFORMATION_SCHEMA.TABLES
	WHERE TABLE_NAME = 'SecPatch_File'
)
BEGIN
	CREATE TABLE SecPatch_File (
		-- Primary key.
		FileID			int NOT NULL,
		-- Descriptive name of the file.
		[Name]			nvarchar(128) NOT NULL,
		-- Foreign key to the SecPatch_Location table.
		LocationID		int NOT NULL,
		CONSTRAINT PK_File
			PRIMARY KEY CLUSTERED(FileID)
	);

END
ELSE
	PRINT 'Using existing SecPatch_File table'
GO

-- The SecPatch_Location table contains URLs and file and registry locations used by security patches and bulletins and is referred to by file and registry entries within a patch.
IF NOT EXISTS (
	SELECT * FROM INFORMATION_SCHEMA.TABLES
	WHERE TABLE_NAME = 'SecPatch_Location'
)
BEGIN
	CREATE TABLE SecPatch_Location (
		-- Primary key.
		LocationID		int NOT NULL,
		-- URL to a file or registry location used by a security patch or bulletin.
		Path			nvarchar(256) NOT NULL,
		-- Whether the location is an absolute path or not.
		AbsolutePath		nvarchar(6) NOT NULL,
		CONSTRAINT PK_Location
			PRIMARY KEY CLUSTERED(LocationID)
	);

END
ELSE
	PRINT 'Using existing SecPatch_Location table'
GO

-- The SecPatch_Product table contains all the products that Microsoft has published security patches for.
IF NOT EXISTS (
	SELECT * FROM INFORMATION_SCHEMA.TABLES
	WHERE TABLE_NAME = 'SecPatch_Product'
)
BEGIN
	CREATE TABLE SecPatch_Product (
		-- Primary key.
		ProductID		int NOT NULL,
		-- Name of this product.
		[Name]			nvarchar(80) NOT NULL,
		-- The least recent service pack that is supported for this product.
		MinimumSupportedServicePackID int NULL,
		-- The most recently released service pack for this product.
		CurrentServicePackID	int NULL,
		-- The most recently released version of this product.
		CurrentVersion		nvarchar(50) NULL,
		CONSTRAINT PK_Product
			PRIMARY KEY CLUSTERED(ProductID)
	);

END
ELSE
	PRINT 'Using existing SecPatch_Product table'
GO

-- The SecPatch_RegKey table contains registry keys used to identify security patches.
IF NOT EXISTS (
	SELECT * FROM INFORMATION_SCHEMA.TABLES
	WHERE TABLE_NAME = 'SecPatch_RegKey'
)
BEGIN
	CREATE TABLE SecPatch_RegKey (
		-- Primary key.
		RegKeyID		int NOT NULL,
		-- The name of the registry key.
		[Name]			nvarchar(256) NOT NULL,
		-- The type of the registry key.
		Type			nvarchar(50) NOT NULL,
		CONSTRAINT PK_RegKey
			PRIMARY KEY CLUSTERED(RegKeyID)
	);

END
ELSE
	PRINT 'Using existing SecPatch_RegKey table'
GO

-- The SecPatch_SUSMapping table is not used by ManageSoft but provides a mapping between mssecure.xml information and Microsoft SUS.
IF NOT EXISTS (
	SELECT * FROM INFORMATION_SCHEMA.TABLES
	WHERE TABLE_NAME = 'SecPatch_SUSMapping'
)
BEGIN
	CREATE TABLE SecPatch_SUSMapping (
		-- The name of the patch as known by SUS.
		SUSPatchName		nvarchar(128) NOT NULL,
		-- The mssecure.xml name of the patch.
		PatchName		nvarchar(50) NOT NULL,
		CONSTRAINT PK_SUSMapping
			PRIMARY KEY CLUSTERED(SUSPatchName, PatchName)
	);

END
ELSE
	PRINT 'Using existing SecPatch_SUSMapping table'
GO

-- The SecPatch_ServicePack table contains all the service packs for products that have security patches published for them.
IF NOT EXISTS (
	SELECT * FROM INFORMATION_SCHEMA.TABLES
	WHERE TABLE_NAME = 'SecPatch_ServicePack'
)
BEGIN
	CREATE TABLE SecPatch_ServicePack (
		-- Primary key.
		ServicePackID		int NOT NULL,
		-- The name of the service pack.
		[Name]			nvarchar(50) NOT NULL,
		-- The URL from which the service pack can be retrieved.
		URL			nvarchar(256) NULL,
		-- The release date of the service pack.
		ReleaseDate		datetime NULL,
		CONSTRAINT PK_ServicePack
			PRIMARY KEY CLUSTERED(ServicePackID)
	);

END
ELSE
	PRINT 'Using existing SecPatch_ServicePack table'
GO

-- The SecPatch_Severity table contains descriptions of the severity of security bulletins. This table is not used by ManageSoft.
IF NOT EXISTS (
	SELECT * FROM INFORMATION_SCHEMA.TABLES
	WHERE TABLE_NAME = 'SecPatch_Severity'
)
BEGIN
	CREATE TABLE SecPatch_Severity (
		-- Primary key.
		SeverityID		char(10) NOT NULL,
		-- Descriptive text of the severity of a security bulletin.
		Description		nvarchar(50) NULL,
		CONSTRAINT PK_Severity
			PRIMARY KEY CLUSTERED(SeverityID)
	);

END
ELSE
	PRINT 'Using existing SecPatch_Severity table'
GO

-- The SecPatch_SupercededBy table is used to determine whether a security patch has been superseded.
IF NOT EXISTS (
	SELECT * FROM INFORMATION_SCHEMA.TABLES
	WHERE TABLE_NAME = 'SecPatch_SupercededBy'
)
BEGIN
	CREATE TABLE SecPatch_SupercededBy (
		-- Primary key.
		SBID			int NOT NULL,
		-- Description of the bulletin that has been superseded. Typically the security bulletin ID and the product.
		Description		ntext NULL,
		CONSTRAINT PK_SupercededBy
			PRIMARY KEY CLUSTERED(SBID)
	);

END
ELSE
	PRINT 'Using existing SecPatch_SupercededBy table'
GO

-- The SecPatch_ProductFamily table defines product groupings used by security patches.
IF NOT EXISTS (
	SELECT * FROM INFORMATION_SCHEMA.TABLES
	WHERE TABLE_NAME = 'SecPatch_ProductFamily'
)
BEGIN
	CREATE TABLE SecPatch_ProductFamily (
		-- Primary key.
		ProductFamilyID		int NOT NULL,
		-- The name of the product family.
		[Name]			nvarchar(50) NOT NULL,
		-- Foreign key to the SecPatch_Product table.
		RecentProductVersionID	int NULL,
		CONSTRAINT PK_ProductFamily
			PRIMARY KEY CLUSTERED(ProductFamilyID)
	);

END
ELSE
	PRINT 'Using existing SecPatch_ProductFamily table'
GO

-- The SecPatch_ProductProductFamily table defines product groupings used by security patches.
IF NOT EXISTS (
	SELECT * FROM INFORMATION_SCHEMA.TABLES
	WHERE TABLE_NAME = 'SecPatch_ProductProductFamily'
)
BEGIN
	CREATE TABLE SecPatch_ProductProductFamily (
		-- Primary key.
		ProductProductFamilyID	int IDENTITY NOT NULL,
		-- Foreign key to the SecPatch_Product table.
		ProductID		int NOT NULL,
		-- Foreign key to the SecPatch_ProductFamily table.
		ProductFamilyID		int NOT NULL,
		CONSTRAINT FK_ProductProductFamily_ProductFamily
			FOREIGN KEY(ProductFamilyID)
			REFERENCES SecPatch_ProductFamily(ProductFamilyID),
		CONSTRAINT FK_ProductProductFamily_Product
			FOREIGN KEY(ProductID)
			REFERENCES SecPatch_Product(ProductID),
		CONSTRAINT UQ_ProductProductFamily
			UNIQUE NONCLUSTERED(ProductID, ProductFamilyID)
	);

END
ELSE
	PRINT 'Using existing SecPatch_ProductProductFamily table'
GO

-- The SecPatch_BulletinComment table is a mapping between SecPatch_Bulletin and the SecPatch_Comment table.
IF NOT EXISTS (
	SELECT * FROM INFORMATION_SCHEMA.TABLES
	WHERE TABLE_NAME = 'SecPatch_BulletinComment'
)
BEGIN
	CREATE TABLE SecPatch_BulletinComment (
		-- Primary key.
		BulletinCommentID	int IDENTITY NOT NULL,
		-- Foreign key to the SecPatch_Comment table.
		CommentID		int NOT NULL,
		-- Foreign key to the SecPatch_Bulletin table.
		BulletinID		nvarchar(50) NOT NULL,
		CONSTRAINT FK_BulletinComment_Comment
			FOREIGN KEY(CommentID)
			REFERENCES SecPatch_Comment(CommentID),
		CONSTRAINT PK_BulletinComment
			PRIMARY KEY CLUSTERED(BulletinCommentID),
		CONSTRAINT UQ_BulletinComment
			UNIQUE NONCLUSTERED(CommentID, BulletinID)
	);

END
ELSE
	PRINT 'Using existing SecPatch_BulletinComment table'
GO

-- The SecPatch_QNumber table contains "Qnumbers" which are the identifier that Microsoft uses for security bulletins.
IF NOT EXISTS (
	SELECT * FROM INFORMATION_SCHEMA.TABLES
	WHERE TABLE_NAME = 'SecPatch_QNumber'
)
BEGIN
	CREATE TABLE SecPatch_QNumber (
		-- The "Qnumber" for this security bulletin.
		qNumber			nvarchar(50) NOT NULL,
		-- Foreign key to the SecPatch_Bulletin table.
		BulletinID		nvarchar(50) NOT NULL,
		CONSTRAINT PK_qNumber
			PRIMARY KEY CLUSTERED(qNumber)
	);

END
ELSE
	PRINT 'Using existing SecPatch_QNumber table'
GO

-- The SecPatch_Patch table contains security patches.
IF NOT EXISTS (
	SELECT * FROM INFORMATION_SCHEMA.TABLES
	WHERE TABLE_NAME = 'SecPatch_Patch'
)
BEGIN
	CREATE TABLE SecPatch_Patch (
		-- Primary key.
		PatchID			int IDENTITY NOT NULL,
		-- The name of this security patch.
		PatchName		nvarchar(128) COLLATE Latin1_General_CS_AS NOT NULL,
		-- Foreign key to the SecPatch_Bulletin table.
		BulletinID		nvarchar(50) NOT NULL,
		-- Foreign key to the SecPatch_Location table.
		PatchLocationID		int NOT NULL,
		-- Foreign key to the SecPatch_SupercededBy table.
		SBID			int NULL,
		-- The SQNumber for this security patch.
		SQNumber		nvarchar(50) NOT NULL,
		-- Whether this security patch requires a reboot or not.
		NoReboot		int NOT NULL,
		-- Foreign key to the SecurityPatch table.
		SecurityPatchID		int NOT NULL,
		CONSTRAINT FK_Patch_Location
			FOREIGN KEY(PatchLocationID)
			REFERENCES SecPatch_Location(LocationID),
		CONSTRAINT FK_Patch_SupercededBy
			FOREIGN KEY(SBID)
			REFERENCES SecPatch_SupercededBy(SBID),
		CONSTRAINT PK_Patch
			PRIMARY KEY CLUSTERED(PatchID),
		CONSTRAINT UQ_PatchSecurityPatchID
			UNIQUE NONCLUSTERED(SecurityPatchID),
		CONSTRAINT UQ_Patch
			UNIQUE NONCLUSTERED(BulletinID, PatchName)
	);

	CREATE NONCLUSTERED INDEX IN_Patch
		ON SecPatch_Patch(PatchName)

END
ELSE
	PRINT 'Using existing SecPatch_Patch table'
GO

-- The SecPatch_FileChg table contains file change records that assist the MBSA client in determining whether a security patch needs to be installed on a computer.
IF NOT EXISTS (
	SELECT * FROM INFORMATION_SCHEMA.TABLES
	WHERE TABLE_NAME = 'SecPatch_FileChg'
)
BEGIN
	CREATE TABLE SecPatch_FileChg (
		-- Primary key.
		FileChgID		int IDENTITY NOT NULL,
		-- Foreign key to the SecPatch_FileChange table.
		FileChangeID		int NOT NULL,
		-- Foreign key to the SecPatch_Patch table.
		PatchID			int NOT NULL,
		CONSTRAINT FK_FileChg_Patch
			FOREIGN KEY(PatchID)
			REFERENCES SecPatch_Patch(PatchID),
		CONSTRAINT PK_FileChg
			PRIMARY KEY CLUSTERED(FileChgID),
		CONSTRAINT UQ_FileChg
			UNIQUE NONCLUSTERED(PatchID, FileChangeID)
	);

END
ELSE
	PRINT 'Using existing SecPatch_FileChg table'
GO

-- The SecPatch_PatchComment table is a mapping between SecPatch_Patch and the SecPatch_Comment table.
IF NOT EXISTS (
	SELECT * FROM INFORMATION_SCHEMA.TABLES
	WHERE TABLE_NAME = 'SecPatch_PatchComment'
)
BEGIN
	CREATE TABLE SecPatch_PatchComment (
		-- Primary key.
		PatchCommentID		int IDENTITY NOT NULL,
		-- Foreign key to the SecPatch_Comment table.
		CommentID		int NOT NULL,
		-- Foreign key to the SecPatch_Patch table.
		PatchID			int NOT NULL,
		CONSTRAINT FK_PatchComment_Comment
			FOREIGN KEY(CommentID)
			REFERENCES SecPatch_Comment(CommentID),
		CONSTRAINT FK_PatchComment_Patch
			FOREIGN KEY(PatchID)
			REFERENCES SecPatch_Patch(PatchID),
		CONSTRAINT PK_PatchComment
			PRIMARY KEY CLUSTERED(PatchCommentID),
		CONSTRAINT UQ_PatchComment
			UNIQUE NONCLUSTERED(CommentID, PatchID)
	);

END
ELSE
	PRINT 'Using existing SecPatch_PatchComment table'
GO

-- The SecPatch_FileChange table contains file change records that assist the MBSA client in determining whether a security patch needs to be installed on a computer.
IF NOT EXISTS (
	SELECT * FROM INFORMATION_SCHEMA.TABLES
	WHERE TABLE_NAME = 'SecPatch_FileChange'
)
BEGIN
	CREATE TABLE SecPatch_FileChange (
		-- Primary key.
		FileChangeID		int NOT NULL,
		-- The timestamp that the file should have if this file change has already been applied.
		Date			nvarchar(50) NULL,
		-- The version that the file should have if this file change has already been applied.
		Version			nvarchar(50) NULL,
		-- The size that the file should have if this file change has already been applied.
		[Size]			nvarchar(50) NULL,
		-- Foreign key to the SecPatch_Comment table.
		CommandID		char(10) NULL,
		-- The checksum that the file should have if this file change has already been applied.
		Checksum		int NULL,
		-- Foreign key to the SecPatch_File table.
		FileID			int NOT NULL,
		CONSTRAINT FK_FileChange_Command
			FOREIGN KEY(CommandID)
			REFERENCES SecPatch_Command(CommandID),
		CONSTRAINT FK_FileChange_File
			FOREIGN KEY(FileID)
			REFERENCES SecPatch_File(FileID),
		CONSTRAINT PK_FileChange
			PRIMARY KEY CLUSTERED(FileChangeID)
	);

END
ELSE
	PRINT 'Using existing SecPatch_FileChange table'
GO

-- The SecPatch_RegChange table contains registry change records that assist the MBSA client in determining whether a security patch needs to be installed on a computer.
IF NOT EXISTS (
	SELECT * FROM INFORMATION_SCHEMA.TABLES
	WHERE TABLE_NAME = 'SecPatch_RegChange'
)
BEGIN
	CREATE TABLE SecPatch_RegChange (
		-- Primary key.
		RegChangeID		int NOT NULL,
		-- Action to perform as part of this registry change.
		RegChangeValue		nvarchar(50) NULL,
		-- Foreign key to the SecPatch_Command table.
		CommandID		char(10) NULL,
		-- Foreign key to the SecPatch_RegKey table.
		RegKeyID		int NULL,
		-- Foreign key to the SecPatch_RegKey table. This reference is the parent of this registry change.
		RegLocationID		int NULL,
		-- Foreign key to the SecPatch_Location table.
		LocationID		int NOT NULL,
		CONSTRAINT FK_RegChange_Command
			FOREIGN KEY(CommandID)
			REFERENCES SecPatch_Command(CommandID),
		CONSTRAINT FK_RegChange_Location
			FOREIGN KEY(LocationID)
			REFERENCES SecPatch_Location(LocationID),
		CONSTRAINT FK_RegChange_RegKey
			FOREIGN KEY(RegLocationID)
			REFERENCES SecPatch_RegKey(RegKeyID),
		CONSTRAINT PK_RegChange
			PRIMARY KEY CLUSTERED(RegChangeID)
	);

END
ELSE
	PRINT 'Using existing SecPatch_RegChange table'
GO

-- The SecPatch_SupercededPatch table specifies the security bulletin that a patch is superseded by.
IF NOT EXISTS (
	SELECT * FROM INFORMATION_SCHEMA.TABLES
	WHERE TABLE_NAME = 'SecPatch_SupercededPatch'
)
BEGIN
	CREATE TABLE SecPatch_SupercededPatch (
		-- Primary key.
		SupercededPatchID	int IDENTITY NOT NULL,
		-- The name of this security patch.
		PatchName		nvarchar(50) COLLATE Latin1_General_CS_AS NOT NULL,
		-- Foreign key to the SecPatch_Bulletin table.
		BulletinID		nvarchar(50) NOT NULL,
		-- Foreign key to the SecPatch_SupercededBy table.
		SupercededByID		int NOT NULL,
		CONSTRAINT FK_SupercededPatch_SupercededBy
			FOREIGN KEY(SupercededByID)
			REFERENCES SecPatch_SupercededBy(SBID),
		CONSTRAINT PK_SupercededPatch
			PRIMARY KEY CLUSTERED(SupercededPatchID),
		CONSTRAINT UQ_SupercededPatch
			UNIQUE NONCLUSTERED(PatchName, BulletinID, SupercededByID)
	);

END
ELSE
	PRINT 'Using existing SecPatch_SupercededPatch table'
GO

-- The SecPatch_Bulletin table describes security bulletins.
IF NOT EXISTS (
	SELECT * FROM INFORMATION_SCHEMA.TABLES
	WHERE TABLE_NAME = 'SecPatch_Bulletin'
)
BEGIN
	CREATE TABLE SecPatch_Bulletin (
		-- Primary key.
		BulletinID		nvarchar(50) NOT NULL,
		-- Foreign key to the SecPatch_Location table.
		BulletinLocationID	int NOT NULL,
		-- Foreign key to the SecPatch_Location table. This is the location of the FAQ document for this security bulletin.
		FAQLocationID		int NULL,
		-- The title text of this bulletin.
		Title			nvarchar(128) NULL,
		-- The date this security bulletin was posted.
		DatePosted		datetime NULL,
		-- The date this security bulletin was last revised.
		DateRevised		datetime NULL,
		-- Whether this security bulletin is still supported or not.
		Supported		nvarchar(10) NOT NULL,
		-- The summary text for this security bulletin.
		Summary			nvarchar(3000) NULL,
		-- The text dsecribing the issue solved by this security bulletin.
		Issue			ntext NULL,
		-- Foreign key to the SecPatch_Severity table.
		ImpactSeverityID	char(10) NOT NULL,
		-- Foreign key to the SecPatch_Severity table.
		PreReqSeverityID	char(10) NOT NULL,
		-- Foreign key to the SecPatch_Severity table.
		MitigationSeverityID	char(10) NOT NULL,
		-- Foreign key to the SecPatch_Severity table.
		PopularitySeverityID	char(10) NOT NULL,
		CONSTRAINT FK_Bulletin_Location
			FOREIGN KEY(BulletinLocationID)
			REFERENCES SecPatch_Location(LocationID),
		CONSTRAINT FK_Bulletin_Location1
			FOREIGN KEY(FAQLocationID)
			REFERENCES SecPatch_Location(LocationID),
		CONSTRAINT FK_Bulletin_Severity
			FOREIGN KEY(ImpactSeverityID)
			REFERENCES SecPatch_Severity(SeverityID),
		CONSTRAINT FK_Bulletin_Severity2
			FOREIGN KEY(MitigationSeverityID)
			REFERENCES SecPatch_Severity(SeverityID),
		CONSTRAINT FK_Bulletin_Severity3
			FOREIGN KEY(PopularitySeverityID)
			REFERENCES SecPatch_Severity(SeverityID),
		CONSTRAINT FK_Bulletin_Severity1
			FOREIGN KEY(PreReqSeverityID)
			REFERENCES SecPatch_Severity(SeverityID),
		CONSTRAINT PK_Bulletin
			PRIMARY KEY CLUSTERED(BulletinID)
	);

END
ELSE
	PRINT 'Using existing SecPatch_Bulletin table'
GO

-- The SecPatch_RegChg table contains registry change records that assist the MBSA client in determining whether a security patch needs to be installed on a computer.
IF NOT EXISTS (
	SELECT * FROM INFORMATION_SCHEMA.TABLES
	WHERE TABLE_NAME = 'SecPatch_RegChg'
)
BEGIN
	CREATE TABLE SecPatch_RegChg (
		-- Foreign key to the SecPatch_Patch table.
		PatchID			int NOT NULL,
		-- Foreign key to the SecPatch_RegChange table.
		RegChangeID		int NOT NULL,
		-- Primary key.
		RegChgID		int IDENTITY NOT NULL,
		CONSTRAINT FK_RegChg_Patch
			FOREIGN KEY(PatchID)
			REFERENCES SecPatch_Patch(PatchID),
		CONSTRAINT FK_RegChg_RegChange
			FOREIGN KEY(RegChangeID)
			REFERENCES SecPatch_RegChange(RegChangeID),
		CONSTRAINT PK_RegChg
			UNIQUE NONCLUSTERED(RegChgID),
		CONSTRAINT UQ_RegChg
			UNIQUE NONCLUSTERED(PatchID, RegChangeID)
	);

END
ELSE
	PRINT 'Using existing SecPatch_RegChg table'
GO

-- The SecurityBulletin table is ManageSoft's record of known security bulletins.
IF NOT EXISTS (
	SELECT * FROM INFORMATION_SCHEMA.TABLES
	WHERE TABLE_NAME = 'SecurityBulletin'
)
BEGIN
	CREATE TABLE SecurityBulletin (
		-- The artificial primary key.
		SecurityBulletinID	int IDENTITY NOT NULL,
		-- The name of the security bulletin. This is a unique key.
		BulletinID		nvarchar(32) NOT NULL,
		-- The severity of the security bulletin. This value is always set to critical.
		Severity		int NOT NULL,
		-- The state of the security bulletin.
		State			int NOT NULL DEFAULT 1,
		-- User comments about this bulletin that are entered from the ManageSoft user interface.
		Comments		ntext NULL,
		-- This is the URL to the Microsoft support website for this bulletin.
		HelpUrl			nvarchar(256) NULL,
		-- The date the bulletin was released.
		DatePosted		datetime NOT NULL,
		-- The date the bulletin was updated.
		DateRevised		datetime NOT NULL,
		-- The version of the bulletin.
		Version			nvarchar(16) NULL DEFAULT '1,0,0,0',
		-- Whether there is an update available.
		UpdateAvailable		int NOT NULL DEFAULT 0,
		-- The state of the bulletin which determines where it is shown in the user interface.
		UIStateID		int NOT NULL DEFAULT 1,
		-- Set to one if the bulletin is not to be shown in the user interface.
		Hidden			int NOT NULL DEFAULT 0,
		-- Not used.
		PackageVersionID	int NULL,
		-- Not used.
		Errata			nvarchar(64) NULL,
		CONSTRAINT PK_SecurityBulletin
			PRIMARY KEY NONCLUSTERED(SecurityBulletinID),
		CONSTRAINT UQ_SecurityBulletin
			UNIQUE NONCLUSTERED(BulletinID)
	);

END
ELSE
	PRINT 'Using existing SecurityBulletin table'
GO

-- The SecurityBulletinToUserState table provides a mapping from the SecurityBulletin table to the current state of the bulletin.
IF NOT EXISTS (
	SELECT * FROM INFORMATION_SCHEMA.TABLES
	WHERE TABLE_NAME = 'SecurityBulletinToUserState'
)
BEGIN
	CREATE TABLE SecurityBulletinToUserState (
		-- Foreign key to the SecurityBulletin table.
		SecurityBulletinID	int NOT NULL,
		-- Foreign key to the SecurityUserState table.
		UserStateID		int NOT NULL,
		-- The date and time the state changed.
		DateChanged		datetime NOT NULL,
		-- A user comment that accompanies the state change.
		Comment			ntext NULL,
		-- The user who changed the state.
		Username		nvarchar(64) NOT NULL,
		-- Whether the security bulletin passed testing.
		Certified		int NOT NULL,
		CONSTRAINT FK_SecurityBulletinToUserState_SecurityBulletin
			FOREIGN KEY(SecurityBulletinID)
			REFERENCES SecurityBulletin(SecurityBulletinID),
		CONSTRAINT PK_SecurityBulletinToUserState
			PRIMARY KEY CLUSTERED(SecurityBulletinID, UserStateID)
	);

END
ELSE
	PRINT 'Using existing SecurityBulletinToUserState table'
GO

-- The SecurityBulletinRequires table contains a list of any bulletins that must be installed before this bulletin.
IF NOT EXISTS (
	SELECT * FROM INFORMATION_SCHEMA.TABLES
	WHERE TABLE_NAME = 'SecurityBulletinRequires'
)
BEGIN
	CREATE TABLE SecurityBulletinRequires (
		-- Artificial primary key for this table.
		SecurityBulletinRequiresID int IDENTITY NOT NULL,
		-- Foreign key to the SecurityBulletin table.
		SecurityBulletinID	int NOT NULL,
		-- Foreign key to the SecurityBulletin table that the SecurityBulletinID requires.
		RequiredBulletinID	int NOT NULL,
		-- The type of requirement. Only supports 0, which is a dependency requirement.
		Strength		int NOT NULL,
		CONSTRAINT FK_SecurityBulletinRequires_SecurityBulletin
			FOREIGN KEY(SecurityBulletinID)
			REFERENCES SecurityBulletin(SecurityBulletinID),
		CONSTRAINT FK_SecurityBulletinRequires2_SecurityBulletin
			FOREIGN KEY(RequiredBulletinID)
			REFERENCES SecurityBulletin(SecurityBulletinID),
		CONSTRAINT PK_SecurityBulletinRequires
			PRIMARY KEY NONCLUSTERED(SecurityBulletinRequiresID)
	);

	CREATE CLUSTERED INDEX SecurityBulletinRequiresByBulletinIDRequiredBulletinID
		ON SecurityBulletinRequires(SecurityBulletinID, Strength)

END
ELSE
	PRINT 'Using existing SecurityBulletinRequires table'
GO

-- The SecurityPatch table is ManageSoft's record of known security patches.
IF NOT EXISTS (
	SELECT * FROM INFORMATION_SCHEMA.TABLES
	WHERE TABLE_NAME = 'SecurityPatch'
)
BEGIN
	CREATE TABLE SecurityPatch (
		-- Synthetic primary key for this table.
		PatchID			int IDENTITY NOT NULL,
		-- Foreign key to the parent bulletin in the SecurityBulletin table.
		BulletinID		nvarchar(32) NOT NULL,
		-- The name of the security patch.
		PatchName		nvarchar(128) COLLATE Latin1_General_CS_AS NOT NULL,
		-- The URL to the patch executable.
		DownloadLocation	nvarchar(256) NOT NULL,
		-- The QNumber of the patch.
		QNumber			nvarchar(32) NOT NULL,
		-- The state of the patch.
		State			int NOT NULL DEFAULT 1,
		-- The command line options to be used when installing the security patch.
		InstallCommandLineOptions nvarchar(256) NULL,
		-- The command line options to be used when uninstalling the security patch.
		UnInstallCommandLineOptions nvarchar(256) NULL,
		-- The location of the patch executable that has been staged in the ManageSoft warehouse.
		StagedFile		nvarchar(512) NULL,
		-- Whether the patch is currently being downloaded.
		Downloading		int NOT NULL DEFAULT 0,
		-- Whether a patch should be included as part of the bulletin. Patches that are not incorporated are ignored by ManageSoft.
		Incorporate		int NOT NULL DEFAULT 1,
		-- Whether this patch is supported by the ManageSoft Security Patch Management System.
		Supported		int NOT NULL DEFAULT 0,
		-- This is a URL that the user enters if the DownloadLocation field is incorrect.
		ActualDownloadLocation	nvarchar(256) NOT NULL,
		-- Not used.
		LanguageID		int NOT NULL DEFAULT 1,
		CONSTRAINT FK_SecurityPatch_SecurityBulletin
			FOREIGN KEY(BulletinID)
			REFERENCES SecurityBulletin(BulletinID),
		CONSTRAINT PK_SecurityPatch
			PRIMARY KEY NONCLUSTERED(PatchID),
		CONSTRAINT UQ_SecurityPatch
			UNIQUE NONCLUSTERED(BulletinID, PatchName)
	);

END
ELSE
	PRINT 'Using existing SecurityPatch table'
GO

-- The SecurityPatchRequires table contains a list of any patches that must be installed before this patch.
IF NOT EXISTS (
	SELECT * FROM INFORMATION_SCHEMA.TABLES
	WHERE TABLE_NAME = 'SecurityPatchRequires'
)
BEGIN
	CREATE TABLE SecurityPatchRequires (
		-- Synthetic primary key.
		SecurityPatchRequiresID	int IDENTITY NOT NULL,
		-- Foreign key to the SecurityPatch table.
		PatchID			int NOT NULL,
		-- This is the patch that the PatchID requires. It is a foreign key to the SecurityPatch table.
		RequiredPatchID		int NOT NULL,
		-- The type of requirement. Only supports 0, which is a dependency requirement.
		Strength		int NOT NULL,
		CONSTRAINT FK_SecurityPatchRequires_SecurityPatch
			FOREIGN KEY(PatchID)
			REFERENCES SecurityPatch(PatchID),
		CONSTRAINT FK_SecurityPatchRequires2_SecurityPatch
			FOREIGN KEY(RequiredPatchID)
			REFERENCES SecurityPatch(PatchID),
		CONSTRAINT PK_SecurityPatchRequires
			PRIMARY KEY NONCLUSTERED(SecurityPatchRequiresID)
	);

	CREATE CLUSTERED INDEX SecurityPatchRequiresByPatchIDRequiredPatchID
		ON SecurityPatchRequires(PatchID, Strength)

END
ELSE
	PRINT 'Using existing SecurityPatchRequires table'
GO

-- The SecurityPatchToPackageVersion table provides a mapping between security patches and packages in the Software Library.
IF NOT EXISTS (
	SELECT * FROM INFORMATION_SCHEMA.TABLES
	WHERE TABLE_NAME = 'SecurityPatchToPackageVersion'
)
BEGIN
	CREATE TABLE SecurityPatchToPackageVersion (
		-- Foreign key to the SecurityPatch table.
		PatchID			int NOT NULL,
		-- Foreign key to the PackageVersion table. This is the package that contains the security patch.
		PackageFullName		nvarchar(256) NOT NULL,
		-- The name of the package.
		PackageName		nvarchar(64) NOT NULL,
		-- The version of the package.
		Version			nvarchar(32) NULL,
		CONSTRAINT FK_SecurityPatchToPackageVersion_SecurityPatch
			FOREIGN KEY(PatchID)
			REFERENCES SecurityPatch(PatchID),
		CONSTRAINT PK_SecurityPatchToPackageVersion
			PRIMARY KEY CLUSTERED(PatchID, PackageFullName)
	);

	CREATE NONCLUSTERED INDEX SecurityPatchToPackageVersionByPatchID
		ON SecurityPatchToPackageVersion(PatchID)

END
ELSE
	PRINT 'Using existing SecurityPatchToPackageVersion table'
GO

-- The SecurityState table describes the state of a security patch or bulletin.
IF NOT EXISTS (
	SELECT * FROM INFORMATION_SCHEMA.TABLES
	WHERE TABLE_NAME = 'SecurityState'
)
BEGIN
	CREATE TABLE SecurityState (
		-- Primary key.
		StateID			int IDENTITY NOT NULL,
		-- The description of the state.
		Description		nvarchar(64) NOT NULL,
		CONSTRAINT PK_SecurityState
			PRIMARY KEY CLUSTERED(StateID)
	);

END
ELSE
	PRINT 'Using existing SecurityState table'
GO

-- The SecurityUserState table describes the state of a security patch or bulletin.
IF NOT EXISTS (
	SELECT * FROM INFORMATION_SCHEMA.TABLES
	WHERE TABLE_NAME = 'SecurityUserState'
)
BEGIN
	CREATE TABLE SecurityUserState (
		-- Primary key.
		UserStateID		int IDENTITY NOT NULL,
		-- The description of the user state.
		Description		nvarchar(64) NOT NULL,
		CONSTRAINT PK_SecurityUserState
			PRIMARY KEY CLUSTERED(UserStateID)
	);

END
ELSE
	PRINT 'Using existing SecurityUserState table'
GO

-- The SecurityUIState table describes the state of a security patch or bulletin.
IF NOT EXISTS (
	SELECT * FROM INFORMATION_SCHEMA.TABLES
	WHERE TABLE_NAME = 'SecurityUIState'
)
BEGIN
	CREATE TABLE SecurityUIState (
		-- Primary key
		UIStateID		int IDENTITY NOT NULL,
		-- The description of the user interface state.
		Description		nvarchar(32) NOT NULL,
		CONSTRAINT PK_SecurityUIState
			PRIMARY KEY CLUSTERED(UIStateID)
	);

END
ELSE
	PRINT 'Using existing SecurityUIState table'
GO

-- The SecurityStateChange table records changes in the SecurityState table for security patches and bulletins.
IF NOT EXISTS (
	SELECT * FROM INFORMATION_SCHEMA.TABLES
	WHERE TABLE_NAME = 'SecurityStateChange'
)
BEGIN
	CREATE TABLE SecurityStateChange (
		-- Primary key.
		SecurityStateChangeID	int IDENTITY NOT NULL,
		-- The ID of the bulletin whose state was changed.
		BulletinID		nvarchar(32) NOT NULL,
		-- The state after it was changed.
		StateTo			int NOT NULL,
		-- The state before it was changed.
		StateFrom		int NOT NULL,
		-- The date the state was changed.
		DateChanged		datetime NOT NULL,
		-- The user comment that accompanies the state change.
		Comment			ntext NULL,
		-- The user who performed the change.
		Username		nvarchar(64) NOT NULL,
		CONSTRAINT FK_SecurityStateChange_SecurityState
			FOREIGN KEY(StateTo)
			REFERENCES SecurityState(StateID),
		CONSTRAINT FK_SecurityStateChange_SecurityState_From
			FOREIGN KEY(StateFrom)
			REFERENCES SecurityState(StateID),
		CONSTRAINT FK_SecurityStateChange_SecurityBulletin
			FOREIGN KEY(BulletinID)
			REFERENCES SecurityBulletin(BulletinID),
		CONSTRAINT PK_SecurityStateChange
			PRIMARY KEY NONCLUSTERED(SecurityStateChangeID),
		CONSTRAINT UQ_SecurityStateChange
			UNIQUE NONCLUSTERED(BulletinID, DateChanged)
	);

END
ELSE
	PRINT 'Using existing SecurityStateChange table'
GO

-- The SecurityUserStateChange table records changes in the SecurityUserState table for security bulletins.
IF NOT EXISTS (
	SELECT * FROM INFORMATION_SCHEMA.TABLES
	WHERE TABLE_NAME = 'SecurityUserStateChange'
)
BEGIN
	CREATE TABLE SecurityUserStateChange (
		-- Primary key.
		SecurityUserStateChangeID int IDENTITY NOT NULL,
		-- The ID of the bulletin whose state was changed.
		SecurityBulletinID	int NOT NULL,
		-- The UserState after it was changed.
		UserStateID		int NOT NULL,
		-- The date of the change.
		DateChanged		datetime NOT NULL,
		-- The user comment that accompanies the state change.
		Comment			ntext NULL,
		-- The user who performed the change.
		Username		nvarchar(64) NOT NULL,
		-- Whether the state was signed off after testing.
		Certified		int NOT NULL,
		CONSTRAINT FK_SecurityUserStateChange_SecurityState
			FOREIGN KEY(UserStateID)
			REFERENCES SecurityUserState(UserStateID),
		CONSTRAINT FK_SecurityUserStateChange_SecurityBulletin
			FOREIGN KEY(SecurityBulletinID)
			REFERENCES SecurityBulletin(SecurityBulletinID),
		CONSTRAINT PK_SecurityUserStateChange
			PRIMARY KEY NONCLUSTERED(SecurityUserStateChangeID)
	);

	CREATE NONCLUSTERED INDEX UQ_SecurityUserStateChange
		ON SecurityUserStateChange(SecurityBulletinID, DateChanged)

END
ELSE
	PRINT 'Using existing SecurityUserStateChange table'
GO

-- The SecurityAnalysisReport table records the last time that a computer reported security patch compliance data.
IF NOT EXISTS (
	SELECT * FROM INFORMATION_SCHEMA.TABLES
	WHERE TABLE_NAME = 'SecurityAnalysisReport'
)
BEGIN
	CREATE TABLE SecurityAnalysisReport (
		-- The ID of the computer. Foreign key into the Computer table.
		ComputerID		int NOT NULL,
		-- The date that the version of mssecure.xml was last updated on the client.
		DataSourceDate		datetime NOT NULL DEFAULT getdate(),
		-- The version of mssecure.xml that was last updated on the client
		DataSourceVersion	nvarchar(32) NULL,
		-- The time the compliance was performed on the client.
		AnalysisDate		datetime NOT NULL DEFAULT getdate(),
		-- When the Warehouse received the compliance report.
		ReceiveDate		datetime NOT NULL DEFAULT getdate(),
		CONSTRAINT PQ_SecurityAnalysisReport_ByComputer
			PRIMARY KEY NONCLUSTERED(ComputerID)
	);

	CREATE NONCLUSTERED INDEX SecurityAnalysisReport_ByDataSourceDate
		ON SecurityAnalysisReport(DataSourceDate)

END
ELSE
	PRINT 'Using existing SecurityAnalysisReport table'
GO

-- The SecurityPatchAnalysis table contains all the security patch compliance status entries for a computer.
IF NOT EXISTS (
	SELECT * FROM INFORMATION_SCHEMA.TABLES
	WHERE TABLE_NAME = 'SecurityPatchAnalysis'
)
BEGIN
	CREATE TABLE SecurityPatchAnalysis (
		-- Foreign key to the Computer table.
		ComputerID		int NOT NULL,
		-- The ID string of the bulletin from mssecure.
		BulletinID		nvarchar(32) NOT NULL,
		-- Foreign key into the SecurityPatch table.
		SecurityPatchID		int NOT NULL,
		-- The mssecure id of the product that this patch applies to.
		ProductID		int NULL,
		-- The mssecure id of the service pack that this patch applies to.
		ServicePackID		int NULL,
		-- Foreign key into the SecurityPatchStatus table.
		Status			int NOT NULL,
		-- Compliance message from the client.
		StatusMessage		nvarchar(3000) NULL,
		-- Whether this patch was installed by ManageSoft.
		IsManaged		bit NOT NULL DEFAULT 0,
		CONSTRAINT FK_SecurityPatchAnalysis_SecutityPatch
			FOREIGN KEY(SecurityPatchID)
			REFERENCES SecurityPatch(PatchID),
		CONSTRAINT PQ_SecurityPatchAnalysis_ByComputer
			PRIMARY KEY CLUSTERED(ComputerID, BulletinID, SecurityPatchID)
	);

	CREATE NONCLUSTERED INDEX SecurityPatchAnalysis_ByBulletin
		ON SecurityPatchAnalysis(BulletinID, ComputerID)

END
ELSE
	PRINT 'Using existing SecurityPatchAnalysis table'
GO

-- A list of statuses that are used in the SecurityPatchAnalysis table. Populated at database creation.
IF NOT EXISTS (
	SELECT * FROM INFORMATION_SCHEMA.TABLES
	WHERE TABLE_NAME = 'SecurityPatchStatus'
)
BEGIN
	CREATE TABLE SecurityPatchStatus (
		-- Primary key.
		SecurityPatchStatusID	int IDENTITY NOT NULL,
		-- The text representing the patch compliance status that is matched against the MSA file (client security patch compliance log).
		InternalText		nvarchar(64) NOT NULL,
		-- Friendly version of the InternalText.
		DisplayText		nvarchar(64) NOT NULL,
		-- Priority of each status value for ordering in the reports.
		Severity		int NOT NULL,
		CONSTRAINT PQ_SecurityPatchStatus
			PRIMARY KEY NONCLUSTERED(SecurityPatchStatusID),
		CONSTRAINT UQ_SecurityPatchStatus
			UNIQUE NONCLUSTERED(InternalText)
	);

END
ELSE
	PRINT 'Using existing SecurityPatchStatus table'
GO

-- The SecurityPatchUIProductGroup table maps products to the logical product groupings that appear in the Security Patch Management UI.
IF NOT EXISTS (
	SELECT * FROM INFORMATION_SCHEMA.TABLES
	WHERE TABLE_NAME = 'SecurityPatchUIProductGroup'
)
BEGIN
	CREATE TABLE SecurityPatchUIProductGroup (
		-- Primary key.
		SecurityPatchUIProductGroupID int IDENTITY NOT NULL,
		-- The name of the logical product group.
		GroupName		nvarchar(64) NOT NULL,
		-- The product name. This is a foreign key into the SecPatch_Product table.
		Product			nvarchar(128) NOT NULL,
		CONSTRAINT PQ_SecurityPatchUIProductGroup
			PRIMARY KEY NONCLUSTERED(SecurityPatchUIProductGroupID)
	);

	CREATE CLUSTERED INDEX SecurityPatchUIProductGroupByGroup
		ON SecurityPatchUIProductGroup(GroupName)

END
ELSE
	PRINT 'Using existing SecurityPatchUIProductGroup table'
GO

-- The SecurityPatchProductGroup table provides a mapping between products and ManageSoft environments that are used in the Packer.
IF NOT EXISTS (
	SELECT * FROM INFORMATION_SCHEMA.TABLES
	WHERE TABLE_NAME = 'SecurityPatchProductGroup'
)
BEGIN
	CREATE TABLE SecurityPatchProductGroup (
		-- Primary key.
		SecurityPatchProductGroupID int IDENTITY NOT NULL,
		-- The name of the ManageSoft environment to be used when a security patch affects the associated product.
		Environment		nvarchar(64) NOT NULL,
		-- The product that the environment is used for.
		Product			nvarchar(128) NOT NULL,
		CONSTRAINT PQ_SecurityPatchProductGroup
			PRIMARY KEY NONCLUSTERED(SecurityPatchProductGroupID)
	);

	CREATE NONCLUSTERED INDEX SecurityPatchProductGroupByEnvironment
		ON SecurityPatchProductGroup(Environment)

	CREATE CLUSTERED INDEX SecurityPatchProductGroupByProduct
		ON SecurityPatchProductGroup(Product)

END
ELSE
	PRINT 'Using existing SecurityPatchProductGroup table'
GO

-- The SecurityPatchProductUninstallValues table contains default uninstall commands for products.
IF NOT EXISTS (
	SELECT * FROM INFORMATION_SCHEMA.TABLES
	WHERE TABLE_NAME = 'SecurityPatchProductUninstallValues'
)
BEGIN
	CREATE TABLE SecurityPatchProductUninstallValues (
		-- Primary key.
		SecurityPatchProductUninstallValuesID int IDENTITY NOT NULL,
		-- The name of the product to set uninstall values for.
		Product			nvarchar(128) NOT NULL,
		-- The RegistryKey on the target system that contains the uninstall command line.
		RegistryKey		nvarchar(256) NOT NULL,
		-- The command line to uninstall the product.
		AbsoluteCommandLine	nvarchar(256) NOT NULL,
		-- The registry key in Add/Remove Programs that applies to the product.
		UninstallKey		nvarchar(128) NOT NULL,
		CONSTRAINT PK_SecurityPatchProductUninstallValues
			PRIMARY KEY NONCLUSTERED(SecurityPatchProductUninstallValuesID)
	);

	CREATE NONCLUSTERED INDEX SecurityPatchProductUninstallValuesByProduct
		ON SecurityPatchProductUninstallValues(Product)

END
ELSE
	PRINT 'Using existing SecurityPatchProductUninstallValues table'
GO

-- The SecurityPatchUninstallValues table contains uninstall commands that overide the defaults for a security patch.
IF NOT EXISTS (
	SELECT * FROM INFORMATION_SCHEMA.TABLES
	WHERE TABLE_NAME = 'SecurityPatchUninstallValues'
)
BEGIN
	CREATE TABLE SecurityPatchUninstallValues (
		-- Primary key.
		SecurityPatchUninstallValuesID int IDENTITY NOT NULL,
		-- Foreign key to the SecurityPatch table.
		SecurityPatchID		int NOT NULL,
		-- The RegistryKey on the target system that contains the uninstall command line.
		RegistryKey		nvarchar(256) NOT NULL,
		-- The command line to uninstall the product.
		AbsoluteCommandLine	nvarchar(256) NOT NULL,
		-- The registry key in Add/Remove Programs that applies to the product.
		UninstallKey		nvarchar(128) NOT NULL,
		CONSTRAINT FK_SecurityPatchUninstallValues_SecurityPatch
			FOREIGN KEY(SecurityPatchID)
			REFERENCES SecurityPatch(PatchID),
		CONSTRAINT PK_SecurityPatchUninstallValues
			PRIMARY KEY NONCLUSTERED(SecurityPatchUninstallValuesID)
	);

	CREATE CLUSTERED INDEX SecurityPatchUninstallValuesBySecurityPatchID
		ON SecurityPatchUninstallValues(SecurityPatchID)

END
ELSE
	PRINT 'Using existing SecurityPatchUninstallValues table'
GO

-- A resource (usually a file) that constitutes part of or the whole of a security patch.
IF NOT EXISTS (
	SELECT * FROM INFORMATION_SCHEMA.TABLES
	WHERE TABLE_NAME = 'SecurityPatchResource'
)
BEGIN
	CREATE TABLE SecurityPatchResource (
		-- Primary key.
		SecurityPatchResourceID	int IDENTITY NOT NULL,
		-- The security patch that the resource belongs to.
		SecurityPatchID		int NOT NULL,
		-- Original URL of the resource.
		ResourceURL		nvarchar(256) NOT NULL,
		-- The architecture that the resource is built for.
		ArchitectureID		int NOT NULL,
		-- The language that the resource is built for.
		LanguageID		int NOT NULL,
		-- The checksum for the resource
		Checksum		nvarchar(256) NULL,
		-- The actual URL of the resource.
		ActualResourceURL	nvarchar(256) NULL,
		-- The local path of the resource.
		LocalPath		nvarchar(256) NULL,
		CONSTRAINT FK_SecurityPatchResource_SecurityPatchID
			FOREIGN KEY(SecurityPatchID)
			REFERENCES SecurityPatch(PatchID),
		CONSTRAINT PQ_SecurityPatchResource
			PRIMARY KEY NONCLUSTERED
			(SecurityPatchID, ResourceURL, ArchitectureID, LanguageID),
		CONSTRAINT UQ_SecurityPatchResource
			UNIQUE NONCLUSTERED(SecurityPatchResourceID)
	);

END
ELSE
	PRINT 'Using existing SecurityPatchResource table'
GO

-- Security patch products suuported by ManageSoft
IF NOT EXISTS (
	SELECT * FROM INFORMATION_SCHEMA.TABLES
	WHERE TABLE_NAME = 'SecurityPatchProduct'
)
BEGIN
	CREATE TABLE SecurityPatchProduct (
		-- Primary key.
		SecurityPatchProductID	int IDENTITY NOT NULL,
		-- Vendor of the product.
		ProductVendor		nvarchar(64) NOT NULL,
		-- Name of the product.
		ProductName		nvarchar(128) NOT NULL,
		-- Version of the product.
		ProductVersion		nvarchar(64) NOT NULL,
		-- Packaging environment of the product.
		Environment		nvarchar(256) NULL,
		CONSTRAINT PQ_SecurityPatchProduct
			PRIMARY KEY NONCLUSTERED(ProductVendor, ProductName, ProductVersion),
		CONSTRAINT UQ_SecurityPatchProduct
			UNIQUE NONCLUSTERED(SecurityPatchProductID)
	);

END
ELSE
	PRINT 'Using existing SecurityPatchProduct table'
GO

-- A mapping between one or more products and resources.
IF NOT EXISTS (
	SELECT * FROM INFORMATION_SCHEMA.TABLES
	WHERE TABLE_NAME = 'SecurityPatchResourceProduct'
)
BEGIN
	CREATE TABLE SecurityPatchResourceProduct (
		-- Foreign key to SecurityPatchResource table.
		SecurityPatchResourceID	int NOT NULL,
		-- Foreign key to SecPatch_Product table.
		SecurityPatchProductID	int NOT NULL,
		CONSTRAINT FK_SecurityPatchResourceProduct_SecurityPatchResource
			FOREIGN KEY(SecurityPatchResourceID)
			REFERENCES SecurityPatchResource(SecurityPatchResourceID),
		CONSTRAINT FK_SecurityPatchResourceProduct_SecurityPatchProduct
			FOREIGN KEY(SecurityPatchProductID)
			REFERENCES SecurityPatchProduct(SecurityPatchProductID),
		CONSTRAINT PQ_SecurityPatchResourceProduct
			PRIMARY KEY NONCLUSTERED(SecurityPatchResourceID, SecurityPatchProductID)
	);

END
ELSE
	PRINT 'Using existing SecurityPatchResourceProduct table'
GO

-- Architecture identifies a target CPU (ABI), used to identify
-- on what type of computer a package may be installed
IF NOT EXISTS (
	SELECT * FROM INFORMATION_SCHEMA.TABLES
	WHERE TABLE_NAME = 'Architecture'
)
BEGIN
	CREATE TABLE Architecture (
		-- Auto-generated identity number
		ArchitectureID		int IDENTITY NOT NULL,
		-- Name of the computer architecture
		ArchitectureName	nvarchar(64) NOT NULL,
		CONSTRAINT PK_Architecture
			PRIMARY KEY NONCLUSTERED(ArchitectureName),
		CONSTRAINT UQ_Architecture
			UNIQUE CLUSTERED(ArchitectureID)
	);

END
ELSE
	PRINT 'Using existing Architecture table'
GO

-- The Language table contains a list of languages that there may be security patches for.
IF NOT EXISTS (
	SELECT * FROM INFORMATION_SCHEMA.TABLES
	WHERE TABLE_NAME = 'Language'
)
BEGIN
	CREATE TABLE Language (
		-- Primary key.
		LanguageID		int IDENTITY NOT NULL,
		-- The name of the language. E.g. EN-US.
		[Name]			nvarchar(10) NOT NULL,
		CONSTRAINT PK_Language
			PRIMARY KEY NONCLUSTERED([Name]),
		CONSTRAINT UQ_Language
			UNIQUE NONCLUSTERED(LanguageID)
	);

END
ELSE
	PRINT 'Using existing Language table'
GO


IF NOT EXISTS(SELECT * FROM Architecture)
BEGIN
	SET IDENTITY_INSERT Architecture ON
	INSERT INTO Architecture (ArchitectureID, ArchitectureName)
		VALUES (1, 'i386')
	INSERT INTO Architecture (ArchitectureID, ArchitectureName)
		VALUES (2, 'i586')
	INSERT INTO Architecture (ArchitectureID, ArchitectureName)
		VALUES (3, 'i686')
	INSERT INTO Architecture (ArchitectureID, ArchitectureName)
		VALUES (4, 'athlon')
	INSERT INTO Architecture (ArchitectureID, ArchitectureName)
		VALUES (5, 'noarch')
	INSERT INTO Architecture (ArchitectureID, ArchitectureName)
		VALUES (6, 'pa-risc32')
	INSERT INTO Architecture (ArchitectureID, ArchitectureName)
		VALUES (7, 'pa-risc64')
	INSERT INTO Architecture (ArchitectureID, ArchitectureName)
		VALUES (8, 'itanium')
	INSERT INTO Architecture (ArchitectureID, ArchitectureName)
		VALUES (9, 'sparc')
	SET IDENTITY_INSERT Architecture OFF
END

IF NOT EXISTS (
        SELECT *
        FROM INFORMATION_SCHEMA.CONSTRAINT_COLUMN_USAGE
        WHERE CONSTRAINT_NAME = 'FK_AffectedProduct_Patch'
)
BEGIN
        PRINT 'Create FK_AffectedProduct_Patch constraint'

        ALTER TABLE SecPatch_AffectedProduct
	        ADD CONSTRAINT FK_AffectedProduct_Patch
		FOREIGN KEY(PatchID)
		REFERENCES SecPatch_Patch(PatchID)
END
ELSE
        PRINT 'Using existing FK_AffectedProduct_Patch constraint'
IF NOT EXISTS (
        SELECT *
        FROM INFORMATION_SCHEMA.CONSTRAINT_COLUMN_USAGE
        WHERE CONSTRAINT_NAME = 'FK_AffectedProduct_Product'
)
BEGIN
        PRINT 'Create FK_AffectedProduct_Product constraint'

        ALTER TABLE SecPatch_AffectedProduct
	        ADD CONSTRAINT FK_AffectedProduct_Product
		FOREIGN KEY(ProductID)
		REFERENCES SecPatch_Product(ProductID)
END
ELSE
        PRINT 'Using existing FK_AffectedProduct_Product constraint'
IF NOT EXISTS (
        SELECT *
        FROM INFORMATION_SCHEMA.CONSTRAINT_COLUMN_USAGE
        WHERE CONSTRAINT_NAME = 'FK_AffectedServicePack_ServicePack'
)
BEGIN
        PRINT 'Create FK_AffectedServicePack_ServicePack constraint'

        ALTER TABLE SecPatch_AffectedServicePack
	        ADD CONSTRAINT FK_AffectedServicePack_ServicePack
		FOREIGN KEY(ServicePackID)
		REFERENCES SecPatch_ServicePack(ServicePackID)
END
ELSE
        PRINT 'Using existing FK_AffectedServicePack_ServicePack constraint'
IF NOT EXISTS (
        SELECT *
        FROM INFORMATION_SCHEMA.CONSTRAINT_COLUMN_USAGE
        WHERE CONSTRAINT_NAME = 'FK_AvailableSP_Product'
)
BEGIN
        PRINT 'Create FK_AvailableSP_Product constraint'

        ALTER TABLE SecPatch_AvailableSP
	        ADD CONSTRAINT FK_AvailableSP_Product
		FOREIGN KEY(ProductID)
		REFERENCES SecPatch_Product(ProductID)
END
ELSE
        PRINT 'Using existing FK_AvailableSP_Product constraint'
IF NOT EXISTS (
        SELECT *
        FROM INFORMATION_SCHEMA.CONSTRAINT_COLUMN_USAGE
        WHERE CONSTRAINT_NAME = 'FK_AvailableSP_ServicePack'
)
BEGIN
        PRINT 'Create FK_AvailableSP_ServicePack constraint'

        ALTER TABLE SecPatch_AvailableSP
	        ADD CONSTRAINT FK_AvailableSP_ServicePack
		FOREIGN KEY(ServicePackID)
		REFERENCES SecPatch_ServicePack(ServicePackID)
END
ELSE
        PRINT 'Using existing FK_AvailableSP_ServicePack constraint'
IF NOT EXISTS (
        SELECT *
        FROM INFORMATION_SCHEMA.CONSTRAINT_COLUMN_USAGE
        WHERE CONSTRAINT_NAME = 'FK_File_Location'
)
BEGIN
        PRINT 'Create FK_File_Location constraint'

        ALTER TABLE SecPatch_File
	        ADD CONSTRAINT FK_File_Location
		FOREIGN KEY(LocationID)
		REFERENCES SecPatch_Location(LocationID)
END
ELSE
        PRINT 'Using existing FK_File_Location constraint'
IF NOT EXISTS (
        SELECT *
        FROM INFORMATION_SCHEMA.CONSTRAINT_COLUMN_USAGE
        WHERE CONSTRAINT_NAME = 'FK_BulletinComment_Bulletin'
)
BEGIN
        PRINT 'Create FK_BulletinComment_Bulletin constraint'

        ALTER TABLE SecPatch_BulletinComment
	        ADD CONSTRAINT FK_BulletinComment_Bulletin
		FOREIGN KEY(BulletinID)
		REFERENCES SecPatch_Bulletin(BulletinID)
END
ELSE
        PRINT 'Using existing FK_BulletinComment_Bulletin constraint'
IF NOT EXISTS (
        SELECT *
        FROM INFORMATION_SCHEMA.CONSTRAINT_COLUMN_USAGE
        WHERE CONSTRAINT_NAME = 'FK_qNumber_Bulletin'
)
BEGIN
        PRINT 'Create FK_qNumber_Bulletin constraint'

        ALTER TABLE SecPatch_QNumber
	        ADD CONSTRAINT FK_qNumber_Bulletin
		FOREIGN KEY(BulletinID)
		REFERENCES SecPatch_Bulletin(BulletinID)
END
ELSE
        PRINT 'Using existing FK_qNumber_Bulletin constraint'
IF NOT EXISTS (
        SELECT *
        FROM INFORMATION_SCHEMA.CONSTRAINT_COLUMN_USAGE
        WHERE CONSTRAINT_NAME = 'FK_Patch_Bulletin'
)
BEGIN
        PRINT 'Create FK_Patch_Bulletin constraint'

        ALTER TABLE SecPatch_Patch
	        ADD CONSTRAINT FK_Patch_Bulletin
		FOREIGN KEY(BulletinID)
		REFERENCES SecPatch_Bulletin(BulletinID)
END
ELSE
        PRINT 'Using existing FK_Patch_Bulletin constraint'
IF NOT EXISTS (
        SELECT *
        FROM INFORMATION_SCHEMA.CONSTRAINT_COLUMN_USAGE
        WHERE CONSTRAINT_NAME = 'FK_Patch_SecurityPatch'
)
BEGIN
        PRINT 'Create FK_Patch_SecurityPatch constraint'

        ALTER TABLE SecPatch_Patch
	        ADD CONSTRAINT FK_Patch_SecurityPatch
		FOREIGN KEY(SecurityPatchID)
		REFERENCES SecurityPatch(PatchID)
END
ELSE
        PRINT 'Using existing FK_Patch_SecurityPatch constraint'
IF NOT EXISTS (
        SELECT *
        FROM INFORMATION_SCHEMA.CONSTRAINT_COLUMN_USAGE
        WHERE CONSTRAINT_NAME = 'FK_FileChg_FileChange'
)
BEGIN
        PRINT 'Create FK_FileChg_FileChange constraint'

        ALTER TABLE SecPatch_FileChg
	        ADD CONSTRAINT FK_FileChg_FileChange
		FOREIGN KEY(FileChangeID)
		REFERENCES SecPatch_FileChange(FileChangeID)
END
ELSE
        PRINT 'Using existing FK_FileChg_FileChange constraint'
IF NOT EXISTS (
        SELECT *
        FROM INFORMATION_SCHEMA.CONSTRAINT_COLUMN_USAGE
        WHERE CONSTRAINT_NAME = 'FK_SupercededPatch_Bulletin'
)
BEGIN
        PRINT 'Create FK_SupercededPatch_Bulletin constraint'

        ALTER TABLE SecPatch_SupercededPatch
	        ADD CONSTRAINT FK_SupercededPatch_Bulletin
		FOREIGN KEY(BulletinID)
		REFERENCES SecPatch_Bulletin(BulletinID)
END
ELSE
        PRINT 'Using existing FK_SupercededPatch_Bulletin constraint'
IF NOT EXISTS (
        SELECT *
        FROM INFORMATION_SCHEMA.CONSTRAINT_COLUMN_USAGE
        WHERE CONSTRAINT_NAME = 'FK_SecurityBulletin_SecurityState'
)
BEGIN
        PRINT 'Create FK_SecurityBulletin_SecurityState constraint'

        ALTER TABLE SecurityBulletin
	        ADD CONSTRAINT FK_SecurityBulletin_SecurityState
		FOREIGN KEY(State)
		REFERENCES SecurityState(StateID)
END
ELSE
        PRINT 'Using existing FK_SecurityBulletin_SecurityState constraint'
IF NOT EXISTS (
        SELECT *
        FROM INFORMATION_SCHEMA.CONSTRAINT_COLUMN_USAGE
        WHERE CONSTRAINT_NAME = 'FK_SecurityBulletinToUserState_SecurityUserState'
)
BEGIN
        PRINT 'Create FK_SecurityBulletinToUserState_SecurityUserState constraint'

        ALTER TABLE SecurityBulletinToUserState
	        ADD CONSTRAINT FK_SecurityBulletinToUserState_SecurityUserState
		FOREIGN KEY(UserStateID)
		REFERENCES SecurityUserState(UserStateID)
END
ELSE
        PRINT 'Using existing FK_SecurityBulletinToUserState_SecurityUserState constraint'
IF NOT EXISTS (
        SELECT *
        FROM INFORMATION_SCHEMA.CONSTRAINT_COLUMN_USAGE
        WHERE CONSTRAINT_NAME = 'FK_SecurityPatch_SecurityState'
)
BEGIN
        PRINT 'Create FK_SecurityPatch_SecurityState constraint'

        ALTER TABLE SecurityPatch
	        ADD CONSTRAINT FK_SecurityPatch_SecurityState
		FOREIGN KEY(State)
		REFERENCES SecurityState(StateID)
END
ELSE
        PRINT 'Using existing FK_SecurityPatch_SecurityState constraint'
IF NOT EXISTS (
        SELECT *
        FROM INFORMATION_SCHEMA.CONSTRAINT_COLUMN_USAGE
        WHERE CONSTRAINT_NAME = 'FK_SecurityPatchAnalysis_SecutityPatchStatus'
)
BEGIN
        PRINT 'Create FK_SecurityPatchAnalysis_SecutityPatchStatus constraint'

        ALTER TABLE SecurityPatchAnalysis
	        ADD CONSTRAINT FK_SecurityPatchAnalysis_SecutityPatchStatus
		FOREIGN KEY(Status)
		REFERENCES SecurityPatchStatus(SecurityPatchStatusID)
END
ELSE
        PRINT 'Using existing FK_SecurityPatchAnalysis_SecutityPatchStatus constraint'
IF NOT EXISTS (
        SELECT *
        FROM INFORMATION_SCHEMA.CONSTRAINT_COLUMN_USAGE
        WHERE CONSTRAINT_NAME = 'FK_SecurityPatchResource_Architecture'
)
BEGIN
        PRINT 'Create FK_SecurityPatchResource_Architecture constraint'

        ALTER TABLE SecurityPatchResource
	        ADD CONSTRAINT FK_SecurityPatchResource_Architecture
		FOREIGN KEY(ArchitectureID)
		REFERENCES Architecture(ArchitectureID)
END
ELSE
        PRINT 'Using existing FK_SecurityPatchResource_Architecture constraint'
