USE ManageSoft
GO

-- The SecPatch_AffectedProduct table contains the products and service packs
-- affected by a security patch.
IF NOT EXISTS (
	SELECT * FROM INFORMATION_SCHEMA.TABLES
	WHERE TABLE_NAME = 'SecPatch_AffectedProduct'
)
BEGIN
	CREATE TABLE SecPatch_AffectedProduct (
		-- Primary key.
		AffectedProductID	int IDENTITY NOT NULL,
		-- Foreign key to the SecPatch_Product table.
		ProductID		int NOT NULL,
		-- Foreign key to the SecPatch_ServicePack table. Maps to service pack id.
		FixedInSP		int NOT NULL,
		-- Foreign key to the SecPatch_Patch table.
		PatchID			int NOT NULL,
		CONSTRAINT PK_AffectedProduct
			PRIMARY KEY CLUSTERED(AffectedProductID),
		CONSTRAINT UQ_AffectedProduct
			UNIQUE NONCLUSTERED(ProductID, PatchID)
	);

	CREATE NONCLUSTERED INDEX AffectedProductByPatchID
		ON SecPatch_AffectedProduct(PatchID)

END
ELSE
	PRINT 'Using existing SecPatch_AffectedProduct table'
GO

-- The SecPatch_AffectedServicePack table contains the service packs that a
-- product applies to for a security patch.
IF NOT EXISTS (
	SELECT * FROM INFORMATION_SCHEMA.TABLES
	WHERE TABLE_NAME = 'SecPatch_AffectedServicePack'
)
BEGIN
	CREATE TABLE SecPatch_AffectedServicePack (
		-- Primary key.
		AffectedServicePackID	int IDENTITY NOT NULL,
		-- Foreign key to the SecPatch_AffectedProduct table.
		AffectedProductID	int NOT NULL,
		-- Foreign key to the SecPatch_ServicePack table.
		ServicePackID		int NOT NULL,
		CONSTRAINT FK_AffectedServicePack_AffectedProduct
			FOREIGN KEY(AffectedProductID)
			REFERENCES SecPatch_AffectedProduct(AffectedProductID) ON DELETE CASCADE,
		CONSTRAINT PK_AffectedServicePack
			PRIMARY KEY NONCLUSTERED(AffectedServicePackID),
		CONSTRAINT UQ_AffectedServicePack
			UNIQUE CLUSTERED(AffectedProductID, ServicePackID)
	);

	CREATE NONCLUSTERED INDEX AffectedServicePackByAffectedProductID
		ON SecPatch_AffectedServicePack(AffectedProductID)

END
ELSE
	PRINT 'Using existing SecPatch_AffectedServicePack table'
GO

-- The SecPatch_Comment table contains descriptive text about security patches and bulletins.
IF NOT EXISTS (
	SELECT * FROM INFORMATION_SCHEMA.TABLES
	WHERE TABLE_NAME = 'SecPatch_Comment'
)
BEGIN
	CREATE TABLE SecPatch_Comment (
		-- Primary key.
		CommentID		int NOT NULL,
		-- Text describing a security patch or bulletin.
		Text			ntext NOT NULL,
		CONSTRAINT PK_Comment
			PRIMARY KEY CLUSTERED(CommentID)
	);

END
ELSE
	PRINT 'Using existing SecPatch_Comment table'
GO

-- The SecPatch_Location table contains URLs and file and registry locations used
-- by security patches and bulletins and is referred to by file and registry entries within a patch.
IF NOT EXISTS (
	SELECT * FROM INFORMATION_SCHEMA.TABLES
	WHERE TABLE_NAME = 'SecPatch_Location'
)
BEGIN
	CREATE TABLE SecPatch_Location (
		-- Primary key.
		LocationID		int NOT NULL,
		-- URL to a file or registry location used by a security patch or bulletin.
		Path			nvarchar(256) NOT NULL,
		-- Whether the location is an absolute path or not.
		AbsolutePath		nvarchar(6) NOT NULL,
		CONSTRAINT PK_Location
			PRIMARY KEY CLUSTERED(LocationID)
	);

END
ELSE
	PRINT 'Using existing SecPatch_Location table'
GO

-- The SecPatch_Product table contains all the products that Microsoft has published security patches for.
IF NOT EXISTS (
	SELECT * FROM INFORMATION_SCHEMA.TABLES
	WHERE TABLE_NAME = 'SecPatch_Product'
)
BEGIN
	CREATE TABLE SecPatch_Product (
		-- Primary key.
		ProductID		int IDENTITY NOT NULL,
		-- Name of this product.
		[Name]			nvarchar(80) NOT NULL,
		-- The least recent service pack that is supported for this product.
		MinimumSupportedServicePackID int NULL,
		-- The most recently released service pack for this product.
		CurrentServicePackID	int NULL,
		-- The most recently released version of this product.
		CurrentVersion		nvarchar(50) NULL,
		CONSTRAINT PK_Product
			PRIMARY KEY NONCLUSTERED([Name]),
		CONSTRAINT UQ_Product
			UNIQUE NONCLUSTERED(ProductID)
	);

END
ELSE
	PRINT 'Using existing SecPatch_Product table'
GO

-- The SecPatch_ServicePack table contains all the service packs for products that have
-- security patches published for them.
IF NOT EXISTS (
	SELECT * FROM INFORMATION_SCHEMA.TABLES
	WHERE TABLE_NAME = 'SecPatch_ServicePack'
)
BEGIN
	CREATE TABLE SecPatch_ServicePack (
		-- Primary key.
		ServicePackID		int NOT NULL,
		-- The name of the service pack.
		[Name]			nvarchar(50) NOT NULL,
		-- The URL from which the service pack can be retrieved.
		URL			nvarchar(256) NULL,
		-- The release date of the service pack.
		ReleaseDate		datetime NULL,
		CONSTRAINT PK_ServicePack
			PRIMARY KEY CLUSTERED(ServicePackID)
	);

END
ELSE
	PRINT 'Using existing SecPatch_ServicePack table'
GO

-- The SecPatch_Severity table contains descriptions of the severity of security bulletins.
IF NOT EXISTS (
	SELECT * FROM INFORMATION_SCHEMA.TABLES
	WHERE TABLE_NAME = 'SecPatch_Severity'
)
BEGIN
	CREATE TABLE SecPatch_Severity (
		-- Primary key.
		SeverityID		char(10) NOT NULL,
		-- Descriptive text of the severity of a security bulletin.
		Description		nvarchar(50) NULL,
		CONSTRAINT PK_Severity
			PRIMARY KEY CLUSTERED(SeverityID)
	);

END
ELSE
	PRINT 'Using existing SecPatch_Severity table'
GO

-- The SecurityPatchSupersede table contains a list of patches that supersede other patches.
IF NOT EXISTS (
	SELECT * FROM INFORMATION_SCHEMA.TABLES
	WHERE TABLE_NAME = 'SecurityPatchSupersede'
)
BEGIN
	CREATE TABLE SecurityPatchSupersede (
		-- Foreign key for security patch that superseds another patch.
		NewSecurityPatchID	int NOT NULL,
		-- Foreign key for security patch that has been superseded.
		OldSecurityPatchID	int NOT NULL,
		CONSTRAINT PK_SecurityPatchSupersede
			PRIMARY KEY NONCLUSTERED(NewSecurityPatchID, OldSecurityPatchID)
	);

	CREATE NONCLUSTERED INDEX SecurityPatchSupersedeByOldSecurityPatch
		ON SecurityPatchSupersede(OldSecurityPatchID)

END
ELSE
	PRINT 'Using existing SecurityPatchSupersede table'
GO

-- The SecPatch_ProductFamily table defines product groupings used by security patches.
IF NOT EXISTS (
	SELECT * FROM INFORMATION_SCHEMA.TABLES
	WHERE TABLE_NAME = 'SecPatch_ProductFamily'
)
BEGIN
	CREATE TABLE SecPatch_ProductFamily (
		-- Primary key.
		ProductFamilyID		int NOT NULL,
		-- The name of the product family.
		[Name]			nvarchar(50) NOT NULL,
		-- Foreign key to the SecPatch_Product table.
		RecentProductVersionID	int NULL,
		CONSTRAINT PK_ProductFamily
			PRIMARY KEY CLUSTERED(ProductFamilyID)
	);

END
ELSE
	PRINT 'Using existing SecPatch_ProductFamily table'
GO

-- The SecPatch_ProductProductFamily table defines product groupings used by security patches.
IF NOT EXISTS (
	SELECT * FROM INFORMATION_SCHEMA.TABLES
	WHERE TABLE_NAME = 'SecPatch_ProductProductFamily'
)
BEGIN
	CREATE TABLE SecPatch_ProductProductFamily (
		-- Primary key.
		ProductProductFamilyID	int IDENTITY NOT NULL,
		-- Foreign key to the SecPatch_Product table.
		ProductID		int NOT NULL,
		-- Foreign key to the SecPatch_ProductFamily table.
		ProductFamilyID		int NOT NULL,
		CONSTRAINT FK_ProductProductFamily_ProductFamily
			FOREIGN KEY(ProductFamilyID)
			REFERENCES SecPatch_ProductFamily(ProductFamilyID) ON DELETE CASCADE,
		CONSTRAINT FK_ProductProductFamily_Product
			FOREIGN KEY(ProductID)
			REFERENCES SecPatch_Product(ProductID) ON DELETE CASCADE,
		CONSTRAINT UQ_ProductProductFamily
			UNIQUE NONCLUSTERED(ProductID, ProductFamilyID)
	);

END
ELSE
	PRINT 'Using existing SecPatch_ProductProductFamily table'
GO

-- The SecPatch_BulletinComment table is a mapping between SecPatch_Bulletin and the SecPatch_Comment table.
IF NOT EXISTS (
	SELECT * FROM INFORMATION_SCHEMA.TABLES
	WHERE TABLE_NAME = 'SecPatch_BulletinComment'
)
BEGIN
	CREATE TABLE SecPatch_BulletinComment (
		-- Primary key.
		BulletinCommentID	int IDENTITY NOT NULL,
		-- Foreign key to the SecPatch_Comment table.
		CommentID		int NOT NULL,
		-- Foreign key to the SecPatch_Bulletin table.
		BulletinID		nvarchar(50) NOT NULL,
		CONSTRAINT FK_BulletinComment_Comment
			FOREIGN KEY(CommentID)
			REFERENCES SecPatch_Comment(CommentID) ON DELETE CASCADE,
		CONSTRAINT PK_BulletinComment
			PRIMARY KEY CLUSTERED(BulletinCommentID),
		CONSTRAINT UQ_BulletinComment
			UNIQUE NONCLUSTERED(CommentID, BulletinID)
	);

END
ELSE
	PRINT 'Using existing SecPatch_BulletinComment table'
GO

-- The SecPatch_QNumber table contains "Qnumbers" which are the identifier that Microsoft uses for security bulletins.
IF NOT EXISTS (
	SELECT * FROM INFORMATION_SCHEMA.TABLES
	WHERE TABLE_NAME = 'SecPatch_QNumber'
)
BEGIN
	CREATE TABLE SecPatch_QNumber (
		-- The "Qnumber" for this security bulletin.
		qNumber			nvarchar(50) NOT NULL,
		-- Foreign key to the SecPatch_Bulletin table.
		BulletinID		nvarchar(50) NOT NULL,
		CONSTRAINT PK_qNumber
			PRIMARY KEY CLUSTERED(qNumber)
	);

END
ELSE
	PRINT 'Using existing SecPatch_QNumber table'
GO

-- The SecPatch_Patch table contains security patches.
IF NOT EXISTS (
	SELECT * FROM INFORMATION_SCHEMA.TABLES
	WHERE TABLE_NAME = 'SecPatch_Patch'
)
BEGIN
	CREATE TABLE SecPatch_Patch (
		-- Primary key.
		PatchID			int IDENTITY NOT NULL,
		-- The name of this security patch.
		PatchName		nvarchar(128) COLLATE Latin1_General_CS_AS NOT NULL,
		-- Foreign key to the SecPatch_Bulletin table.
		BulletinID		nvarchar(50) NOT NULL,
		-- Foreign key to the SecPatch_Location table.
		PatchLocationID		int NOT NULL,
		-- The SQNumber for this security patch.
		SQNumber		nvarchar(50) NOT NULL,
		-- Whether this security patch requires a reboot or not.
		NoReboot		int NOT NULL,
		-- Foreign key to the SecurityPatch table.
		SecurityPatchID		int NOT NULL,
		CONSTRAINT FK_Patch_Location
			FOREIGN KEY(PatchLocationID)
			REFERENCES SecPatch_Location(LocationID) ON DELETE CASCADE,
		CONSTRAINT PK_Patch
			PRIMARY KEY CLUSTERED(PatchID),
		CONSTRAINT UQ_Patch
			UNIQUE NONCLUSTERED(BulletinID, PatchName),
		CONSTRAINT UQ_PatchSecurityPatchID
			UNIQUE NONCLUSTERED(SecurityPatchID)
	);

	CREATE NONCLUSTERED INDEX IN_Patch
		ON SecPatch_Patch(PatchName)

END
ELSE
	PRINT 'Using existing SecPatch_Patch table'
GO

-- The SecPatch_PatchComment table is a mapping between SecPatch_Patch and the SecPatch_Comment table.
IF NOT EXISTS (
	SELECT * FROM INFORMATION_SCHEMA.TABLES
	WHERE TABLE_NAME = 'SecPatch_PatchComment'
)
BEGIN
	CREATE TABLE SecPatch_PatchComment (
		-- Primary key.
		PatchCommentID		int IDENTITY NOT NULL,
		-- Foreign key to the SecPatch_Comment table.
		CommentID		int NOT NULL,
		-- Foreign key to the SecPatch_Patch table.
		PatchID			int NOT NULL,
		CONSTRAINT FK_PatchComment_Comment
			FOREIGN KEY(CommentID)
			REFERENCES SecPatch_Comment(CommentID) ON DELETE CASCADE,
		CONSTRAINT FK_PatchComment_Patch
			FOREIGN KEY(PatchID)
			REFERENCES SecPatch_Patch(PatchID) ON DELETE CASCADE,
		CONSTRAINT PK_PatchComment
			PRIMARY KEY CLUSTERED(PatchCommentID),
		CONSTRAINT UQ_PatchComment
			UNIQUE NONCLUSTERED(CommentID, PatchID)
	);

END
ELSE
	PRINT 'Using existing SecPatch_PatchComment table'
GO

-- The SecPatch_Bulletin table describes security bulletins.
IF NOT EXISTS (
	SELECT * FROM INFORMATION_SCHEMA.TABLES
	WHERE TABLE_NAME = 'SecPatch_Bulletin'
)
BEGIN
	CREATE TABLE SecPatch_Bulletin (
		-- Primary key.
		BulletinID		nvarchar(50) NOT NULL,
		-- Foreign key to the SecPatch_Location table.
		BulletinLocationID	int NOT NULL,
		-- Foreign key to the SecPatch_Location table. This is the location of the FAQ document for this security bulletin.
		FAQLocationID		int NULL,
		-- The title text of this bulletin.
		Title			nvarchar(128) NULL,
		-- The date this security bulletin was posted.
		DatePosted		datetime NULL,
		-- The date this security bulletin was last revised.
		DateRevised		datetime NULL,
		-- Whether this security bulletin is still supported or not.
		Supported		nvarchar(10) NOT NULL,
		-- The summary text for this security bulletin.
		Summary			ntext NULL,
		-- The text describing the issue solved by this security bulletin.
		Issue			ntext NULL,
		-- Foreign key to the SecPatch_Severity table.
		ImpactSeverityID	char(10) NOT NULL,
		-- Foreign key to the SecPatch_Severity table.
		PreReqSeverityID	char(10) NOT NULL,
		-- Foreign key to the SecPatch_Severity table.
		MitigationSeverityID	char(10) NOT NULL,
		-- Foreign key to the SecPatch_Severity table.
		PopularitySeverityID	char(10) NOT NULL,
		CONSTRAINT FK_Bulletin_Location
			FOREIGN KEY(BulletinLocationID)
			REFERENCES SecPatch_Location(LocationID) ON DELETE NO ACTION,
		CONSTRAINT FK_Bulletin_Location1
			FOREIGN KEY(FAQLocationID)
			REFERENCES SecPatch_Location(LocationID) ON DELETE NO ACTION,
		CONSTRAINT PK_Bulletin
			PRIMARY KEY CLUSTERED(BulletinID)
	);

END
ELSE
	PRINT 'Using existing SecPatch_Bulletin table'
GO

-- The SecurityBulletin table is the ManageSoft record of known security bulletins.
IF NOT EXISTS (
	SELECT * FROM INFORMATION_SCHEMA.TABLES
	WHERE TABLE_NAME = 'SecurityBulletin'
)
BEGIN
	CREATE TABLE SecurityBulletin (
		-- The artificial primary key.
		SecurityBulletinID	int IDENTITY NOT NULL,
		-- The name of the security bulletin. This is a unique key.
		BulletinID		nvarchar(32) NOT NULL,
		-- The severity of the security bulletin.
		Severity		int NOT NULL,
		-- The state of the security bulletin.
		State			int NOT NULL DEFAULT 1,
		-- Operator comments about this bulletin that are entered from the ManageSoft user interface.
		Comments		ntext NULL,
		-- This is the URL to the Microsoft support website for this bulletin.
		HelpUrl			nvarchar(256) NULL,
		-- The date the bulletin was released.
		DatePosted		datetime NOT NULL,
		-- The date the bulletin was updated.
		DateRevised		datetime NOT NULL,
		-- The version of the bulletin.
		Version			nvarchar(16) NULL DEFAULT '1,0,0,0',
		-- Whether there is an update available.
		UpdateAvailable		int NOT NULL DEFAULT 0,
		-- The state of the bulletin which determines where it is shown in the user interface.
		UIStateID		int NOT NULL DEFAULT 1,
		-- Set to 1 when the bulletin is deployed.
		Hidden			int NOT NULL DEFAULT 0,
		-- Not used.
		PackageVersionID	int NULL,
		-- Not used.
		Errata			nvarchar(64) NULL,
		-- Set to one if the bulletin is not to be shown in the user interface.
		-- Only bulletins that have been manually hidden have this value set.
		-- Bulletins that are hidden because of OS/product/language/architecture filters set UIStateID=Hidden instead.
		Ignore			int NOT NULL DEFAULT 0,
		CONSTRAINT PK_SecurityBulletin
			PRIMARY KEY NONCLUSTERED(SecurityBulletinID),
		CONSTRAINT UQ_SecurityBulletin
			UNIQUE NONCLUSTERED(BulletinID)
	);

	CREATE NONCLUSTERED INDEX SecurityBulletinByErrata
		ON SecurityBulletin(Errata)

END
ELSE
	PRINT 'Using existing SecurityBulletin table'
GO

-- The SecurityBulletinToUserState table provides a mapping from the SecurityBulletin table to the current state of the bulletin.
IF NOT EXISTS (
	SELECT * FROM INFORMATION_SCHEMA.TABLES
	WHERE TABLE_NAME = 'SecurityBulletinToUserState'
)
BEGIN
	CREATE TABLE SecurityBulletinToUserState (
		-- Foreign key to the SecurityBulletin table.
		SecurityBulletinID	int NOT NULL,
		-- Foreign key to the SecurityUserState table.
		UserStateID		int NOT NULL,
		-- The date and time the state changed.
		DateChanged		datetime NOT NULL,
		-- A user comment that accompanies the state change.
		Comment			ntext NULL,
		-- The user who changed the state.
		Username		nvarchar(64) NOT NULL,
		-- Whether the security bulletin passed testing.
		Certified		int NOT NULL,
		CONSTRAINT FK_SecurityBulletinToUserState_SecurityBulletin
			FOREIGN KEY(SecurityBulletinID)
			REFERENCES SecurityBulletin(SecurityBulletinID) ON DELETE CASCADE,
		CONSTRAINT PK_SecurityBulletinToUserState
			PRIMARY KEY CLUSTERED(SecurityBulletinID, UserStateID)
	);

END
ELSE
	PRINT 'Using existing SecurityBulletinToUserState table'
GO

-- The SecurityBulletinRequires table contains a list of any bulletins that must be installed before this bulletin.
IF NOT EXISTS (
	SELECT * FROM INFORMATION_SCHEMA.TABLES
	WHERE TABLE_NAME = 'SecurityBulletinRequires'
)
BEGIN
	CREATE TABLE SecurityBulletinRequires (
		-- Artificial primary key for this table.
		SecurityBulletinRequiresID int IDENTITY NOT NULL,
		-- Foreign key to the SecurityBulletin table.
		SecurityBulletinID	int NOT NULL,
		-- Foreign key to the SecurityBulletin table that the SecurityBulletinID requires.
		RequiredBulletinID	int NOT NULL,
		-- The type of requirement. Only supports 0, which is a dependency requirement.
		Strength		int NOT NULL,
		CONSTRAINT FK_SecurityBulletinRequires_SecurityBulletin
			FOREIGN KEY(SecurityBulletinID)
			REFERENCES SecurityBulletin(SecurityBulletinID) ON DELETE NO ACTION,
		CONSTRAINT FK_SecurityBulletinRequires2_SecurityBulletin
			FOREIGN KEY(RequiredBulletinID)
			REFERENCES SecurityBulletin(SecurityBulletinID) ON DELETE NO ACTION,
		CONSTRAINT PK_SecurityBulletinRequires
			PRIMARY KEY NONCLUSTERED(SecurityBulletinRequiresID)
	);

	CREATE CLUSTERED INDEX SecurityBulletinRequiresByBulletinIDRequiredBulletinID
		ON SecurityBulletinRequires(SecurityBulletinID, Strength)

END
ELSE
	PRINT 'Using existing SecurityBulletinRequires table'
GO

-- The SecurityPatch table is the ManageSoft record of known security patches.
IF NOT EXISTS (
	SELECT * FROM INFORMATION_SCHEMA.TABLES
	WHERE TABLE_NAME = 'SecurityPatch'
)
BEGIN
	CREATE TABLE SecurityPatch (
		-- Synthetic primary key for this table.
		PatchID			int IDENTITY NOT NULL,
		-- Foreign key to the parent bulletin in the SecurityBulletin table.
		BulletinID		nvarchar(32) NOT NULL,
		-- The name of the security patch.
		PatchName		nvarchar(128) COLLATE Latin1_General_CS_AS NOT NULL,
		-- The title of the security patch.
		Title			nvarchar(256) NOT NULL,
		-- The QNumber of the patch.
		QNumber			nvarchar(32) NOT NULL,
		-- The state of the patch.
		State			int NOT NULL DEFAULT 1,
		-- The command line options to be used when installing the security patch.
		InstallCommandLineOptions nvarchar(256) NULL,
		-- The command line options to be used when uninstalling the security patch.
		UnInstallCommandLineOptions nvarchar(256) NULL,
		-- The path of the patch executables that has been staged in the ManageSoft administration server.
		StagedFile		nvarchar(512) NULL,
		-- Whether a patch should be included as part of the bulletin. Patches that are not incorporated are ignored by ManageSoft.
		Incorporate		int NOT NULL DEFAULT 1,
		-- Whether this patch is supported by the ManageSoft Security Patch Management System.
		Supported		int NOT NULL DEFAULT 0,
		-- Whether a patch should be displayed as part of the bulletin.
		Ignore			int NOT NULL DEFAULT 0,
		-- The default command line options to be used when installing the security patch.
		DefaultInstallCmdLineOptions nvarchar(256) NULL,
		-- The default command line options to be used when uninstalling the security patch.
		DefaultUnInstallCmdLineOptions nvarchar(256) NULL,
		CONSTRAINT FK_SecurityPatch_SecurityBulletin
			FOREIGN KEY(BulletinID)
			REFERENCES SecurityBulletin(BulletinID) ON DELETE CASCADE,
		CONSTRAINT PK_SecurityPatch
			PRIMARY KEY NONCLUSTERED(PatchID),
		CONSTRAINT UQ_SecurityPatch
			UNIQUE NONCLUSTERED(BulletinID, PatchName)
	);

END
ELSE
	PRINT 'Using existing SecurityPatch table'
GO

-- The SecurityPatchAlias table contains a list of any aliases for a security patch.
IF NOT EXISTS (
	SELECT * FROM INFORMATION_SCHEMA.TABLES
	WHERE TABLE_NAME = 'SecurityPatchAlias'
)
BEGIN
	CREATE TABLE SecurityPatchAlias (
		-- Foreign key to the parent bulletin in the SecurityBulletin table.
		BulletinID		nvarchar(32) NOT NULL,
		-- The alias of the security patch.
		PatchName		nvarchar(128) COLLATE Latin1_General_CS_AS NOT NULL,
		-- Foreign key to the patch in the SecurityPatch table with alias.
		SecurityPatchID		int NOT NULL,
		CONSTRAINT FK_SecurityPatchAlias_SecurityBulletin
			FOREIGN KEY(BulletinID)
			REFERENCES SecurityBulletin(BulletinID) ON DELETE NO ACTION,
		CONSTRAINT FK_SecurityPatchAlias_SecurityPatch
			FOREIGN KEY(SecurityPatchID)
			REFERENCES SecurityPatch(PatchID) ON DELETE CASCADE,
		CONSTRAINT PK_SecurityPatchAlias
			PRIMARY KEY NONCLUSTERED(BulletinID, PatchName)
	);

	CREATE NONCLUSTERED INDEX SecurityPatchAliasBySecurityPatchID
		ON SecurityPatchAlias(SecurityPatchID)

END
ELSE
	PRINT 'Using existing SecurityPatchAlias table'
GO

-- The SecurityPatchRequires table contains a list of any patches that must be installed before this patch.
IF NOT EXISTS (
	SELECT * FROM INFORMATION_SCHEMA.TABLES
	WHERE TABLE_NAME = 'SecurityPatchRequires'
)
BEGIN
	CREATE TABLE SecurityPatchRequires (
		-- Synthetic primary key.
		SecurityPatchRequiresID	int IDENTITY NOT NULL,
		-- Foreign key to the SecurityPatch table.
		PatchID			int NOT NULL,
		-- This is the patch that the PatchID requires. It is a foreign key to the SecurityPatch table.
		RequiredPatchID		int NOT NULL,
		-- The type of requirement. Only supports 0, which is a dependency requirement.
		Strength		int NOT NULL,
		CONSTRAINT FK_SecurityPatchRequires_SecurityPatch
			FOREIGN KEY(PatchID)
			REFERENCES SecurityPatch(PatchID) ON DELETE CASCADE,
		CONSTRAINT FK_SecurityPatchRequires2_SecurityPatch
			FOREIGN KEY(RequiredPatchID)
			REFERENCES SecurityPatch(PatchID) ON DELETE NO ACTION,
		CONSTRAINT PK_SecurityPatchRequires
			PRIMARY KEY NONCLUSTERED(SecurityPatchRequiresID)
	);

	CREATE CLUSTERED INDEX SecurityPatchRequiresByPatchIDRequiredPatchID
		ON SecurityPatchRequires(PatchID, Strength)

END
ELSE
	PRINT 'Using existing SecurityPatchRequires table'
GO

-- The SecurityPatchToPackageVersion table provides a mapping between security patches and packages in the Software Library.
IF NOT EXISTS (
	SELECT * FROM INFORMATION_SCHEMA.TABLES
	WHERE TABLE_NAME = 'SecurityPatchToPackageVersion'
)
BEGIN
	CREATE TABLE SecurityPatchToPackageVersion (
		-- Foreign key to the SecurityPatch table.
		PatchID			int NOT NULL,
		-- Foreign key to the PackageVersion table. This is the package that contains the security patch.
		PackageFullName		nvarchar(256) NOT NULL,
		-- The name of the package.
		PackageName		nvarchar(64) NOT NULL,
		-- The version of the package.
		Version			nvarchar(32) NULL,
		CONSTRAINT FK_SecurityPatchToPackageVersion_SecurityPatch
			FOREIGN KEY(PatchID)
			REFERENCES SecurityPatch(PatchID) ON DELETE CASCADE,
		CONSTRAINT PK_SecurityPatchToPackageVersion
			PRIMARY KEY CLUSTERED(PatchID)
	);

END
ELSE
	PRINT 'Using existing SecurityPatchToPackageVersion table'
GO

-- The SecurityState table describes the state of a security patch or bulletin.
IF NOT EXISTS (
	SELECT * FROM INFORMATION_SCHEMA.TABLES
	WHERE TABLE_NAME = 'SecurityState'
)
BEGIN
	CREATE TABLE SecurityState (
		-- Primary key.
		StateID			int IDENTITY NOT NULL,
		-- The description of the state.
		Description		nvarchar(64) NOT NULL,
		CONSTRAINT PK_SecurityState
			PRIMARY KEY CLUSTERED(StateID),
		CONSTRAINT UQ_SecurityStateByDescription
			UNIQUE NONCLUSTERED(Description)
	);

END
ELSE
	PRINT 'Using existing SecurityState table'
GO

-- The SecurityUserState table describes the state of a security patch or bulletin.
-- These are the user-signoff states (such as "patch tested", "package tested", and "signoff")
-- which appear in the user interface and allow for identification of the authorizing user.
IF NOT EXISTS (
	SELECT * FROM INFORMATION_SCHEMA.TABLES
	WHERE TABLE_NAME = 'SecurityUserState'
)
BEGIN
	CREATE TABLE SecurityUserState (
		-- Primary key.
		UserStateID		int IDENTITY NOT NULL,
		-- The description of the user state.
		Description		nvarchar(64) NOT NULL,
		CONSTRAINT PK_SecurityUserState
			PRIMARY KEY CLUSTERED(UserStateID)
	);

END
ELSE
	PRINT 'Using existing SecurityUserState table'
GO

-- The SecurityUIState table describes the progress of a security patch or bulletin through the
-- various conceptual folders in the user interface (New, In Progress, and the like).
IF NOT EXISTS (
	SELECT * FROM INFORMATION_SCHEMA.TABLES
	WHERE TABLE_NAME = 'SecurityUIState'
)
BEGIN
	CREATE TABLE SecurityUIState (
		-- Primary key.
		UIStateID		int IDENTITY NOT NULL,
		-- The description of the user interface state.
		Description		nvarchar(32) NOT NULL,
		CONSTRAINT PK_SecurityUIState
			PRIMARY KEY CLUSTERED(UIStateID),
		CONSTRAINT UQ_SecurityUIStateByDescription
			UNIQUE NONCLUSTERED(Description)
	);

END
ELSE
	PRINT 'Using existing SecurityUIState table'
GO

-- The SecurityStateChange table records changes in the SecurityState table for security patches and bulletins.
IF NOT EXISTS (
	SELECT * FROM INFORMATION_SCHEMA.TABLES
	WHERE TABLE_NAME = 'SecurityStateChange'
)
BEGIN
	CREATE TABLE SecurityStateChange (
		-- Primary key.
		SecurityStateChangeID	int IDENTITY NOT NULL,
		-- The id of the bulletin whose state was changed.
		BulletinID		nvarchar(32) NOT NULL,
		-- The state after it was changed.
		StateTo			int NOT NULL,
		-- The state before it was changed.
		StateFrom		int NOT NULL,
		-- The date the state was changed.
		DateChanged		datetime NOT NULL,
		-- The user comment that accompanies the state change.
		Comment			ntext NULL,
		-- The user who performed the change.
		Username		nvarchar(64) NOT NULL,
		CONSTRAINT FK_SecurityStateChange_SecurityState
			FOREIGN KEY(StateTo)
			REFERENCES SecurityState(StateID) ON DELETE NO ACTION,
		CONSTRAINT FK_SecurityStateChange_SecurityState_From
			FOREIGN KEY(StateFrom)
			REFERENCES SecurityState(StateID) ON DELETE NO ACTION,
		CONSTRAINT FK_SecurityStateChange_SecurityBulletin
			FOREIGN KEY(BulletinID)
			REFERENCES SecurityBulletin(BulletinID) ON DELETE CASCADE,
		CONSTRAINT PK_SecurityStateChange
			PRIMARY KEY NONCLUSTERED(SecurityStateChangeID),
		CONSTRAINT UQ_SecurityStateChange
			UNIQUE NONCLUSTERED(BulletinID, DateChanged)
	);

END
ELSE
	PRINT 'Using existing SecurityStateChange table'
GO

-- The SecurityUserStateChange table records changes in the SecurityUserState table for security bulletins.
IF NOT EXISTS (
	SELECT * FROM INFORMATION_SCHEMA.TABLES
	WHERE TABLE_NAME = 'SecurityUserStateChange'
)
BEGIN
	CREATE TABLE SecurityUserStateChange (
		-- Primary key.
		SecurityUserStateChangeID int IDENTITY NOT NULL,
		-- The id of the bulletin whose state was changed.
		SecurityBulletinID	int NOT NULL,
		-- The UserState after it was changed.
		UserStateID		int NOT NULL,
		-- The date of the change.
		DateChanged		datetime NOT NULL,
		-- The user comment that accompanies the state change.
		Comment			ntext NULL,
		-- The user who performed the change.
		Username		nvarchar(64) NOT NULL,
		-- Whether the state was signed off after testing.
		Certified		int NOT NULL,
		CONSTRAINT FK_SecurityUserStateChange_SecurityState
			FOREIGN KEY(UserStateID)
			REFERENCES SecurityUserState(UserStateID) ON DELETE NO ACTION,
		CONSTRAINT FK_SecurityUserStateChange_SecurityBulletin
			FOREIGN KEY(SecurityBulletinID)
			REFERENCES SecurityBulletin(SecurityBulletinID) ON DELETE CASCADE,
		CONSTRAINT PK_SecurityUserStateChange
			PRIMARY KEY NONCLUSTERED(SecurityUserStateChangeID)
	);

	CREATE NONCLUSTERED INDEX UQ_SecurityUserStateChange
		ON SecurityUserStateChange(SecurityBulletinID, DateChanged)

END
ELSE
	PRINT 'Using existing SecurityUserStateChange table'
GO

-- The SecurityAnalysisReport table records the last time that a computer reported security patch compliance data.
IF NOT EXISTS (
	SELECT * FROM INFORMATION_SCHEMA.TABLES
	WHERE TABLE_NAME = 'SecurityAnalysisReport'
)
BEGIN
	CREATE TABLE SecurityAnalysisReport (
		-- The id of the computer. Foreign key into the Computer table.
		ComputerID		int NOT NULL,
		-- The date that the version of mssecure.xml was last updated on the client.
		DataSourceDate		datetime NOT NULL DEFAULT getdate(),
		-- The version of mssecure.xml that was last updated on the client.
		DataSourceVersion	nvarchar(32) NULL,
		-- The time the compliance was performed on the client.
		AnalysisDate		datetime NOT NULL DEFAULT getdate(),
		-- When the Administration Server received the compliance report.
		ReceiveDate		datetime NOT NULL DEFAULT getdate(),
		CONSTRAINT PQ_SecurityAnalysisReport_ByComputer
			PRIMARY KEY NONCLUSTERED(ComputerID)
	);

	CREATE NONCLUSTERED INDEX SecurityAnalysisReport_ByDataSourceDate
		ON SecurityAnalysisReport(DataSourceDate)

END
ELSE
	PRINT 'Using existing SecurityAnalysisReport table'
GO

-- The SecurityPatchAnalysis table contains all the security patch compliance status entries for a computer.
IF NOT EXISTS (
	SELECT * FROM INFORMATION_SCHEMA.TABLES
	WHERE TABLE_NAME = 'SecurityPatchAnalysis'
)
BEGIN
	CREATE TABLE SecurityPatchAnalysis (
		-- Foreign key to the Computer table.
		ComputerID		int NOT NULL,
		-- The id string of the bulletin from mssecure.
		BulletinID		nvarchar(32) NOT NULL,
		-- Foreign key into the SecurityPatch table.
		SecurityPatchID		int NOT NULL,
		-- The mssecure id of the product that this patch applies to.
		ProductID		int NULL,
		-- The mssecure id of the service pack that this patch applies to.
		ServicePackID		int NULL,
		-- Foreign key into the SecurityPatchStatus table.
		Status			int NOT NULL,
		-- Compliance message from the client.
		StatusMessage		nvarchar(3000) NULL,
		-- Whether this patch was installed by ManageSoft.
		IsManaged		bit NOT NULL DEFAULT 0,
		CONSTRAINT FK_SecurityPatchAnalysis_SecutityPatch
			FOREIGN KEY(SecurityPatchID)
			REFERENCES SecurityPatch(PatchID) ON DELETE CASCADE,
		CONSTRAINT PQ_SecurityPatchAnalysis_ByComputer
			PRIMARY KEY CLUSTERED(ComputerID, BulletinID, SecurityPatchID)
	);

	CREATE NONCLUSTERED INDEX SecurityPatchAnalysis_ByBulletin
		ON SecurityPatchAnalysis(BulletinID, ComputerID)

END
ELSE
	PRINT 'Using existing SecurityPatchAnalysis table'
GO

-- A list of statuses that are used in the SecurityPatchAnalysis table. Populated at database creation.
IF NOT EXISTS (
	SELECT * FROM INFORMATION_SCHEMA.TABLES
	WHERE TABLE_NAME = 'SecurityPatchStatus'
)
BEGIN
	CREATE TABLE SecurityPatchStatus (
		-- Primary key.
		SecurityPatchStatusID	int IDENTITY NOT NULL,
		-- The text representing the patch compliance status that is matched against the MSA file (client security patch compliance log).
		InternalText		nvarchar(64) NOT NULL,
		-- Friendly version of the InternalText.
		DisplayText		nvarchar(64) NOT NULL,
		-- Priority of each status value for ordering in the reports.
		Severity		int NOT NULL,
		CONSTRAINT PQ_SecurityPatchStatus
			PRIMARY KEY NONCLUSTERED(SecurityPatchStatusID),
		CONSTRAINT UQ_SecurityPatchStatus
			UNIQUE NONCLUSTERED(InternalText)
	);

END
ELSE
	PRINT 'Using existing SecurityPatchStatus table'
GO

-- The SecurityPatchUIProductGroup table maps products to the logical product groupings that appear in the Security Patch Management UI.
IF NOT EXISTS (
	SELECT * FROM INFORMATION_SCHEMA.TABLES
	WHERE TABLE_NAME = 'SecurityPatchUIProductGroup'
)
BEGIN
	CREATE TABLE SecurityPatchUIProductGroup (
		-- Primary key.
		SecurityPatchUIProductGroupID int IDENTITY NOT NULL,
		-- The name of the logical product group.
		GroupName		nvarchar(64) NOT NULL,
		-- The product name. This is a foreign key into the SecPatch_Product table.
		Product			nvarchar(128) NOT NULL,
		CONSTRAINT PQ_SecurityPatchUIProductGroup
			PRIMARY KEY NONCLUSTERED(SecurityPatchUIProductGroupID),
		CONSTRAINT UQ_SecurityPatchUIProductGroupByProduct
			UNIQUE NONCLUSTERED(Product)
	);

	CREATE CLUSTERED INDEX SecurityPatchUIProductGroupByGroup
		ON SecurityPatchUIProductGroup(GroupName)

END
ELSE
	PRINT 'Using existing SecurityPatchUIProductGroup table'
GO

-- The SecurityPatchProductGroup table provides a mapping between products and ManageSoft environments that are used in the Packer.
IF NOT EXISTS (
	SELECT * FROM INFORMATION_SCHEMA.TABLES
	WHERE TABLE_NAME = 'SecurityPatchProductGroup'
)
BEGIN
	CREATE TABLE SecurityPatchProductGroup (
		-- Primary key.
		SecurityPatchProductGroupID int IDENTITY NOT NULL,
		-- The name of the ManageSoft environment to be used when a security patch affects the associated product.
		Environment		nvarchar(64) NOT NULL,
		-- The product that the environment is used for.
		Product			nvarchar(128) NOT NULL,
		CONSTRAINT PQ_SecurityPatchProductGroup
			PRIMARY KEY NONCLUSTERED(SecurityPatchProductGroupID)
	);

	CREATE NONCLUSTERED INDEX SecurityPatchProductGroupByEnvironment
		ON SecurityPatchProductGroup(Environment)

	CREATE CLUSTERED INDEX SecurityPatchProductGroupByProduct
		ON SecurityPatchProductGroup(Product)

END
ELSE
	PRINT 'Using existing SecurityPatchProductGroup table'
GO

-- The SecurityPatchProductUninstallValues table contains default uninstall commands for products.
IF NOT EXISTS (
	SELECT * FROM INFORMATION_SCHEMA.TABLES
	WHERE TABLE_NAME = 'SecurityPatchProductUninstallValues'
)
BEGIN
	CREATE TABLE SecurityPatchProductUninstallValues (
		-- Primary key.
		SecurityPatchProductUninstallValuesID int IDENTITY NOT NULL,
		-- The name of the product to set uninstall values for.
		Product			nvarchar(128) NOT NULL,
		-- The RegistryKey on the target system that contains the uninstall command line.
		RegistryKey		nvarchar(256) NOT NULL,
		-- The command line to uninstall the product.
		AbsoluteCommandLine	nvarchar(256) NOT NULL,
		-- The registry key in Add/Remove Programs that applies to the product.
		UninstallKey		nvarchar(128) NOT NULL,
		CONSTRAINT PK_SecurityPatchProductUninstallValues
			PRIMARY KEY NONCLUSTERED(SecurityPatchProductUninstallValuesID)
	);

	CREATE NONCLUSTERED INDEX SecurityPatchProductUninstallValuesByProduct
		ON SecurityPatchProductUninstallValues(Product)

END
ELSE
	PRINT 'Using existing SecurityPatchProductUninstallValues table'
GO

-- The SecurityPatchUninstallValues table contains uninstall commands that override the defaults for a security patch.
IF NOT EXISTS (
	SELECT * FROM INFORMATION_SCHEMA.TABLES
	WHERE TABLE_NAME = 'SecurityPatchUninstallValues'
)
BEGIN
	CREATE TABLE SecurityPatchUninstallValues (
		-- Primary key.
		SecurityPatchUninstallValuesID int IDENTITY NOT NULL,
		-- Foreign key to the SecurityPatch table.
		SecurityPatchID		int NOT NULL,
		-- The registry key on the target system that contains the uninstall command line.
		RegistryKey		nvarchar(256) NOT NULL,
		-- The command line to uninstall the product.
		AbsoluteCommandLine	nvarchar(256) NOT NULL,
		-- The registry key in Add/Remove Programs that applies to the product.
		UninstallKey		nvarchar(128) NOT NULL,
		CONSTRAINT FK_SecurityPatchUninstallValues_SecurityPatch
			FOREIGN KEY(SecurityPatchID)
			REFERENCES SecurityPatch(PatchID) ON DELETE CASCADE,
		CONSTRAINT PK_SecurityPatchUninstallValues
			PRIMARY KEY NONCLUSTERED(SecurityPatchUninstallValuesID)
	);

	CREATE CLUSTERED INDEX SecurityPatchUninstallValuesBySecurityPatchID
		ON SecurityPatchUninstallValues(SecurityPatchID)

END
ELSE
	PRINT 'Using existing SecurityPatchUninstallValues table'
GO

-- A resource (usually a file) that constitutes part of or the whole of a security patch.
IF NOT EXISTS (
	SELECT * FROM INFORMATION_SCHEMA.TABLES
	WHERE TABLE_NAME = 'SecurityPatchResource'
)
BEGIN
	CREATE TABLE SecurityPatchResource (
		-- Artificial key.
		SecurityPatchResourceID	int IDENTITY NOT NULL,
		-- The security patch that the resource belongs to.
		SecurityPatchID		int NOT NULL,
		-- Original URL of the resource.
		ResourceURL		nvarchar(256) NOT NULL,
		-- The architecture that the resource is built for.
		ArchitectureID		int NOT NULL,
		-- The language that the resource is built for.
		LanguageID		nvarchar(6) NOT NULL DEFAULT 'eng',
		-- The checksum for the resource.
		Checksum		nvarchar(256) NULL,
		-- The actual URL of the resource.
		ActualResourceURL	nvarchar(256) NULL,
		-- The local path of the resource.
		LocalPath		nvarchar(256) NULL,
		-- Whether this resource should be included as part of the patch.
		Incorporate		bit NOT NULL DEFAULT 1,
		-- The name of the security bulletin.
		BulletinID		nvarchar(32) NOT NULL,
		CONSTRAINT FK_SecurityPatchResource_SecurityPatchID
			FOREIGN KEY(SecurityPatchID)
			REFERENCES SecurityPatch(PatchID) ON DELETE CASCADE,
		CONSTRAINT FK_SecurityPatchResource_BulletinID
			FOREIGN KEY(BulletinID)
			REFERENCES SecurityBulletin(BulletinID) ON DELETE NO ACTION,
		CONSTRAINT PQ_SecurityPatchResource
			PRIMARY KEY NONCLUSTERED
			(SecurityPatchID, ResourceURL, ArchitectureID, LanguageID),
		CONSTRAINT UQ_SecurityPatchResource
			UNIQUE NONCLUSTERED(SecurityPatchResourceID)
	);

	CREATE NONCLUSTERED INDEX SecurityPatchResourceByBulletinID
		ON SecurityPatchResource(BulletinID)

END
ELSE
	PRINT 'Using existing SecurityPatchResource table'
GO

-- Security patch products supported by ManageSoft.
IF NOT EXISTS (
	SELECT * FROM INFORMATION_SCHEMA.TABLES
	WHERE TABLE_NAME = 'SecurityPatchProduct'
)
BEGIN
	CREATE TABLE SecurityPatchProduct (
		-- Primary key.
		SecurityPatchProductID	int IDENTITY NOT NULL,
		-- Vendor of the product.
		ProductVendor		nvarchar(64) NOT NULL,
		-- Name of the product.
		ProductName		nvarchar(128) NOT NULL,
		-- Version of the product.
		ProductVersion		nvarchar(64) NOT NULL,
		-- Packaging environment of the product.
		Environment		nvarchar(256) NULL,
		CONSTRAINT PQ_SecurityPatchProduct
			PRIMARY KEY NONCLUSTERED(ProductVendor, ProductName, ProductVersion),
		CONSTRAINT UQ_SecurityPatchProduct
			UNIQUE NONCLUSTERED(SecurityPatchProductID)
	);

END
ELSE
	PRINT 'Using existing SecurityPatchProduct table'
GO

-- A mapping between one or more products and resources.
IF NOT EXISTS (
	SELECT * FROM INFORMATION_SCHEMA.TABLES
	WHERE TABLE_NAME = 'SecurityPatchResourceProduct'
)
BEGIN
	CREATE TABLE SecurityPatchResourceProduct (
		-- Foreign key to SecurityPatchResource table.
		SecurityPatchResourceID	int NOT NULL,
		-- Foreign key to SecPatch_Product table.
		SecurityPatchProductID	int NOT NULL,
		CONSTRAINT FK_SecurityPatchResourceProduct_SecurityPatchResource
			FOREIGN KEY(SecurityPatchResourceID)
			REFERENCES SecurityPatchResource(SecurityPatchResourceID) ON DELETE CASCADE,
		CONSTRAINT FK_SecurityPatchResourceProduct_SecurityPatchProduct
			FOREIGN KEY(SecurityPatchProductID)
			REFERENCES SecurityPatchProduct(SecurityPatchProductID) ON DELETE CASCADE,
		CONSTRAINT PQ_SecurityPatchResourceProduct
			PRIMARY KEY NONCLUSTERED(SecurityPatchResourceID, SecurityPatchProductID)
	);

END
ELSE
	PRINT 'Using existing SecurityPatchResourceProduct table'
GO

-- The SecurityPatchLanguage table contains the list of supported and visible languages.
IF NOT EXISTS (
	SELECT * FROM INFORMATION_SCHEMA.TABLES
	WHERE TABLE_NAME = 'SecurityPatchLanguage'
)
BEGIN
	CREATE TABLE SecurityPatchLanguage (
		-- Primary key.
		LanguageName		nvarchar(6) NOT NULL,
		-- A friendly name for the language.
		Description		nvarchar(128) NOT NULL,
		-- If it is set to true then it is supported by ManageSoft Security Patch Management.
		Selected		bit NOT NULL,
		-- If it is set to true then it is shown on the properties dialog.
		Visible			bit NOT NULL,
		CONSTRAINT PK_SecurityPatchLanguage
			PRIMARY KEY NONCLUSTERED(LanguageName)
	);

	CREATE NONCLUSTERED INDEX SecurityPatchLanguageBySelected
		ON SecurityPatchLanguage(Selected)

END
ELSE
	PRINT 'Using existing SecurityPatchLanguage table'
GO

-- The SecurityPatchOperatingSystem table contains the list of supported and visible operating systems.
IF NOT EXISTS (
	SELECT * FROM INFORMATION_SCHEMA.TABLES
	WHERE TABLE_NAME = 'SecurityPatchOperatingSystem'
)
BEGIN
	CREATE TABLE SecurityPatchOperatingSystem (
		-- Operating system id.
		OperatingSystemID	int NOT NULL,
		-- A friendly name for the operating system.
		Description		nvarchar(128) NOT NULL,
		-- If it is set to true then it is supported by ManageSoft Security Patch Management.
		Selected		bit NOT NULL,
		-- If it is set to true then it is shown on the properties dialog.
		Visible			bit NOT NULL,
		CONSTRAINT FK_SecurityPatchOperatingSystem_SecurityPatchUIProductGroup
			FOREIGN KEY(OperatingSystemID)
			REFERENCES SecurityPatchUIProductGroup(SecurityPatchUIProductGroupID) ON DELETE CASCADE,
		CONSTRAINT PK_SecurityPatchOperatingSystem
			PRIMARY KEY NONCLUSTERED(OperatingSystemID)
	);

END
ELSE
	PRINT 'Using existing SecurityPatchOperatingSystem table'
GO

-- The SecurityPatchArchitecture table contains the list of supported and visible architectures.
IF NOT EXISTS (
	SELECT * FROM INFORMATION_SCHEMA.TABLES
	WHERE TABLE_NAME = 'SecurityPatchArchitecture'
)
BEGIN
	CREATE TABLE SecurityPatchArchitecture (
		-- Architecture id.
		ArchitectureID		int NOT NULL,
		-- A friendly name for the architecture.
		Description		nvarchar(128) NOT NULL,
		-- If it is set to true then it is supported by ManageSoft Security Patch Management.
		Selected		bit NOT NULL,
		-- If it is set to true then it is shown on the properties dialog.
		Visible			bit NOT NULL,
		CONSTRAINT PK_SecurityPatchArchitecture
			PRIMARY KEY NONCLUSTERED(ArchitectureID)
	);

	CREATE NONCLUSTERED INDEX SecurityPatchArchitectureBySelected
		ON SecurityPatchArchitecture(Selected)

END
ELSE
	PRINT 'Using existing SecurityPatchArchitecture table'
GO

-- The SecurityPatchApplication table contains the list of supported and visible applications.
IF NOT EXISTS (
	SELECT * FROM INFORMATION_SCHEMA.TABLES
	WHERE TABLE_NAME = 'SecurityPatchApplication'
)
BEGIN
	CREATE TABLE SecurityPatchApplication (
		-- Application id.
		ApplicationID		int NOT NULL,
		-- A friendly name for the application.
		Description		nvarchar(128) NOT NULL,
		-- If it is set to true then it is supported by ManageSoft Security Patch Management.
		Selected		bit NOT NULL,
		-- If it is set to true then it is shown on the properties dialog.
		Visible			bit NOT NULL,
		CONSTRAINT FK_SecurityPatchApplication_SecurityPatchUIProductGroup
			FOREIGN KEY(ApplicationID)
			REFERENCES SecurityPatchUIProductGroup(SecurityPatchUIProductGroupID) ON DELETE CASCADE,
		CONSTRAINT PK_SecurityPatchApplication
			PRIMARY KEY NONCLUSTERED(ApplicationID)
	);

END
ELSE
	PRINT 'Using existing SecurityPatchApplication table'
GO

-- The xxxx table contains the list of changes made to a bulletin by the automatic bulletin update.
IF NOT EXISTS (
	SELECT * FROM INFORMATION_SCHEMA.TABLES
	WHERE TABLE_NAME = 'SecurityBulletinChange'
)
BEGIN
	CREATE TABLE SecurityBulletinChange (
		-- ID of modified bulletin.
		BulletinID		nvarchar(32) NOT NULL,
		-- Type of change that was made.
		ChangeTypeID		int NOT NULL,
		CONSTRAINT PK_SecurityBulletinChange
			PRIMARY KEY NONCLUSTERED(BulletinID, ChangeTypeID)
	);

END
ELSE
	PRINT 'Using existing SecurityBulletinChange table'
GO

-- The xxxx table contains the list of available changes that can be made to a bulletin by the automatic bulletin update.
IF NOT EXISTS (
	SELECT * FROM INFORMATION_SCHEMA.TABLES
	WHERE TABLE_NAME = 'SecurityBulletinChangeType'
)
BEGIN
	CREATE TABLE SecurityBulletinChangeType (
		-- Bulletin change type ID.
		SecurityBulletinChangeTypeID int IDENTITY NOT NULL,
		-- Description of change to a bulletin.
		Description		nvarchar(64) NOT NULL,
		CONSTRAINT PK_SecurityBulletinChangeType
			PRIMARY KEY NONCLUSTERED(SecurityBulletinChangeTypeID),
		CONSTRAINT UQ_SecurityBulletinChangeTypeByDescription
			UNIQUE NONCLUSTERED(Description)
	);

END
ELSE
	PRINT 'Using existing SecurityBulletinChangeType table'
GO

-- List of threat types.
IF NOT EXISTS (
	SELECT * FROM INFORMATION_SCHEMA.TABLES
	WHERE TABLE_NAME = 'ThreatType'
)
BEGIN
	CREATE TABLE ThreatType (
		ThreatTypeID		int IDENTITY NOT NULL,
		[Name]			nvarchar(64) NOT NULL,
		CONSTRAINT PK_ThreatType
			PRIMARY KEY NONCLUSTERED([Name]),
		CONSTRAINT UQ_ThreatType
			UNIQUE NONCLUSTERED(ThreatTypeID)
	);

END
ELSE
	PRINT 'Using existing ThreatType table'
GO

-- List of threat categories.
IF NOT EXISTS (
	SELECT * FROM INFORMATION_SCHEMA.TABLES
	WHERE TABLE_NAME = 'ThreatCategory'
)
BEGIN
	CREATE TABLE ThreatCategory (
		ThreatCategoryID	int IDENTITY NOT NULL,
		[Name]			nvarchar(64) NOT NULL,
		ThreatTypeID		int NOT NULL,
		CONSTRAINT FK_ThreatCategory_ThreatType
			FOREIGN KEY(ThreatTypeID)
			REFERENCES ThreatType(ThreatTypeID) ON DELETE NO ACTION,
		CONSTRAINT PK_ThreatCategory
			PRIMARY KEY NONCLUSTERED([Name]),
		CONSTRAINT UQ_ThreatCategory
			UNIQUE NONCLUSTERED(ThreatCategoryID)
	);

	CREATE NONCLUSTERED INDEX ThreatCategoryByThreatTypeID
		ON ThreatCategory(ThreatTypeID)

END
ELSE
	PRINT 'Using existing ThreatCategory table'
GO

-- List of threat actions.
IF NOT EXISTS (
	SELECT * FROM INFORMATION_SCHEMA.TABLES
	WHERE TABLE_NAME = 'ThreatAction'
)
BEGIN
	CREATE TABLE ThreatAction (
		ThreatActionID		int IDENTITY NOT NULL,
		[Name]			nvarchar(64) NOT NULL,
		CONSTRAINT PK_ThreatAction
			PRIMARY KEY NONCLUSTERED([Name]),
		CONSTRAINT UQ_ThreatAction
			UNIQUE NONCLUSTERED(ThreatActionID)
	);

END
ELSE
	PRINT 'Using existing ThreatAction table'
GO

-- List of threat actions.
IF NOT EXISTS (
	SELECT * FROM INFORMATION_SCHEMA.TABLES
	WHERE TABLE_NAME = 'ThreatRisk'
)
BEGIN
	CREATE TABLE ThreatRisk (
		ThreatRiskID		int IDENTITY NOT NULL,
		[Name]			nvarchar(64) NOT NULL,
		Severity		int NOT NULL,
		CONSTRAINT PK_ThreatRisk
			PRIMARY KEY NONCLUSTERED([Name]),
		CONSTRAINT UQ_ThreatRisk
			UNIQUE NONCLUSTERED(ThreatRiskID)
	);

END
ELSE
	PRINT 'Using existing ThreatRisk table'
GO

-- Applications that scan for threats.
IF NOT EXISTS (
	SELECT * FROM INFORMATION_SCHEMA.TABLES
	WHERE TABLE_NAME = 'ThreatScanner'
)
BEGIN
	CREATE TABLE ThreatScanner (
		ThreatScannerID		int IDENTITY NOT NULL,
		[Name]			nvarchar(128) NOT NULL,
		Title			nvarchar(256) NULL,
		Version			nvarchar(256) NULL,
		Manufacturer		nvarchar(256) NULL,
		CONSTRAINT PK_ThreatScanner
			PRIMARY KEY NONCLUSTERED([Name]),
		CONSTRAINT UQ_ThreatScanner
			UNIQUE NONCLUSTERED(ThreatScannerID)
	);

END
ELSE
	PRINT 'Using existing ThreatScanner table'
GO

-- The list of threat types detected by a Scanner.
IF NOT EXISTS (
	SELECT * FROM INFORMATION_SCHEMA.TABLES
	WHERE TABLE_NAME = 'ThreatScannerToType'
)
BEGIN
	CREATE TABLE ThreatScannerToType (
		ThreatScannerID		int NOT NULL,
		ThreatTypeID		int NOT NULL,
		CONSTRAINT FK_ThreatScannerToType_ThreatScanner
			FOREIGN KEY(ThreatScannerID)
			REFERENCES ThreatScanner(ThreatScannerID) ON DELETE NO ACTION,
		CONSTRAINT FK_ThreatScannerToType_ThreatType
			FOREIGN KEY(ThreatTypeID)
			REFERENCES ThreatType(ThreatTypeID) ON DELETE NO ACTION,
		CONSTRAINT PK_ThreatScannerToType
			PRIMARY KEY NONCLUSTERED(ThreatScannerID, ThreatTypeID)
	);

END
ELSE
	PRINT 'Using existing ThreatScannerToType table'
GO

-- The infected item details from the Threat application.
IF NOT EXISTS (
	SELECT * FROM INFORMATION_SCHEMA.TABLES
	WHERE TABLE_NAME = 'Threat'
)
BEGIN
	CREATE TABLE Threat (
		ThreatID		int IDENTITY NOT NULL,
		[Name]			nvarchar(128) NOT NULL,
		Title			nvarchar(256) NOT NULL,
		ThreatTypeID		int NOT NULL,
		ThreatRiskID		int NOT NULL,
		CategorySummary		nvarchar(256) NOT NULL DEFAULT '',
		State			int NOT NULL DEFAULT 2,
		DatePosted		datetime NOT NULL DEFAULT getdate(),
		Description		ntext NOT NULL DEFAULT '',
		CONSTRAINT FK_Threat_ThreatType
			FOREIGN KEY(ThreatTypeID)
			REFERENCES ThreatType(ThreatTypeID) ON DELETE NO ACTION,
		CONSTRAINT FK_Threat_ThreatRisk
			FOREIGN KEY(ThreatRiskID)
			REFERENCES ThreatRisk(ThreatRiskID) ON DELETE NO ACTION,
		CONSTRAINT PK_Threat
			PRIMARY KEY NONCLUSTERED([Name]),
		CONSTRAINT UQ_Threat
			UNIQUE NONCLUSTERED(ThreatID)
	);

	CREATE NONCLUSTERED INDEX ThreatByThreatType
		ON Threat(ThreatTypeID)

END
ELSE
	PRINT 'Using existing Threat table'
GO

-- List of categories per threat.
IF NOT EXISTS (
	SELECT * FROM INFORMATION_SCHEMA.TABLES
	WHERE TABLE_NAME = 'ThreatToCategory'
)
BEGIN
	CREATE TABLE ThreatToCategory (
		ThreatID		int NOT NULL,
		ThreatCategoryID	int NOT NULL,
		CONSTRAINT FK_ThreatToCategory_Threat
			FOREIGN KEY(ThreatID)
			REFERENCES Threat(ThreatID) ON DELETE CASCADE,
		CONSTRAINT FK_ThreatToCategory_ThreatCategory
			FOREIGN KEY(ThreatCategoryID)
			REFERENCES ThreatCategory(ThreatCategoryID) ON DELETE CASCADE,
		CONSTRAINT PK_ThreatToCategory
			PRIMARY KEY NONCLUSTERED(ThreatID, ThreatCategoryID)
	);

	CREATE NONCLUSTERED INDEX UQ_ThreatToCategory
		ON ThreatToCategory(ThreatCategoryID)

END
ELSE
	PRINT 'Using existing ThreatToCategory table'
GO

-- List of Scanners that can detect a threat.
IF NOT EXISTS (
	SELECT * FROM INFORMATION_SCHEMA.TABLES
	WHERE TABLE_NAME = 'ThreatToScanner'
)
BEGIN
	CREATE TABLE ThreatToScanner (
		ThreatID		int NOT NULL,
		ThreatScannerID		int NOT NULL,
		CONSTRAINT FK_ThreatToScanner_Threat
			FOREIGN KEY(ThreatID)
			REFERENCES Threat(ThreatID) ON DELETE CASCADE,
		CONSTRAINT FK_ThreatToScanner_ThreatScanner
			FOREIGN KEY(ThreatScannerID)
			REFERENCES ThreatScanner(ThreatScannerID) ON DELETE NO ACTION,
		CONSTRAINT PK_ThreatToScanner
			PRIMARY KEY NONCLUSTERED(ThreatID, ThreatScannerID)
	);

	CREATE NONCLUSTERED INDEX UQ_ThreatToScanner
		ON ThreatToScanner(ThreatScannerID)

END
ELSE
	PRINT 'Using existing ThreatToScanner table'
GO

-- Log messages associated with a threat
IF NOT EXISTS (
	SELECT * FROM INFORMATION_SCHEMA.TABLES
	WHERE TABLE_NAME = 'ThreatLog'
)
BEGIN
	CREATE TABLE ThreatLog (
		ThreatLogID		int IDENTITY NOT NULL,
		ThreatID		int NOT NULL,
		Message			nvarchar(128) NOT NULL,
		DatePosted		datetime NOT NULL,
		CONSTRAINT FK_ThreatMessageLog_Threat
			FOREIGN KEY(ThreatID)
			REFERENCES Threat(ThreatID) ON DELETE CASCADE,
		CONSTRAINT PK_ThreatLog
			PRIMARY KEY NONCLUSTERED(ThreatLogID)
	);

	CREATE NONCLUSTERED INDEX ThreatMessageLogByThreat
		ON ThreatLog(ThreatID)

END
ELSE
	PRINT 'Using existing ThreatLog table'
GO

-- The detail results from the scan.
IF NOT EXISTS (
	SELECT * FROM INFORMATION_SCHEMA.TABLES
	WHERE TABLE_NAME = 'ThreatScan'
)
BEGIN
	CREATE TABLE ThreatScan (
		ComputerID		int NOT NULL,
		UserID			int NOT NULL,
		ThreatTypeID		int NOT NULL,
		ThreatScannerID		int NOT NULL,
		DataSourceDate		datetime NULL,
		DataSourceVersion	nvarchar(128) NULL,
		ScanStart		datetime NULL,
		ScanEnd			datetime NULL,
		CONSTRAINT FK_ThreatScan_ThreatType
			FOREIGN KEY(ThreatTypeID)
			REFERENCES ThreatType(ThreatTypeID) ON DELETE NO ACTION,
		CONSTRAINT FK_ThreatScan_ThreatScanner
			FOREIGN KEY(ThreatScannerID)
			REFERENCES ThreatScanner(ThreatScannerID) ON DELETE NO ACTION,
		CONSTRAINT PK_ThreatScan
			PRIMARY KEY NONCLUSTERED
			(ComputerID, UserID, ThreatTypeID, ThreatScannerID)
	);

END
ELSE
	PRINT 'Using existing ThreatScan table'
GO

-- Details outlining the occurrences of this infected item.
IF NOT EXISTS (
	SELECT * FROM INFORMATION_SCHEMA.TABLES
	WHERE TABLE_NAME = 'ThreatOccurrence'
)
BEGIN
	CREATE TABLE ThreatOccurrence (
		ComputerID		int NOT NULL,
		UserID			int NOT NULL,
		ThreatTypeID		int NOT NULL,
		ThreatID		int NOT NULL,
		ThreatScannerID		int NOT NULL,
		ThreatOccurrenceRiskID	int NOT NULL,
		ThreatActionID		int NOT NULL,
		Details			ntext NULL,
		CONSTRAINT FK_ThreatOccurrence_ThreatType
			FOREIGN KEY(ThreatTypeID)
			REFERENCES ThreatType(ThreatTypeID) ON DELETE NO ACTION,
		CONSTRAINT FK_ThreatOccurrence_Threat
			FOREIGN KEY(ThreatID)
			REFERENCES Threat(ThreatID) ON DELETE CASCADE,
		CONSTRAINT FK_ThreatOccurrence_ThreatScanner
			FOREIGN KEY(ThreatScannerID)
			REFERENCES ThreatScanner(ThreatScannerID) ON DELETE NO ACTION,
		CONSTRAINT FK_ThreatOccurrence_ThreatRisk
			FOREIGN KEY(ThreatOccurrenceRiskID)
			REFERENCES ThreatRisk(ThreatRiskID) ON DELETE NO ACTION,
		CONSTRAINT FK_ThreatOccurrence_ThreatAction
			FOREIGN KEY(ThreatActionID)
			REFERENCES ThreatAction(ThreatActionID) ON DELETE NO ACTION,
		CONSTRAINT PK_ThreatOccurrence
			PRIMARY KEY NONCLUSTERED
			(ComputerID, UserID, ThreatTypeID, ThreatID)
	);

	CREATE NONCLUSTERED INDEX ThreatOccurrenceByComputerUserThreatTypeThreatAction
		ON ThreatOccurrence
		(ThreatTypeID, ThreatActionID, ComputerID, UserID)

END
ELSE
	PRINT 'Using existing ThreatOccurrence table'
GO

-- List of applications that can be blocked from running.
IF NOT EXISTS (
	SELECT * FROM INFORMATION_SCHEMA.TABLES
	WHERE TABLE_NAME = 'BlockedApplication'
)
BEGIN
	CREATE TABLE BlockedApplication (
		[FileName]		nvarchar(256) NOT NULL,
		ApplicationName		nvarchar(256) NOT NULL DEFAULT '',
		Description		ntext NOT NULL DEFAULT '',
		Visible			bit NOT NULL DEFAULT 1,
		CONSTRAINT PK_BlockedApplication
			PRIMARY KEY NONCLUSTERED([FileName])
	);

END
ELSE
	PRINT 'Using existing BlockedApplication table'
GO


IF NOT EXISTS(SELECT * FROM SecPatch_Location)
BEGIN
	INSERT INTO SecPatch_Location (AbsolutePath, LocationID, Path)
		VALUES ('', 0, 'Other')
END
GO

IF NOT EXISTS(SELECT * FROM SecurityBulletin)
BEGIN
	SET IDENTITY_INSERT SecurityBulletin ON
	INSERT INTO SecurityBulletin (BulletinID, DatePosted, DateRevised, SecurityBulletinID, Severity)
		VALUES ('Unknown', '20030328', '20030328', 0, 0)
	SET IDENTITY_INSERT SecurityBulletin OFF
END
GO

IF NOT EXISTS(SELECT * FROM SecurityPatch)
BEGIN
	SET IDENTITY_INSERT SecurityPatch ON
	INSERT INTO SecurityPatch (BulletinID, PatchID, PatchName, QNumber, Title)
		VALUES ('Unknown', 0, 'Unknown', '', 'Unknown')
	SET IDENTITY_INSERT SecurityPatch OFF
END
GO

IF NOT EXISTS(SELECT * FROM SecurityState)
BEGIN
	SET IDENTITY_INSERT SecurityState ON
	INSERT INTO SecurityState (Description, StateID)
		VALUES ('Posted', 1)
	INSERT INTO SecurityState (Description, StateID)
		VALUES ('Downloaded', 2)
	INSERT INTO SecurityState (Description, StateID)
		VALUES ('Packaged', 3)
	INSERT INTO SecurityState (Description, StateID)
		VALUES ('Released', 4)
	SET IDENTITY_INSERT SecurityState OFF
END
GO

IF NOT EXISTS(SELECT * FROM SecurityUserState)
BEGIN
	SET IDENTITY_INSERT SecurityUserState ON
	INSERT INTO SecurityUserState (Description, UserStateID)
		VALUES ('Patch Tested', 1)
	INSERT INTO SecurityUserState (Description, UserStateID)
		VALUES ('Package Tested', 2)
	INSERT INTO SecurityUserState (Description, UserStateID)
		VALUES ('Signoff', 3)
	SET IDENTITY_INSERT SecurityUserState OFF
END
GO

IF NOT EXISTS(SELECT * FROM SecurityUIState)
BEGIN
	SET IDENTITY_INSERT SecurityUIState ON
	INSERT INTO SecurityUIState (Description, UIStateID)
		VALUES ('NewOrUpdated', 1)
	INSERT INTO SecurityUIState (Description, UIStateID)
		VALUES ('InProgress', 2)
	INSERT INTO SecurityUIState (Description, UIStateID)
		VALUES ('Released', 3)
	INSERT INTO SecurityUIState (Description, UIStateID)
		VALUES ('Hidden', 4)
	SET IDENTITY_INSERT SecurityUIState OFF
END
GO

IF NOT EXISTS(SELECT * FROM SecurityPatchStatus)
BEGIN
	SET IDENTITY_INSERT SecurityPatchStatus ON
	INSERT INTO SecurityPatchStatus (DisplayText, InternalText, SecurityPatchStatusID, Severity)
		VALUES ('Not applied', 'NotApplied', 1, 1)
	INSERT INTO SecurityPatchStatus (DisplayText, InternalText, SecurityPatchStatusID, Severity)
		VALUES ('Analyzed but unknown', 'Unknown', 2, 2)
	INSERT INTO SecurityPatchStatus (DisplayText, InternalText, SecurityPatchStatusID, Severity)
		VALUES ('Not analyzed', 'NotAnalyzed', 3, 3)
	INSERT INTO SecurityPatchStatus (DisplayText, InternalText, SecurityPatchStatusID, Severity)
		VALUES ('Applied with warning', 'Warning', 4, 4)
	INSERT INTO SecurityPatchStatus (DisplayText, InternalText, SecurityPatchStatusID, Severity)
		VALUES ('Not applicable', 'NotApplicable', 5, 5)
	INSERT INTO SecurityPatchStatus (DisplayText, InternalText, SecurityPatchStatusID, Severity)
		VALUES ('Superseded', 'Superseded', 6, 6)
	INSERT INTO SecurityPatchStatus (DisplayText, InternalText, SecurityPatchStatusID, Severity)
		VALUES ('Applied', 'Applied', 7, 7)
	SET IDENTITY_INSERT SecurityPatchStatus OFF
END
GO

IF NOT EXISTS(SELECT * FROM SecurityPatchUIProductGroup)
BEGIN
	SET IDENTITY_INSERT SecurityPatchUIProductGroup ON
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Internet Explorer', 'Internet Explorer 4.0', 3)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Internet Explorer', 'Internet Explorer 4.01', 4)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Internet Explorer', 'Internet Explorer 5', 6)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Internet Explorer', 'Internet Explorer 5.01', 7)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Internet Explorer', 'Internet Explorer 5.5', 10)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Internet Explorer', 'Internet Explorer 6', 11)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Internet Explorer', 'Internet Explorer 6.0 for Windows Server 2003', 12)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('IIS', 'Internet Information Server 3.0', 13)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('IIS', 'Internet Information Server 4.0', 14)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('IIS', 'Internet Information Services 5.0', 15)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('IIS', 'Internet Information Services 5.1', 16)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('IIS', 'Internet Information Services 6.0', 17)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('SQL Server', 'Microsoft SQL Server 2000 Desktop Engine (MSDE 2000)', 18)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('SQL Server', 'SQL Server 2000', 19)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('SQL Server', 'SQL Server 7.0', 20)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Windows 2000', 'Windows 2000 Advanced Server', 21)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Windows 2000', 'Windows 2000 Datacenter Server', 22)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Windows 2000', 'Windows 2000 Professional', 23)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Windows 2000', 'Windows 2000 Server', 24)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Windows 95', 'Windows 95', 25)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Windows 98', 'Windows 98', 26)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Windows 98', 'Windows 98 Resource Kit', 27)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Windows 98', 'Windows 98 Resource Kit Sampler', 28)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Windows 98', 'Windows 98 SE', 29)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Windows Millennium', 'Windows Me', 30)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Windows NT 4.0', 'Windows NT Server 4.0', 31)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Windows NT 4.0', 'Windows NT Server 4.0, Enterprise Edition', 32)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Windows NT 4.0', 'Windows NT Server 4.0, Terminal Server Edition', 33)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Windows NT 4.0', 'Windows NT Workstation 4.0', 34)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Windows Server 2003', 'Windows Server 2003 for Small Business Server', 35)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Windows Server 2003', 'Windows Server 2003, Datacenter Edition', 36)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Windows Server 2003', 'Windows Server 2003, Enterprise Edition', 37)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Windows Server 2003', 'Windows Server 2003, Standard Edition', 38)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Windows Server 2003', 'Windows Server 2003, Web Edition', 39)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Windows XP', 'Windows XP Home Edition', 40)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Windows XP', 'Windows XP Professional', 41)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Microsoft Office 2000', 'Microsoft Office 2000', 42)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Microsoft Office XP', 'Microsoft Office XP', 43)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Microsoft Office 2003', 'Microsoft Office 2003', 44)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Windows Media Player', 'Windows Media Player 6.4', 45)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Windows Media Player', 'Windows Media Player 6.4 for Windows NT 4.0', 46)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Windows Media Player', 'Windows Media Player 6.4 for Windows 2000', 47)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Windows Media Player', 'Windows Media Player 6.4 for Windows XP', 48)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Windows Media Player', 'Windows Media Player 6.4 for Windows Server 2003', 49)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Windows Media Player', 'Windows Media Player 7.0', 50)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Windows Media Player', 'Windows Media Player 7.1', 51)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Windows Media Player', 'Windows Media Player 9.0', 52)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Windows Media Player', 'Windows Media Player 9 Series', 53)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Windows Media Player', 'Windows Media Player 9 Series for Windows XP', 54)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Windows Media Player', 'Windows Media Player for Windows XP', 55)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Windows Media Player', 'Windows Media Player 9 Series for Windows Server 2003', 56)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Exchange Server', 'Exchange 2000 Enterprise Server', 57)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Exchange Server', 'Exchange 2000 Server', 58)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Exchange Server', 'Exchange Server', 59)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Exchange Server', 'Exchange Server 2003', 60)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Exchange Server', 'Exchange Server 5.0', 61)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Exchange Server', 'Exchange Server 5.5', 62)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('MDAC', 'MDAC 2.1', 63)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('MDAC', 'MDAC 2.5', 64)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('MDAC', 'MDAC 2.6', 65)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('MDAC', 'MDAC 2.7', 66)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('MDAC', 'MDAC 2.8', 67)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Virtual Machine', 'Microsoft Virtual Machine (VM)', 68)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('MSXML', 'MSXML 2.6', 69)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('MSXML', 'MSXML 3.0', 70)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('MSXML', 'MSXML 4.0', 71)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('MSXML', 'MSXML 6.0', 72)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('RedHat Linux', 'RedHat Enterprise Linux AS 2.1', 73)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('RedHat Linux', 'RedHat Enterprise Linux AS 3', 74)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('RedHat Linux', 'RedHat Enterprise Linux ES 2.1', 75)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('RedHat Linux', 'RedHat Enterprise Linux ES 3', 76)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('RedHat Linux', 'RedHat Enterprise Linux WS 2.1', 77)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('RedHat Linux', 'RedHat Enterprise Linux WS 3', 78)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('SuSE Linux', 'SuSE Linux 9.0', 79)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('SuSE Linux', 'SuSE Linux 9.1', 80)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('SuSE Linux', 'SuSE Linux 9.2', 81)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('SuSE Linux Enterprise Server', 'SuSE Linux Enterprise 9.0', 82)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Visual Studio .NET', 'Visual Studio .NET 2002', 83)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Visual Studio .NET', 'Visual Studio .NET 2003', 84)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('.NET Framework', '.NET Framework 1.0', 85)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('.NET Framework', '.NET Framework 1.0 SP2', 86)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('.NET Framework', '.NET Framework 1.0 SP3', 87)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('.NET Framework', '.NET Framework 1.1', 88)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('.NET Framework', '.NET Framework 1.1 RTM', 89)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('.NET Framework', '.NET Framework 1.1 RTM for Windows Server 2003', 90)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('.NET Framework', '.NET Framework 1.1 SP1', 91)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('.NET Framework', '.NET Framework 1.1 SP1 for Windows Server 2003', 92)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Picture It!/Digital Image', 'Picture It! or Digital Image v6', 93)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Picture It!/Digital Image', 'Picture It! or Digital Image v7', 94)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Picture It!/Digital Image', 'Picture It! or Digital Image v9', 95)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Microsoft Producer', 'Producer for 2003', 96)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Journal Viewer', 'Journal Viewer 1.5', 97)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Visual FoxPro', 'Visual FoxPro 8.0', 98)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Windows Sharepoint Services', 'Windows Sharepoint Services', 99)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('MSN Messenger', 'Windows Messenger 4.7.0.2009', 100)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('MSN Messenger', 'Windows Messenger 4.7.0.3000', 101)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('MSN Messenger', 'Windows Messenger 5.0', 102)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('MSN Messenger', 'MSN Messenger', 103)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Outlook Express', 'Outlook Express 4.01', 104)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Outlook Express', 'Outlook Express 5.01', 105)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Outlook Express', 'Outlook Express 5.5', 106)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Outlook Express', 'Outlook Express 5.5 Service Pack 2', 107)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Outlook Express', 'Outlook Express 5.5 SP2', 108)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Outlook Express', 'Outlook Express 6', 109)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Outlook Express', 'Outlook Express 6 on Windows Server 2003', 110)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Outlook Express', 'Outlook Express 6 Service Pack 1', 111)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Outlook Express', 'Outlook Express 6 SP1', 112)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Outlook Express', 'Outlook Express 6.0', 113)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Outlook Express', 'Outlook Express for Windows Server 2003', 114)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Outlook Express', 'Outlook Express for Windows Server 2003 64-bit Itanium Edition', 115)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('BackOffice Server', 'BizTalk Server 2000', 116)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('BackOffice Server', 'BizTalk Server 2002', 117)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('BackOffice Server', 'BackOffice Server 4.0', 118)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('BackOffice Server', 'BackOffice Server 2000', 119)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('BackOffice Server', 'BackOffice Resource Kit SE', 120)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('BackOffice Server', 'Site Server 3.0', 121)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('BackOffice Server', 'Site Server 3.0, Commerce Edition', 122)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('BackOffice Server', 'Microsoft Commercial Internet System 2.0', 123)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('BackOffice Server', 'Microsoft Commercial Internet System 2.5', 124)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('BackOffice Server', 'Commerce Server 2000', 125)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('BackOffice Server', 'Commerce Server 2002', 126)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('BackOffice Server', 'ISA Server 2000', 127)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('BackOffice Server', 'Proxy Server 2.0', 128)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('BackOffice Server', 'Content Management Server 2001', 129)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('BackOffice Server', 'Small Business Server 2000', 130)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('BackOffice Server', 'Windows Small Business Server 2003', 131)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('BackOffice Server', 'Microsoft Business Solutions CRM', 132)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Microsoft Works', 'Works 2000', 133)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Microsoft Works', 'Works 2001', 134)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Microsoft Works', 'Works 2002', 135)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Microsoft Works', 'Works 2003', 136)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Microsoft Works', 'Works 2004', 137)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Microsoft Works', 'Money 2000', 138)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Microsoft Works', 'Money 2001', 139)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Microsoft Works', 'Greetings 2000', 140)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Microsoft Works', 'Home Publishing 2000', 141)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Microsoft Office 97', 'Office 97', 142)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Microsoft Office 97', 'Access 97', 143)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Microsoft Office 97', 'Excel 97', 144)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Microsoft Office 97', 'PowerPoint 97', 145)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Microsoft Office 97', 'Word 97', 146)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Microsoft Office 2000', 'Access 2000', 147)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Microsoft Office 2000', 'Excel 2000', 148)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Microsoft Office 2000', 'FrontPage 2000', 149)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Microsoft Office 2000', 'Office 2000', 150)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Microsoft Office 2000', 'Office Web Components 2000', 151)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Microsoft Office 2000', 'Outlook 2000', 152)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Microsoft Office 2000', 'Powerpoint 2000', 153)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Microsoft Office 2000', 'Publisher 2000', 154)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Microsoft Office 2000', 'Word 2000', 155)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Microsoft Office XP', 'Access 2002', 156)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Microsoft Office XP', 'Excel 2002', 157)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Microsoft Office XP', 'FrontPage 2002', 158)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Microsoft Office XP', 'Office XP', 159)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Microsoft Office XP', 'Office Web Components XP', 160)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Microsoft Office XP', 'Office Web Components 2002', 161)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Microsoft Office XP', 'Outlook 2002', 162)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Microsoft Office XP', 'Powerpoint 2002', 163)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Microsoft Office XP', 'Publisher 2002', 164)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Microsoft Office XP', 'Word 2002', 165)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Microsoft Office 2003', 'Access 2003', 166)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Microsoft Office 2003', 'Excel 2003', 167)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Microsoft Office 2003', 'FrontPage 2003', 168)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Microsoft Office 2003', 'Office 2003', 169)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Microsoft Office 2003', 'Office Web Components 2003', 170)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Microsoft Office 2003', 'Outlook 2003', 171)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Microsoft Office 2003', 'Powerpoint 2003', 172)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Microsoft Office 2003', 'Publisher 2003', 173)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Microsoft Office 2003', 'Word 2003', 174)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('MDAC', 'Microsoft Data Access Components', 175)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('.NET Framework', '.NET Framework', 176)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Windows 2000', 'Windows 2000', 177)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Windows NT 4.0', 'Windows NT 4.0', 178)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Windows XP', 'Windows XP', 179)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Windows Server 2003', 'Windows Server 2003', 180)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Windows Server 2003', 'Windows Server 2003 64-bit Itanium Edition', 181)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Windows Server 2003', 'Windows Server 2003 x64 Edition', 182)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Windows XP', 'Windows XP x64 Edition', 183)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Windows Media Player', 'Windows Media Services', 184)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Windows Media Player', 'Windows Media Services 4.0', 185)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Windows Media Player', 'Windows Media Services 4.1', 186)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Windows Media Player', 'Windows Media Encoder 4.0', 187)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Windows Media Player', 'Windows Media Encoder 4.1', 188)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Windows Media Player', 'Windows Media Rights Manager 1', 189)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Windows Media Player', 'Windows Media Player', 190)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('IIS', 'FrontPage 98 Personal Web Server 1.0', 191)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('IIS', 'FrontPage 97 Personal Web Server 1.0', 192)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('IIS', 'Personal Web Server 4.0', 193)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('IIS', 'FrontPage 97 Server Extensions', 194)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('IIS', 'FrontPage 98 Server Extensions', 195)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('IIS', 'FrontPage 2000 Server Extensions', 196)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('IIS', 'Internet Information Services', 197)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('IIS', 'Internet Information Services and Windows XP', 198)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('IIS', 'FrontPage Server Extensions 2002', 199)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Virtual Machine', 'Microsoft Virtual Machine  Microsoft VM', 200)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Internet Explorer', 'Internet Explorer for Windows 2000', 201)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Internet Explorer', 'Internet Explorer for Windows Server 2003', 202)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Internet Explorer', 'Internet Explorer for Windows Server 2003 64-bit Itanium Edition', 203)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Internet Explorer', 'Internet Explorer for Windows Server 2003 x64 Edition', 204)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Internet Explorer', 'Internet Explorer for Windows XP', 205)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Internet Explorer', 'Internet Explorer for Windows XP Service Pack 2', 206)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Internet Explorer', 'Internet Explorer for Windows XP x64 Edition', 207)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Picture It!/Digital Image', 'PictureIt 2000', 208)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('MSN Messenger', 'Windows Messenger', 209)
	SET IDENTITY_INSERT SecurityPatchUIProductGroup OFF
END
GO

IF NOT EXISTS(SELECT * FROM SecurityPatchProductGroup)
BEGIN
	SET IDENTITY_INSERT SecurityPatchProductGroup ON
	INSERT INTO SecurityPatchProductGroup (Environment, Product, SecurityPatchProductGroupID)
		VALUES ('Microsoft Windows 2000 Server', 'Windows 2000 Advanced Server', 1)
	INSERT INTO SecurityPatchProductGroup (Environment, Product, SecurityPatchProductGroupID)
		VALUES ('Microsoft Windows 2000 Server', 'Windows 2000 Datacenter Server', 2)
	INSERT INTO SecurityPatchProductGroup (Environment, Product, SecurityPatchProductGroupID)
		VALUES ('Microsoft Windows 2000 Professional', 'Windows 2000 Professional', 3)
	INSERT INTO SecurityPatchProductGroup (Environment, Product, SecurityPatchProductGroupID)
		VALUES ('Microsoft Windows 2000 Server', 'Windows 2000 Server', 4)
	INSERT INTO SecurityPatchProductGroup (Environment, Product, SecurityPatchProductGroupID)
		VALUES ('Microsoft Windows 95', 'Windows 95', 5)
	INSERT INTO SecurityPatchProductGroup (Environment, Product, SecurityPatchProductGroupID)
		VALUES ('Microsoft Windows 98', 'Windows 98', 6)
	INSERT INTO SecurityPatchProductGroup (Environment, Product, SecurityPatchProductGroupID)
		VALUES ('Microsoft Windows 98', 'Windows 98 Resource Kit', 7)
	INSERT INTO SecurityPatchProductGroup (Environment, Product, SecurityPatchProductGroupID)
		VALUES ('Microsoft Windows 98', 'Windows 98 Resource Kit Sampler', 8)
	INSERT INTO SecurityPatchProductGroup (Environment, Product, SecurityPatchProductGroupID)
		VALUES ('Microsoft Windows 98', 'Windows 98 SE', 9)
	INSERT INTO SecurityPatchProductGroup (Environment, Product, SecurityPatchProductGroupID)
		VALUES ('Microsoft Windows Millennium Edition', 'Windows Me', 10)
	INSERT INTO SecurityPatchProductGroup (Environment, Product, SecurityPatchProductGroupID)
		VALUES ('Microsoft Windows NT 4.0', 'Windows NT Server 4.0', 11)
	INSERT INTO SecurityPatchProductGroup (Environment, Product, SecurityPatchProductGroupID)
		VALUES ('Microsoft Windows NT 4.0', 'Windows NT Server 4.0, Enterprise Edition', 12)
	INSERT INTO SecurityPatchProductGroup (Environment, Product, SecurityPatchProductGroupID)
		VALUES ('Microsoft Windows NT 4.0', 'Windows NT Server 4.0, Terminal Server Edition', 13)
	INSERT INTO SecurityPatchProductGroup (Environment, Product, SecurityPatchProductGroupID)
		VALUES ('Microsoft Windows NT 4.0', 'Windows NT Workstation 4.0', 14)
	INSERT INTO SecurityPatchProductGroup (Environment, Product, SecurityPatchProductGroupID)
		VALUES ('Microsoft Windows Server 2003', 'Windows Server 2003 for Small Business Server', 15)
	INSERT INTO SecurityPatchProductGroup (Environment, Product, SecurityPatchProductGroupID)
		VALUES ('Microsoft Windows Server 2003', 'Windows Server 2003, Datacenter Edition', 16)
	INSERT INTO SecurityPatchProductGroup (Environment, Product, SecurityPatchProductGroupID)
		VALUES ('Microsoft Windows Server 2003', 'Windows Server 2003, Enterprise Edition', 17)
	INSERT INTO SecurityPatchProductGroup (Environment, Product, SecurityPatchProductGroupID)
		VALUES ('Microsoft Windows Server 2003', 'Windows Server 2003, Standard Edition', 18)
	INSERT INTO SecurityPatchProductGroup (Environment, Product, SecurityPatchProductGroupID)
		VALUES ('Microsoft Windows Server 2003', 'Windows Server 2003, Web Edition', 19)
	INSERT INTO SecurityPatchProductGroup (Environment, Product, SecurityPatchProductGroupID)
		VALUES ('Microsoft Windows XP', 'Windows XP Home Edition', 20)
	INSERT INTO SecurityPatchProductGroup (Environment, Product, SecurityPatchProductGroupID)
		VALUES ('Microsoft Windows XP', 'Windows XP Professional', 21)
	SET IDENTITY_INSERT SecurityPatchProductGroup OFF
END
GO

IF NOT EXISTS(SELECT * FROM SecurityPatchLanguage)
BEGIN
	INSERT INTO SecurityPatchLanguage (Description, LanguageName, Selected, Visible)
		VALUES ('Arabic', 'ara', 0, 0)
	INSERT INTO SecurityPatchLanguage (Description, LanguageName, Selected, Visible)
		VALUES ('Chinese - Hong Kong SAR', 'zho-hk', 0, 0)
	INSERT INTO SecurityPatchLanguage (Description, LanguageName, Selected, Visible)
		VALUES ('Chinese - Simplified', 'zho-cn', 0, 0)
	INSERT INTO SecurityPatchLanguage (Description, LanguageName, Selected, Visible)
		VALUES ('Chinese - Traditional', 'zho-tw', 0, 0)
	INSERT INTO SecurityPatchLanguage (Description, LanguageName, Selected, Visible)
		VALUES ('Czech', 'ces', 0, 0)
	INSERT INTO SecurityPatchLanguage (Description, LanguageName, Selected, Visible)
		VALUES ('Danish', 'dan', 0, 0)
	INSERT INTO SecurityPatchLanguage (Description, LanguageName, Selected, Visible)
		VALUES ('Dutch', 'nld', 0, 0)
	INSERT INTO SecurityPatchLanguage (Description, LanguageName, Selected, Visible)
		VALUES ('English*', 'eng', 1, 1)
	INSERT INTO SecurityPatchLanguage (Description, LanguageName, Selected, Visible)
		VALUES ('Finnish', 'fin', 0, 0)
	INSERT INTO SecurityPatchLanguage (Description, LanguageName, Selected, Visible)
		VALUES ('French*', 'fra', 0, 1)
	INSERT INTO SecurityPatchLanguage (Description, LanguageName, Selected, Visible)
		VALUES ('German*', 'deu', 0, 1)
	INSERT INTO SecurityPatchLanguage (Description, LanguageName, Selected, Visible)
		VALUES ('Greek', 'ell-gr', 0, 0)
	INSERT INTO SecurityPatchLanguage (Description, LanguageName, Selected, Visible)
		VALUES ('Hebrew', 'heb', 0, 0)
	INSERT INTO SecurityPatchLanguage (Description, LanguageName, Selected, Visible)
		VALUES ('Hungarian', 'hun', 0, 0)
	INSERT INTO SecurityPatchLanguage (Description, LanguageName, Selected, Visible)
		VALUES ('Italian', 'ita', 0, 0)
	INSERT INTO SecurityPatchLanguage (Description, LanguageName, Selected, Visible)
		VALUES ('Japanese*', 'jpn', 0, 1)
	INSERT INTO SecurityPatchLanguage (Description, LanguageName, Selected, Visible)
		VALUES ('Korean', 'kor', 0, 0)
	INSERT INTO SecurityPatchLanguage (Description, LanguageName, Selected, Visible)
		VALUES ('Norwegian - Bokmal', 'nob-bo', 0, 0)
	INSERT INTO SecurityPatchLanguage (Description, LanguageName, Selected, Visible)
		VALUES ('Norwegian - Nynorsk', 'nno-no', 0, 0)
	INSERT INTO SecurityPatchLanguage (Description, LanguageName, Selected, Visible)
		VALUES ('Polish', 'pol', 0, 0)
	INSERT INTO SecurityPatchLanguage (Description, LanguageName, Selected, Visible)
		VALUES ('Portuguese (Portugal)', 'por-pt', 0, 0)
	INSERT INTO SecurityPatchLanguage (Description, LanguageName, Selected, Visible)
		VALUES ('Portuguese (Brazil)', 'por-br', 0, 0)
	INSERT INTO SecurityPatchLanguage (Description, LanguageName, Selected, Visible)
		VALUES ('Russian', 'rus', 0, 0)
	INSERT INTO SecurityPatchLanguage (Description, LanguageName, Selected, Visible)
		VALUES ('Slovenian', 'slv', 0, 0)
	INSERT INTO SecurityPatchLanguage (Description, LanguageName, Selected, Visible)
		VALUES ('Slovak', 'slk', 0, 0)
	INSERT INTO SecurityPatchLanguage (Description, LanguageName, Selected, Visible)
		VALUES ('Spanish', 'spa', 0, 0)
	INSERT INTO SecurityPatchLanguage (Description, LanguageName, Selected, Visible)
		VALUES ('Swedish', 'swe', 0, 0)
	INSERT INTO SecurityPatchLanguage (Description, LanguageName, Selected, Visible)
		VALUES ('Thai', 'tha', 0, 0)
	INSERT INTO SecurityPatchLanguage (Description, LanguageName, Selected, Visible)
		VALUES ('Turkish', 'tur', 0, 0)
END
GO

IF NOT EXISTS(SELECT * FROM SecurityPatchOperatingSystem)
BEGIN
	INSERT INTO SecurityPatchOperatingSystem (Description, OperatingSystemID, Selected, Visible)
		VALUES ('SuSE Linux', 79, 1, 1)
	INSERT INTO SecurityPatchOperatingSystem (Description, OperatingSystemID, Selected, Visible)
		VALUES ('RedHat Linux', 73, 1, 1)
	INSERT INTO SecurityPatchOperatingSystem (Description, OperatingSystemID, Selected, Visible)
		VALUES ('Microsoft Windows 2000', 21, 1, 1)
	INSERT INTO SecurityPatchOperatingSystem (Description, OperatingSystemID, Selected, Visible)
		VALUES ('Microsoft Windows 95', 25, 1, 1)
	INSERT INTO SecurityPatchOperatingSystem (Description, OperatingSystemID, Selected, Visible)
		VALUES ('Microsoft Windows 98', 26, 1, 1)
	INSERT INTO SecurityPatchOperatingSystem (Description, OperatingSystemID, Selected, Visible)
		VALUES ('Microsoft Windows Millennium', 30, 1, 1)
	INSERT INTO SecurityPatchOperatingSystem (Description, OperatingSystemID, Selected, Visible)
		VALUES ('Microsoft Windows NT 4', 31, 1, 1)
	INSERT INTO SecurityPatchOperatingSystem (Description, OperatingSystemID, Selected, Visible)
		VALUES ('Microsoft Windows Server 2003', 35, 1, 1)
	INSERT INTO SecurityPatchOperatingSystem (Description, OperatingSystemID, Selected, Visible)
		VALUES ('Microsoft Windows XP', 40, 1, 1)
END
GO

IF NOT EXISTS(SELECT * FROM SecurityPatchArchitecture)
BEGIN
	INSERT INTO SecurityPatchArchitecture (ArchitectureID, Description, Selected, Visible)
		VALUES (1, 'Intel i386', 1, 1)
	INSERT INTO SecurityPatchArchitecture (ArchitectureID, Description, Selected, Visible)
		VALUES (2, 'Intel i586', 1, 1)
	INSERT INTO SecurityPatchArchitecture (ArchitectureID, Description, Selected, Visible)
		VALUES (3, 'Intel i686', 1, 1)
	INSERT INTO SecurityPatchArchitecture (ArchitectureID, Description, Selected, Visible)
		VALUES (4, 'AMD Athlon', 1, 1)
END
GO

IF NOT EXISTS(SELECT * FROM SecurityPatchApplication)
BEGIN
	INSERT INTO SecurityPatchApplication (ApplicationID, Description, Selected, Visible)
		VALUES (57, 'Microsoft Exchange Server', 1, 1)
	INSERT INTO SecurityPatchApplication (ApplicationID, Description, Selected, Visible)
		VALUES (13, 'Internet Information Services', 1, 1)
	INSERT INTO SecurityPatchApplication (ApplicationID, Description, Selected, Visible)
		VALUES (3, 'Microsoft Internet Explorer', 1, 1)
	INSERT INTO SecurityPatchApplication (ApplicationID, Description, Selected, Visible)
		VALUES (63, 'MDAC', 1, 1)
	INSERT INTO SecurityPatchApplication (ApplicationID, Description, Selected, Visible)
		VALUES (42, 'Microsoft Office 2000', 1, 1)
	INSERT INTO SecurityPatchApplication (ApplicationID, Description, Selected, Visible)
		VALUES (44, 'Microsoft Office 2003', 1, 1)
	INSERT INTO SecurityPatchApplication (ApplicationID, Description, Selected, Visible)
		VALUES (43, 'Microsoft Office XP', 1, 1)
	INSERT INTO SecurityPatchApplication (ApplicationID, Description, Selected, Visible)
		VALUES (69, 'MSXML', 1, 1)
	INSERT INTO SecurityPatchApplication (ApplicationID, Description, Selected, Visible)
		VALUES (18, 'SQL Server', 1, 1)
	INSERT INTO SecurityPatchApplication (ApplicationID, Description, Selected, Visible)
		VALUES (68, 'Virtual Machine', 1, 1)
	INSERT INTO SecurityPatchApplication (ApplicationID, Description, Selected, Visible)
		VALUES (45, 'Microsoft Windows Media Player', 1, 1)
	INSERT INTO SecurityPatchApplication (ApplicationID, Description, Selected, Visible)
		VALUES (83, 'Visual Studio .NET', 1, 1)
	INSERT INTO SecurityPatchApplication (ApplicationID, Description, Selected, Visible)
		VALUES (85, '.NET Framework', 1, 1)
	INSERT INTO SecurityPatchApplication (ApplicationID, Description, Selected, Visible)
		VALUES (93, 'Picture It!/Digital Image', 1, 1)
	INSERT INTO SecurityPatchApplication (ApplicationID, Description, Selected, Visible)
		VALUES (96, 'Microsoft Producer', 1, 1)
	INSERT INTO SecurityPatchApplication (ApplicationID, Description, Selected, Visible)
		VALUES (97, 'Journal Viewer', 1, 1)
	INSERT INTO SecurityPatchApplication (ApplicationID, Description, Selected, Visible)
		VALUES (98, 'Visual FoxPro', 1, 1)
	INSERT INTO SecurityPatchApplication (ApplicationID, Description, Selected, Visible)
		VALUES (99, 'Windows Sharepoint Services', 1, 1)
	INSERT INTO SecurityPatchApplication (ApplicationID, Description, Selected, Visible)
		VALUES (100, 'MSN Messenger', 1, 1)
	INSERT INTO SecurityPatchApplication (ApplicationID, Description, Selected, Visible)
		VALUES (104, 'Outlook Express', 1, 1)
	INSERT INTO SecurityPatchApplication (ApplicationID, Description, Selected, Visible)
		VALUES (116, 'BackOffice Server', 1, 1)
	INSERT INTO SecurityPatchApplication (ApplicationID, Description, Selected, Visible)
		VALUES (133, 'Microsoft Works', 1, 1)
	INSERT INTO SecurityPatchApplication (ApplicationID, Description, Selected, Visible)
		VALUES (142, 'Microsoft Office 97', 1, 1)
END
GO

IF NOT EXISTS(SELECT * FROM SecurityBulletinChangeType)
BEGIN
	SET IDENTITY_INSERT SecurityBulletinChangeType ON
	INSERT INTO SecurityBulletinChangeType (Description, SecurityBulletinChangeTypeID)
		VALUES ('BulletinRevision', 1)
	INSERT INTO SecurityBulletinChangeType (Description, SecurityBulletinChangeTypeID)
		VALUES ('PatchCommandLines', 2)
	INSERT INTO SecurityBulletinChangeType (Description, SecurityBulletinChangeTypeID)
		VALUES ('PatchDownloadLocations', 3)
	INSERT INTO SecurityBulletinChangeType (Description, SecurityBulletinChangeTypeID)
		VALUES ('BulletinInformation', 4)
	SET IDENTITY_INSERT SecurityBulletinChangeType OFF
END
GO

IF NOT EXISTS(SELECT * FROM ThreatType)
BEGIN
	SET IDENTITY_INSERT ThreatType ON
	INSERT INTO ThreatType (Name, ThreatTypeID)
		VALUES ('malware', 1)
	INSERT INTO ThreatType (Name, ThreatTypeID)
		VALUES ('patch', 2)
	INSERT INTO ThreatType (Name, ThreatTypeID)
		VALUES ('vulnerability', 3)
	SET IDENTITY_INSERT ThreatType OFF
END
GO

IF NOT EXISTS(SELECT * FROM ThreatCategory)
BEGIN
	SET IDENTITY_INSERT ThreatCategory ON
	INSERT INTO ThreatCategory (Name, ThreatCategoryID, ThreatTypeID)
		VALUES ('Windows', 1, 3)
	INSERT INTO ThreatCategory (Name, ThreatCategoryID, ThreatTypeID)
		VALUES ('Password', 2, 3)
	INSERT INTO ThreatCategory (Name, ThreatCategoryID, ThreatTypeID)
		VALUES ('IIS', 3, 3)
	INSERT INTO ThreatCategory (Name, ThreatCategoryID, ThreatTypeID)
		VALUES ('SQL Server', 4, 3)
	SET IDENTITY_INSERT ThreatCategory OFF
END
GO

IF NOT EXISTS(SELECT * FROM ThreatAction)
BEGIN
	SET IDENTITY_INSERT ThreatAction ON
	INSERT INTO ThreatAction (Name, ThreatActionID)
		VALUES ('none', 1)
	INSERT INTO ThreatAction (Name, ThreatActionID)
		VALUES ('ignore', 2)
	INSERT INTO ThreatAction (Name, ThreatActionID)
		VALUES ('quarantine', 3)
	INSERT INTO ThreatAction (Name, ThreatActionID)
		VALUES ('restore', 4)
	INSERT INTO ThreatAction (Name, ThreatActionID)
		VALUES ('clean', 5)
	SET IDENTITY_INSERT ThreatAction OFF
END
GO

IF NOT EXISTS(SELECT * FROM ThreatRisk)
BEGIN
	SET IDENTITY_INSERT ThreatRisk ON
	INSERT INTO ThreatRisk (Name, Severity, ThreatRiskID)
		VALUES ('none', 0, 1)
	INSERT INTO ThreatRisk (Name, Severity, ThreatRiskID)
		VALUES ('not applicable', 1, 2)
	INSERT INTO ThreatRisk (Name, Severity, ThreatRiskID)
		VALUES ('unknown', 2, 3)
	INSERT INTO ThreatRisk (Name, Severity, ThreatRiskID)
		VALUES ('low', 3, 4)
	INSERT INTO ThreatRisk (Name, Severity, ThreatRiskID)
		VALUES ('guarded', 4, 5)
	INSERT INTO ThreatRisk (Name, Severity, ThreatRiskID)
		VALUES ('elevated', 5, 6)
	INSERT INTO ThreatRisk (Name, Severity, ThreatRiskID)
		VALUES ('high', 6, 7)
	INSERT INTO ThreatRisk (Name, Severity, ThreatRiskID)
		VALUES ('critical', 7, 8)
	SET IDENTITY_INSERT ThreatRisk OFF
END
GO

IF NOT EXISTS(SELECT * FROM ThreatScanner)
BEGIN
	SET IDENTITY_INSERT ThreatScanner ON
	INSERT INTO ThreatScanner (Name, ThreatScannerID)
		VALUES ('Unknown', 0)
	INSERT INTO ThreatScanner (Manufacturer, Name, ThreatScannerID, Title, Version)
		VALUES ('Microsoft', 'MBSA 1.2', 1, 'Microsoft Baseline Security Analyzer', '1.2')
	INSERT INTO ThreatScanner (Manufacturer, Name, ThreatScannerID, Title, Version)
		VALUES ('Microsoft', 'MBSA 2.0', 2, 'Microsoft Baseline Security Analyzer', '2.0')
	INSERT INTO ThreatScanner (Manufacturer, Name, ThreatScannerID, Title, Version)
		VALUES ('Aluria', 'Spyware Eliminator 1.0', 3, 'Aluria Spyware Eliminator', '1.0')
	INSERT INTO ThreatScanner (Manufacturer, Name, ThreatScannerID, Title)
		VALUES ('Microsoft', 'EST', 4, 'Microsoft Enterprise Update Scan Tool')
	SET IDENTITY_INSERT ThreatScanner OFF
END
GO

IF NOT EXISTS(SELECT * FROM ThreatScannerToType)
BEGIN
	INSERT INTO ThreatScannerToType (ThreatScannerID, ThreatTypeID)
		VALUES (1, 1)
	INSERT INTO ThreatScannerToType (ThreatScannerID, ThreatTypeID)
		VALUES (2, 2)
	INSERT INTO ThreatScannerToType (ThreatScannerID, ThreatTypeID)
		VALUES (2, 3)
	INSERT INTO ThreatScannerToType (ThreatScannerID, ThreatTypeID)
		VALUES (3, 2)
	INSERT INTO ThreatScannerToType (ThreatScannerID, ThreatTypeID)
		VALUES (3, 3)
	INSERT INTO ThreatScannerToType (ThreatScannerID, ThreatTypeID)
		VALUES (4, 2)
END
GO

IF NOT EXISTS(SELECT * FROM BlockedApplication)
BEGIN
	INSERT INTO BlockedApplication (ApplicationName, Description, FileName, Visible)
		VALUES ('Ares', 'Ares filesharing application', 'Ares.exe', 1)
	INSERT INTO BlockedApplication (ApplicationName, Description, FileName, Visible)
		VALUES ('Ares', 'Ares filesharing application', 'Areslite.exe', 1)
	INSERT INTO BlockedApplication (ApplicationName, Description, FileName, Visible)
		VALUES ('AIMaster Peer to Peer', 'AIMaster Peer to Peer filesharing application', 'Buddyizer.exe', 1)
	INSERT INTO BlockedApplication (ApplicationName, Description, FileName, Visible)
		VALUES ('CuteMX', 'CuteMX filesharing application', 'Cutemx.exe', 1)
	INSERT INTO BlockedApplication (ApplicationName, Description, FileName, Visible)
		VALUES ('Kaza', 'Kaza filesharing application', 'Kazaalite.exe', 1)
	INSERT INTO BlockedApplication (ApplicationName, Description, FileName, Visible)
		VALUES ('Overnet Peer to Peer', 'Overnet Peer to Peer filesharing application', 'Overnet.exe', 1)
	INSERT INTO BlockedApplication (ApplicationName, Description, FileName, Visible)
		VALUES ('Joltid Peer Enabler', 'Joltid filesharing application', 'P2P Networking.exe', 1)
	INSERT INTO BlockedApplication (ApplicationName, Description, FileName, Visible)
		VALUES ('Joltid', 'Joltid adware', 'P2P Networking3.exe', 1)
	INSERT INTO BlockedApplication (ApplicationName, Description, FileName, Visible)
		VALUES ('Piolet Music Sharing', 'Piolet Music filesharing application', 'Piolet.exe', 1)
	INSERT INTO BlockedApplication (ApplicationName, Description, FileName, Visible)
		VALUES ('Warez P2P Client', 'Warez P2P filesharing application', 'Warez.exe', 1)
	INSERT INTO BlockedApplication (ApplicationName, Description, FileName, Visible)
		VALUES ('FileFreedom P2P', 'FileFreedom P2P filesharing application', 'Wtm.exe', 1)
	INSERT INTO BlockedApplication (ApplicationName, Description, FileName, Visible)
		VALUES ('Microgaming/Casino gaming software', 'Downloader for Microgaming/Casino Software', 'Dlhelper.exe', 1)
	INSERT INTO BlockedApplication (ApplicationName, Description, FileName, Visible)
		VALUES ('Valve game software', 'Valve game patching utility', 'Steam.exe', 1)
	INSERT INTO BlockedApplication (ApplicationName, Description, FileName, Visible)
		VALUES ('AOL Instant Messenger', 'AOL Instant Messenger', 'Aim.exe', 1)
	INSERT INTO BlockedApplication (ApplicationName, Description, FileName, Visible)
		VALUES ('IBM/Lotus Instant Messaging', 'IBM/Lotus Instant Messaging', 'Connect.exe', 1)
	INSERT INTO BlockedApplication (ApplicationName, Description, FileName, Visible)
		VALUES ('Digital Dreams Messenger', 'Digital Dreams Instant Messenger', 'Dgdrhe~1.exe', 1)
	INSERT INTO BlockedApplication (ApplicationName, Description, FileName, Visible)
		VALUES ('Easy Messenger', 'Easy Instant Messenger', 'Em2.exe', 1)
	INSERT INTO BlockedApplication (ApplicationName, Description, FileName, Visible)
		VALUES ('Praize Messenger', 'Praize Instant Messenger', 'itLoad.exe', 1)
	INSERT INTO BlockedApplication (ApplicationName, Description, FileName, Visible)
		VALUES ('Meca IM Client', 'Meca Instant Messenger', 'Meca.exe', 1)
	INSERT INTO BlockedApplication (ApplicationName, Description, FileName, Visible)
		VALUES ('Windows Messenger', 'Windows Instant Messenger', 'Msmsgs.exe', 1)
	INSERT INTO BlockedApplication (ApplicationName, Description, FileName, Visible)
		VALUES ('Net message', 'Net message', 'Netmsg.exe', 1)
	INSERT INTO BlockedApplication (ApplicationName, Description, FileName, Visible)
		VALUES ('Windows Pop-up Utility', 'Windows Pop-up Utility', 'Winpopup.exe', 1)
	INSERT INTO BlockedApplication (ApplicationName, Description, FileName, Visible)
		VALUES ('Yahoo Messenger', 'Yahoo Instant Messenger', 'Ypager.exe', 1)
	INSERT INTO BlockedApplication (ApplicationName, Description, FileName, Visible)
		VALUES ('Trillian', 'Trillian Instant Messenger', 'Trillian.exe', 1)
	INSERT INTO BlockedApplication (ApplicationName, Description, FileName, Visible)
		VALUES ('Ipod media playing application', 'Detects when Ipod is connected', 'Ipodwatcher.exe', 1)
	INSERT INTO BlockedApplication (ApplicationName, Description, FileName, Visible)
		VALUES ('Macvtfy', 'Macvtfy media playing application', 'Macvtfy.exe', 1)
	INSERT INTO BlockedApplication (ApplicationName, Description, FileName, Visible)
		VALUES ('MusicMatch Juikebox', 'MusicMatch Juikebox media playing application', 'mmtask.exe', 1)
	INSERT INTO BlockedApplication (ApplicationName, Description, FileName, Visible)
		VALUES ('Omgstartup', 'Omgstartup media playing application', 'Omgstartup.exe', 1)
	INSERT INTO BlockedApplication (ApplicationName, Description, FileName, Visible)
		VALUES ('Screendragon video player', 'Screendragon video player', 'Screendragon_VS_Taskbar.exe', 1)
	INSERT INTO BlockedApplication (ApplicationName, Description, FileName, Visible)
		VALUES ('SM1BG', 'SM1BG media playing application', 'SM1BG.exe', 1)
	INSERT INTO BlockedApplication (ApplicationName, Description, FileName, Visible)
		VALUES ('Windows Media Player', 'Windows Media Player', 'WMPLAYER.exe', 1)
	INSERT INTO BlockedApplication (ApplicationName, Description, FileName, Visible)
		VALUES ('Windows Media Player', 'Windows Media Player', 'Mplayer.exe', 1)
	INSERT INTO BlockedApplication (ApplicationName, Description, FileName, Visible)
		VALUES ('iTunes', 'iTunes media playing application', 'Itunes.exe', 1)
	INSERT INTO BlockedApplication (ApplicationName, Description, FileName, Visible)
		VALUES ('Active Ports', 'Active Ports network monitoring tool', 'Aports.exe', 1)
END
GO

IF NOT EXISTS (
	SELECT *
	FROM INFORMATION_SCHEMA.CONSTRAINT_COLUMN_USAGE
	WHERE CONSTRAINT_NAME = 'FK_AffectedProduct_Patch'
)
BEGIN
	PRINT 'Create FK_AffectedProduct_Patch constraint'

	ALTER TABLE SecPatch_AffectedProduct
		ADD CONSTRAINT FK_AffectedProduct_Patch
		FOREIGN KEY(PatchID)
		REFERENCES SecPatch_Patch(PatchID) ON DELETE CASCADE
END
ELSE
	PRINT 'Using existing FK_AffectedProduct_Patch constraint'
GO
IF NOT EXISTS (
	SELECT *
	FROM INFORMATION_SCHEMA.CONSTRAINT_COLUMN_USAGE
	WHERE CONSTRAINT_NAME = 'FK_AffectedProduct_Product'
)
BEGIN
	PRINT 'Create FK_AffectedProduct_Product constraint'

	ALTER TABLE SecPatch_AffectedProduct
		ADD CONSTRAINT FK_AffectedProduct_Product
		FOREIGN KEY(ProductID)
		REFERENCES SecPatch_Product(ProductID) ON DELETE CASCADE
END
ELSE
	PRINT 'Using existing FK_AffectedProduct_Product constraint'
GO
IF NOT EXISTS (
	SELECT *
	FROM INFORMATION_SCHEMA.CONSTRAINT_COLUMN_USAGE
	WHERE CONSTRAINT_NAME = 'FK_AffectedServicePack_ServicePack'
)
BEGIN
	PRINT 'Create FK_AffectedServicePack_ServicePack constraint'

	ALTER TABLE SecPatch_AffectedServicePack
		ADD CONSTRAINT FK_AffectedServicePack_ServicePack
		FOREIGN KEY(ServicePackID)
		REFERENCES SecPatch_ServicePack(ServicePackID) ON DELETE CASCADE
END
ELSE
	PRINT 'Using existing FK_AffectedServicePack_ServicePack constraint'
GO
IF NOT EXISTS (
	SELECT *
	FROM INFORMATION_SCHEMA.CONSTRAINT_COLUMN_USAGE
	WHERE CONSTRAINT_NAME = 'FK_BulletinComment_Bulletin'
)
BEGIN
	PRINT 'Create FK_BulletinComment_Bulletin constraint'

	ALTER TABLE SecPatch_BulletinComment
		ADD CONSTRAINT FK_BulletinComment_Bulletin
		FOREIGN KEY(BulletinID)
		REFERENCES SecPatch_Bulletin(BulletinID) ON DELETE CASCADE
END
ELSE
	PRINT 'Using existing FK_BulletinComment_Bulletin constraint'
GO
IF NOT EXISTS (
	SELECT *
	FROM INFORMATION_SCHEMA.CONSTRAINT_COLUMN_USAGE
	WHERE CONSTRAINT_NAME = 'FK_qNumber_Bulletin'
)
BEGIN
	PRINT 'Create FK_qNumber_Bulletin constraint'

	ALTER TABLE SecPatch_QNumber
		ADD CONSTRAINT FK_qNumber_Bulletin
		FOREIGN KEY(BulletinID)
		REFERENCES SecPatch_Bulletin(BulletinID) ON DELETE CASCADE
END
ELSE
	PRINT 'Using existing FK_qNumber_Bulletin constraint'
GO
IF NOT EXISTS (
	SELECT *
	FROM INFORMATION_SCHEMA.CONSTRAINT_COLUMN_USAGE
	WHERE CONSTRAINT_NAME = 'FK_Patch_Bulletin'
)
BEGIN
	PRINT 'Create FK_Patch_Bulletin constraint'

	ALTER TABLE SecPatch_Patch
		ADD CONSTRAINT FK_Patch_Bulletin
		FOREIGN KEY(BulletinID)
		REFERENCES SecPatch_Bulletin(BulletinID) ON DELETE CASCADE
END
ELSE
	PRINT 'Using existing FK_Patch_Bulletin constraint'
GO
IF NOT EXISTS (
	SELECT *
	FROM INFORMATION_SCHEMA.CONSTRAINT_COLUMN_USAGE
	WHERE CONSTRAINT_NAME = 'FK_Patch_SecurityPatch'
)
BEGIN
	PRINT 'Create FK_Patch_SecurityPatch constraint'

	ALTER TABLE SecPatch_Patch
		ADD CONSTRAINT FK_Patch_SecurityPatch
		FOREIGN KEY(SecurityPatchID)
		REFERENCES SecurityPatch(PatchID) ON DELETE CASCADE
END
ELSE
	PRINT 'Using existing FK_Patch_SecurityPatch constraint'
GO
IF NOT EXISTS (
	SELECT *
	FROM INFORMATION_SCHEMA.CONSTRAINT_COLUMN_USAGE
	WHERE CONSTRAINT_NAME = 'FK_SecurityBulletin_SecurityState'
)
BEGIN
	PRINT 'Create FK_SecurityBulletin_SecurityState constraint'

	ALTER TABLE SecurityBulletin
		ADD CONSTRAINT FK_SecurityBulletin_SecurityState
		FOREIGN KEY(State)
		REFERENCES SecurityState(StateID) ON DELETE NO ACTION
END
ELSE
	PRINT 'Using existing FK_SecurityBulletin_SecurityState constraint'
GO
IF NOT EXISTS (
	SELECT *
	FROM INFORMATION_SCHEMA.CONSTRAINT_COLUMN_USAGE
	WHERE CONSTRAINT_NAME = 'FK_SecurityBulletin_PackageVersion'
)
BEGIN
	PRINT 'Create FK_SecurityBulletin_PackageVersion constraint'

	ALTER TABLE SecurityBulletin
		ADD CONSTRAINT FK_SecurityBulletin_PackageVersion
		FOREIGN KEY(PackageVersionID)
		REFERENCES PackageVersion(PackageVersionID) ON DELETE CASCADE
END
ELSE
	PRINT 'Using existing FK_SecurityBulletin_PackageVersion constraint'
GO
IF NOT EXISTS (
	SELECT *
	FROM INFORMATION_SCHEMA.CONSTRAINT_COLUMN_USAGE
	WHERE CONSTRAINT_NAME = 'FK_SecurityBulletinToUserState_SecurityUserState'
)
BEGIN
	PRINT 'Create FK_SecurityBulletinToUserState_SecurityUserState constraint'

	ALTER TABLE SecurityBulletinToUserState
		ADD CONSTRAINT FK_SecurityBulletinToUserState_SecurityUserState
		FOREIGN KEY(UserStateID)
		REFERENCES SecurityUserState(UserStateID) ON DELETE NO ACTION
END
ELSE
	PRINT 'Using existing FK_SecurityBulletinToUserState_SecurityUserState constraint'
GO
IF NOT EXISTS (
	SELECT *
	FROM INFORMATION_SCHEMA.CONSTRAINT_COLUMN_USAGE
	WHERE CONSTRAINT_NAME = 'FK_SecurityPatch_SecurityState'
)
BEGIN
	PRINT 'Create FK_SecurityPatch_SecurityState constraint'

	ALTER TABLE SecurityPatch
		ADD CONSTRAINT FK_SecurityPatch_SecurityState
		FOREIGN KEY(State)
		REFERENCES SecurityState(StateID) ON DELETE NO ACTION
END
ELSE
	PRINT 'Using existing FK_SecurityPatch_SecurityState constraint'
GO
IF NOT EXISTS (
	SELECT *
	FROM INFORMATION_SCHEMA.CONSTRAINT_COLUMN_USAGE
	WHERE CONSTRAINT_NAME = 'FK_SecurityPatchAnalysis_SecutityPatchStatus'
)
BEGIN
	PRINT 'Create FK_SecurityPatchAnalysis_SecutityPatchStatus constraint'

	ALTER TABLE SecurityPatchAnalysis
		ADD CONSTRAINT FK_SecurityPatchAnalysis_SecutityPatchStatus
		FOREIGN KEY(Status)
		REFERENCES SecurityPatchStatus(SecurityPatchStatusID) ON DELETE NO ACTION
END
ELSE
	PRINT 'Using existing FK_SecurityPatchAnalysis_SecutityPatchStatus constraint'
GO
IF NOT EXISTS (
	SELECT *
	FROM INFORMATION_SCHEMA.CONSTRAINT_COLUMN_USAGE
	WHERE CONSTRAINT_NAME = 'FK_SecurityPatchResource_Architecture'
)
BEGIN
	PRINT 'Create FK_SecurityPatchResource_Architecture constraint'

	ALTER TABLE SecurityPatchResource
		ADD CONSTRAINT FK_SecurityPatchResource_Architecture
		FOREIGN KEY(ArchitectureID)
		REFERENCES Architecture(ArchitectureID) ON DELETE NO ACTION
END
ELSE
	PRINT 'Using existing FK_SecurityPatchResource_Architecture constraint'
GO
IF NOT EXISTS (
	SELECT *
	FROM INFORMATION_SCHEMA.CONSTRAINT_COLUMN_USAGE
	WHERE CONSTRAINT_NAME = 'FK_SecurityPatchResource_Locale'
)
BEGIN
	PRINT 'Create FK_SecurityPatchResource_Locale constraint'

	ALTER TABLE SecurityPatchResource
		ADD CONSTRAINT FK_SecurityPatchResource_Locale
		FOREIGN KEY(LanguageID)
		REFERENCES Locale(LocaleCode) ON DELETE CASCADE
END
ELSE
	PRINT 'Using existing FK_SecurityPatchResource_Locale constraint'
GO
IF NOT EXISTS (
	SELECT *
	FROM INFORMATION_SCHEMA.CONSTRAINT_COLUMN_USAGE
	WHERE CONSTRAINT_NAME = 'FK_SecurityPatchLanguage_Locale'
)
BEGIN
	PRINT 'Create FK_SecurityPatchLanguage_Locale constraint'

	ALTER TABLE SecurityPatchLanguage
		ADD CONSTRAINT FK_SecurityPatchLanguage_Locale
		FOREIGN KEY(LanguageName)
		REFERENCES Locale(LocaleCode) ON DELETE CASCADE
END
ELSE
	PRINT 'Using existing FK_SecurityPatchLanguage_Locale constraint'
GO
IF NOT EXISTS (
	SELECT *
	FROM INFORMATION_SCHEMA.CONSTRAINT_COLUMN_USAGE
	WHERE CONSTRAINT_NAME = 'FK_SecurityPatchApplication_Architecture'
)
BEGIN
	PRINT 'Create FK_SecurityPatchApplication_Architecture constraint'

	ALTER TABLE SecurityPatchArchitecture
		ADD CONSTRAINT FK_SecurityPatchApplication_Architecture
		FOREIGN KEY(ArchitectureID)
		REFERENCES Architecture(ArchitectureID) ON DELETE NO ACTION
END
ELSE
	PRINT 'Using existing FK_SecurityPatchApplication_Architecture constraint'
GO
IF NOT EXISTS (
	SELECT *
	FROM INFORMATION_SCHEMA.CONSTRAINT_COLUMN_USAGE
	WHERE CONSTRAINT_NAME = 'FK_SecurityBulletinChange_SecurityBulletinChangeType'
)
BEGIN
	PRINT 'Create FK_SecurityBulletinChange_SecurityBulletinChangeType constraint'

	ALTER TABLE SecurityBulletinChange
		ADD CONSTRAINT FK_SecurityBulletinChange_SecurityBulletinChangeType
		FOREIGN KEY(ChangeTypeID)
		REFERENCES SecurityBulletinChangeType(SecurityBulletinChangeTypeID) ON DELETE CASCADE
END
ELSE
	PRINT 'Using existing FK_SecurityBulletinChange_SecurityBulletinChangeType constraint'
GO
IF NOT EXISTS (
	SELECT *
	FROM INFORMATION_SCHEMA.CONSTRAINT_COLUMN_USAGE
	WHERE CONSTRAINT_NAME = 'FK_ThreatScan_Computer'
)
BEGIN
	PRINT 'Create FK_ThreatScan_Computer constraint'

	ALTER TABLE ThreatScan
		ADD CONSTRAINT FK_ThreatScan_Computer
		FOREIGN KEY(ComputerID)
		REFERENCES Computer(ComputerID) ON DELETE CASCADE
END
ELSE
	PRINT 'Using existing FK_ThreatScan_Computer constraint'
GO
IF NOT EXISTS (
	SELECT *
	FROM INFORMATION_SCHEMA.CONSTRAINT_COLUMN_USAGE
	WHERE CONSTRAINT_NAME = 'FK_ThreatScan_User'
)
BEGIN
	PRINT 'Create FK_ThreatScan_User constraint'

	ALTER TABLE ThreatScan
		ADD CONSTRAINT FK_ThreatScan_User
		FOREIGN KEY(UserID)
		REFERENCES [User](UserID) ON DELETE CASCADE
END
ELSE
	PRINT 'Using existing FK_ThreatScan_User constraint'
GO
IF NOT EXISTS (
	SELECT *
	FROM INFORMATION_SCHEMA.CONSTRAINT_COLUMN_USAGE
	WHERE CONSTRAINT_NAME = 'FK_ThreatOccurrence_Computer'
)
BEGIN
	PRINT 'Create FK_ThreatOccurrence_Computer constraint'

	ALTER TABLE ThreatOccurrence
		ADD CONSTRAINT FK_ThreatOccurrence_Computer
		FOREIGN KEY(ComputerID)
		REFERENCES Computer(ComputerID) ON DELETE CASCADE
END
ELSE
	PRINT 'Using existing FK_ThreatOccurrence_Computer constraint'
GO
IF NOT EXISTS (
	SELECT *
	FROM INFORMATION_SCHEMA.CONSTRAINT_COLUMN_USAGE
	WHERE CONSTRAINT_NAME = 'FK_ThreatOccurrence_User'
)
BEGIN
	PRINT 'Create FK_ThreatOccurrence_User constraint'

	ALTER TABLE ThreatOccurrence
		ADD CONSTRAINT FK_ThreatOccurrence_User
		FOREIGN KEY(UserID)
		REFERENCES [User](UserID) ON DELETE CASCADE
END
ELSE
	PRINT 'Using existing FK_ThreatOccurrence_User constraint'
GO
